<?php

namespace App\Exports;

use App\Models\Attendance;
use Maatwebsite\Excel\Concerns\FromCollection;
use Maatwebsite\Excel\Concerns\WithHeadings;
use Maatwebsite\Excel\Concerns\ShouldAutoSize;
use Maatwebsite\Excel\Concerns\WithStyles;
use PhpOffice\PhpSpreadsheet\Worksheet\Worksheet;
use PhpOffice\PhpSpreadsheet\Style\Fill;
use PhpOffice\PhpSpreadsheet\Style\Border;
use PhpOffice\PhpSpreadsheet\Style\Alignment;

class AttendanceExport implements FromCollection, WithHeadings, ShouldAutoSize, WithStyles
{
    protected $month;
    protected $year;

    public function __construct($month = null, $year = null)
    {
        $this->month = $month;
        $this->year = $year;
    }

    public function collection()
    {
        $query = Attendance::query();

        // Apply filters if month and year are provided
        if ($this->year && $this->month) {
            $query->whereYear('date', $this->year)
                ->whereMonth('date', $this->month);
        }

        $attendances = $query->with('employee')
            ->get();

        return $attendances->map(function ($attendance) {
            return [
                'Employee Name' => $attendance->employee ? $attendance->employee->complete_name : 'N/A',
                'Date' => $attendance->date,
                'Clock In' => $attendance->clock_in,
                'Clock Out' => $attendance->clock_out,
                'Hours Worked' => $attendance->hours_worked,
                'Notes' => $attendance->notes,
            ];
        });
    }

    public function headings(): array
    {
        $monthName = $this->month ? date('F', mktime(0, 0, 0, $this->month, 1)) : 'All Time';
        return [
            ["Attendance Records for {$monthName} {$this->year}"],
            [],
            ['Employee Name', 'Date', 'Clock In', 'Clock Out', 'Hours Worked', 'Notes'],
        ];
    }

    public function styles(Worksheet $sheet)
    {
        // Apply styles to the title
        $sheet->getStyle('A1')->applyFromArray([
            'font' => ['bold' => true, 'size' => 14],
            'alignment' => ['horizontal' => Alignment::HORIZONTAL_CENTER],
        ]);

        // Apply styles to the headings row
        $sheet->getStyle('A3:F3')->applyFromArray([
            'font' => ['bold' => true, 'size' => 12],
            'fill' => [
                'fillType' => Fill::FILL_SOLID,
                'startColor' => ['rgb' => 'FFFF00'],
            ],
        ]);

        // Apply styles to the data rows
        $sheet->getStyle('A4:F' . ($sheet->getHighestRow() - 1))->applyFromArray([
            'font' => ['size' => 10],
            'borders' => [
                'allBorders' => [
                    'borderStyle' => Border::BORDER_THIN,
                    'color' => ['rgb' => '000000'],
                ],
            ],
        ]);

        // Apply styles to the total row (if applicable)
        $totalRow = $sheet->getHighestRow();
        if ($totalRow > 3) {
            $sheet->getStyle('A' . $totalRow . ':F' . $totalRow)->applyFromArray([
                'font' => ['bold' => true, 'size' => 12],
                'fill' => [
                    'fillType' => Fill::FILL_SOLID,
                    'startColor' => ['rgb' => 'FFFF00'],
                ],
                'borders' => [
                    'allBorders' => [
                        'borderStyle' => Border::BORDER_THIN,
                        'color' => ['rgb' => '000000'],
                    ],
                ],
            ]);
        }

        return [];
    }
}
