<?php

namespace App\Exports;

use App\Models\NewPayment;
use Maatwebsite\Excel\Concerns\FromCollection;
use Maatwebsite\Excel\Concerns\WithHeadings;
use Maatwebsite\Excel\Concerns\WithMapping;
use Maatwebsite\Excel\Concerns\WithStyles;
use Maatwebsite\Excel\Concerns\ShouldAutoSize;
use PhpOffice\PhpSpreadsheet\Worksheet\Worksheet;
use PhpOffice\PhpSpreadsheet\Style\Border;
use PhpOffice\PhpSpreadsheet\Style\Fill;
use PhpOffice\PhpSpreadsheet\Style\Alignment;
use PhpOffice\PhpSpreadsheet\Style\Font;

class CombinedPaymentExport implements FromCollection, WithHeadings, WithMapping, WithStyles, ShouldAutoSize
{
    protected $month;
    protected $year;

    public function __construct($month = null, $year = null)
    {
        $this->month = $month;
        $this->year = $year;
    }

    public function collection()
    {
        $query = NewPayment::with(
            'payment',
            'payment.lease.unit',         // Load unit relationship
            'payment.lease.property',     // Load property relationship
            'payment.lease.client',       // Load client relationship
            'payment.electricPayments',
            'payment.waterPayments'
        );

        if ($this->year) {
            $query->whereYear('created_at', $this->year);
        }

        if ($this->month) {
            $query->whereMonth('created_at', $this->month);
        }

        return $query->get();
    }

    public function headings(): array
    {
        return [
            'Property Name',
            'Unit Name',      // Added Property Name
            'Business Name',       // Added Business Name
            'Owner\'s Name',
            'Date',
            'Rent Amount',
            'Amount Paid',
            'Balance',
            'Running Balance',
            'Light',
            'Water',
            'Voucher#',
            'Remarks',
            // Added Unit Name
            // Added Owner's Name
        ];
    }

    public function map($payment): array
    {
        $electricAmount = $payment->payment->electricPayments->sum('amount'); // Calculate total electric amount
        $waterAmount = $payment->payment->waterPayments->sum('amount'); // Calculate total water amount

        return [

            $payment->payment->lease->property->property_name ?? 'N/A', // Property Name
            $payment->payment->lease->unit->unit_name ?? 'N/A',       // Unit Name
            $payment->payment->lease->client->business_name ?? 'N/A', // Business Name
            $payment->payment->lease->client->owners_name ?? 'N/A',   // Owner's Name
            $payment->payment->payment_date->format('Y-m-d'), // Ensure date is formatted
            $payment->payment->Amount,
            $payment->rental_amount,
            $payment->payment->Amount - $payment->rental_amount,
            $payment->running_balance,
            $electricAmount,
            $waterAmount,
            $payment->newpayment_id,
            $payment->remarks,

        ];
    }

    public function styles(Worksheet $sheet)
    {
        // Apply styles to the header row
        $headerStyle = [
            'font' => [
                'bold' => true,
                'size' => 12,
            ],
            'alignment' => [
                'horizontal' => Alignment::HORIZONTAL_CENTER,
            ],
            'fill' => [
                'fillType' => Fill::FILL_SOLID,
                'color' => ['argb' => 'FFFF00'], // Yellow background
            ],
            'borders' => [
                'bottom' => [
                    'borderStyle' => Border::BORDER_THIN,
                    'color' => ['argb' => '000000'], // Black border
                ],
            ],
        ];

        $sheet->getStyle('A1:N1')->applyFromArray($headerStyle); // Update range to include new columns

        // Adjust column widths (auto size might not be perfect)
        foreach (range('A', 'N') as $column) {
            $sheet->getColumnDimension($column)->setAutoSize(true);
        }
    }
}
