<?php

namespace App\Exports;

use App\Models\Electricbill;
use Maatwebsite\Excel\Concerns\FromCollection;
use Maatwebsite\Excel\Concerns\WithHeadings;
use Maatwebsite\Excel\Concerns\ShouldAutoSize;
use Maatwebsite\Excel\Concerns\WithStyles;
use PhpOffice\PhpSpreadsheet\Worksheet\Worksheet;
use PhpOffice\PhpSpreadsheet\Style\Fill;
use PhpOffice\PhpSpreadsheet\Style\Border;

class ElectricbillExport implements FromCollection, WithHeadings, ShouldAutoSize, WithStyles
{
    protected $month;
    protected $year;

    public function __construct($month, $year)
    {
        $this->month = $month;
        $this->year = $year;
    }

    public function collection()
    {
        $bills = Electricbill::whereHas('billing', function ($query) {
            $query->whereYear('payment_date', $this->year);
            $query->whereMonth('payment_date', $this->month);
        })
            ->with('billing.lease.unit', 'billing.lease.client')
            ->get();

        $mappedBills = $bills->map(function ($electricbill) {
            return [
                'Unit Name' => $electricbill->billing->lease->unit ? $electricbill->billing->lease->unit->unit_name : 'N/A',
                'Client Name' => $electricbill->billing->lease->client ? $electricbill->billing->lease->client->owners_name : 'N/A',
                'Consumption' => $electricbill->consumption,
                'Rate' => $electricbill->rate,
                'Amount' => $electricbill->amount,
            ];
        });

        // Calculate total amount
        $totalAmount = $mappedBills->sum('Amount');

        // Add total row
        $mappedBills->push([
            'Unit Name' => '',
            'Client Name' => '',
            'Consumption' => '',
            'Rate' => 'Total',
            'Amount' => $totalAmount,
        ]);

        return $mappedBills;
    }

    public function headings(): array
    {
        $monthName = date('F', mktime(0, 0, 0, $this->month, 1));
        return [
            ["Light Bills for {$monthName} {$this->year}"],
            [],
            ['Unit Name', 'Client Name', 'Consumption', 'Rate', 'Amount'],
        ];
    }

    public function styles(Worksheet $sheet)
    {
        // Apply styles to the title
        $sheet->getStyle('A1')->applyFromArray([
            'font' => ['bold' => true, 'size' => 14],
            'alignment' => ['horizontal' => \PhpOffice\PhpSpreadsheet\Style\Alignment::HORIZONTAL_CENTER],
        ]);

        // Apply styles to the headings row
        $sheet->getStyle('A3:E3')->applyFromArray([
            'font' => ['bold' => true, 'size' => 12],
            'fill' => [
                'fillType' => Fill::FILL_SOLID,
                'startColor' => ['rgb' => 'FFFF00'],
            ],
        ]);

        // Apply styles to the data rows
        $sheet->getStyle('A4:E' . ($sheet->getHighestRow() - 1))->applyFromArray([
            'font' => ['size' => 10],
            'borders' => [
                'allBorders' => [
                    'borderStyle' => Border::BORDER_THIN,
                    'color' => ['rgb' => '000000'],
                ],
            ],
        ]);

        // Apply styles to the total row
        $sheet->getStyle('A' . $sheet->getHighestRow() . ':E' . $sheet->getHighestRow())->applyFromArray([
            'font' => ['bold' => true, 'size' => 12],
            'fill' => [
                'fillType' => Fill::FILL_SOLID,
                'startColor' => ['rgb' => 'FFFF00'],
            ],
            'borders' => [
                'allBorders' => [
                    'borderStyle' => Border::BORDER_THIN,
                    'color' => ['rgb' => '000000'],
                ],
            ],
        ]);

        return [];
    }
}
