<?php

namespace App\Exports;

use App\Models\Property;
use Maatwebsite\Excel\Concerns\FromCollection;
use Maatwebsite\Excel\Concerns\WithHeadings;
use Maatwebsite\Excel\Concerns\ShouldAutoSize;
use Maatwebsite\Excel\Concerns\WithStyles;
use PhpOffice\PhpSpreadsheet\Worksheet\Worksheet;
use PhpOffice\PhpSpreadsheet\Style\Fill;
use PhpOffice\PhpSpreadsheet\Style\Border;
use PhpOffice\PhpSpreadsheet\Style\Alignment;

class PropertyExport implements FromCollection, WithHeadings, ShouldAutoSize, WithStyles
{
    public function collection()
    {
        return Property::select(
            'property_name',
            'street_address',
            'city',
            'state',
            'zip',

        )->get();
    }

    public function headings(): array
    {
        return [
            'Property Name',
            'Street Address',
            'City',
            'State',
            'ZIP Code',

        ];
    }

    public function styles(Worksheet $sheet)
    {
        // Style the header row
        $headerStyle = [
            'font' => [
                'bold' => true,
                'size' => 12,
            ],
            'alignment' => [
                'horizontal' => Alignment::HORIZONTAL_CENTER,
            ],
            'fill' => [
                'fillType' => Fill::FILL_SOLID,
                'startColor' => ['rgb' => 'FFFF00'], // Yellow background
            ],
            'borders' => [
                'bottom' => [
                    'borderStyle' => Border::BORDER_THIN,
                    'color' => ['rgb' => '000000'], // Black border
                ],
            ],
        ];

        // Apply styles to the header row
        $sheet->getStyle('A1:G1')->applyFromArray($headerStyle);

        // Manually set column widths (auto size might not be perfect)
        $columnWidths = [
            'A' => 25,
            'B' => 30,
            'C' => 20,
            'D' => 10,
            'E' => 10,
            'F' => 15,
            'G' => 15,
        ];

        foreach ($columnWidths as $column => $width) {
            $sheet->getColumnDimension($column)->setWidth($width);
        }

        return [];
    }
}
