<?php

namespace App\Exports;

use App\Models\Client;
use Maatwebsite\Excel\Concerns\FromCollection;
use Maatwebsite\Excel\Concerns\WithHeadings;
use Maatwebsite\Excel\Concerns\ShouldAutoSize;
use Maatwebsite\Excel\Concerns\WithStyles;
use PhpOffice\PhpSpreadsheet\Worksheet\Worksheet;
use PhpOffice\PhpSpreadsheet\Style\Fill;
use PhpOffice\PhpSpreadsheet\Style\Border;
use PhpOffice\PhpSpreadsheet\Style\Alignment;

class UsersExport implements FromCollection, WithHeadings, ShouldAutoSize, WithStyles
{
    public function collection()
    {
        return Client::select(

            'business_name',
            'business_type',
            'home_address',
            'owners_name',
            'email',
            'id_type',
            'id_no',
            'contact_no',
            'phone_no',
            'vat',
            'w_holding_tax'
        )->get();
    }

    public function headings(): array
    {
        return [

            'Business Name',
            'Business Type',
            'Home Address',
            'Owner\'s Name',
            'email',
            'ID Type',
            'ID Number',
            'Contact Number',
            'Phone Number',
            'VAT',
            'Withholding Tax',
        ];
    }

    public function styles(Worksheet $sheet)
    {
        // Style the header row
        $headerStyle = [
            'font' => [
                'bold' => true,
                'size' => 12,
            ],
            'alignment' => [
                'horizontal' => Alignment::HORIZONTAL_CENTER,
            ],
            'fill' => [
                'fillType' => Fill::FILL_SOLID,
                'startColor' => ['rgb' => 'FFFF00'], // Yellow background
            ],
            'borders' => [
                'bottom' => [
                    'borderStyle' => Border::BORDER_THIN,
                    'color' => ['rgb' => '000000'], // Black border
                ],
            ],
        ];

        // Apply styles to the header row
        $sheet->getStyle('A1:L1')->applyFromArray($headerStyle);

        // Manually set column widths (auto size might not be perfect)
        $columnWidths = [
            'A' => 10,
            'B' => 10,
            'C' => 20,
            'D' => 20,
            'E' => 30,
            'F' => 25,
            'G' => 15,
            'H' => 20,
            'I' => 15,
            'J' => 15,
            'K' => 10,
            'L' => 15,
        ];

        foreach ($columnWidths as $column => $width) {
            $sheet->getColumnDimension($column)->setWidth($width);
        }

        return [];
    }
}
