<?php

// app/Http/Controllers/AdditionalFeeController.php

namespace App\Http\Controllers;

use App\Models\AdditionalFee;

use Yajra\DataTables\Facades\DataTables;
use Illuminate\Http\Request;
use App\Models\Payment; // Ensure this is imported

class AdditionalFeeController extends Controller
{


    public function index()
    {
        if (request()->ajax()) {
            $additionalFees = AdditionalFee::all();

            return DataTables::of($additionalFees)


                ->addColumn('actions', function ($additionalFees) {
                    return '<button class="px-2 py-1 text-white bg-blue-500 rounded"
                           onclick="openModal(\'editPayableModal' . $additionalFees->id . '\')">Edit</button>
                          <button onclick="openModal(\'deleteModal' . $additionalFees->id . '\')" class="px-2 py-1 font-bold text-white bg-red-500 rounded hover:bg-red-700">Delete</button>';
                })
                ->rawColumns(['payroll', 'actions'])
                ->toJson();
        }
        $additionalFees = AdditionalFee::all();
        $payments =  Payment::with('electricPayments', 'waterPayments', 'lease.client', 'lease.unit.property')
            ->whereIn('status', ['Unpaid', 'Partial Payment'])
            ->get();


        return view('CMS.Recievable.additionalfees', compact('additionalFees', 'payments'));
    }




    public function create()
    {
        return view('additionalfees.create');
    }

    public function store(Request $request)
    {
        $request->validate([
            'billing_id' => 'required|exists:payment,payment_id',
            'charge_type' => 'required|string|max:255',
            'amount' => 'required|numeric',
            'notes' => 'nullable|string',
            'date_of_payable' => 'required|date',
        ]);

        AdditionalFee::create($request->all());
        return redirect()->back()->with('success', 'Additional fee created successfully.');
    }

    public function show(AdditionalFee $additionalFee)
    {
        return view('additionalfees.show', compact('additionalFee'));
    }

    public function edit(AdditionalFee $additionalFee)
    {
        return view('additionalfees.edit', compact('additionalFee'));
    }

    public function update(Request $request, $id)
    {
        $request->validate([
            'billing_id' => 'required|exists:payment,payment_id',
            'charge_type' => 'required',
            'custom_charge_type' => 'nullable|string',
            'amount' => 'required|numeric|min:0',
            'notes' => 'nullable|string',
            'date_of_payable' => 'required|date',
        ]);

        $additionalFee = AdditionalFee::findOrFail($id);
        $additionalFee->update([
            'billing_id' => $request->billing_id,
            'charge_type' => $request->charge_type,
            'custom_charge_type' => $request->charge_type === 'custom' ? $request->custom_charge_type : null,
            'amount' => $request->amount,
            'notes' => $request->notes,
            'date_of_payable' => $request->date_of_payable,
        ]);

        return redirect()->back()->with('success', 'Additional Fee updated successfully.');
    }

    public function destroy($id)
    {
        $additionalFee = AdditionalFee::findOrFail($id);
        $additionalFee->delete();

        return redirect()->route('additionalfees.index')->with('success', 'Additional Fee deleted successfully.');
    }
}
