<?php

namespace App\Http\Controllers;

use Yajra\DataTables\Facades\DataTables;
use Illuminate\Http\Request;
use App\Models\Client;
use Illuminate\Support\Facades\DB;
use App\Models\Admin;
use App\Models\User;
use Illuminate\Support\Facades\Hash;

class AdminController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        if (request()->ajax()) {
            $admins = Admin::with('user')->get();

            return DataTables::of($admins)
                ->addColumn('email', function ($admin) {
                    // Assuming you have a method or attribute for billing
                    return $admin->user->email; // Or format it as needed
                })
                ->addColumn('actions', function ($admin) {
                    return '<button onclick="openModal(\'editModal' . $admin->admin_id . '\')" class="px-2 py-1 font-bold text-white bg-blue-500 rounded hover:bg-blue-700">Edit</button>
                           <button onclick="openModal(\'deleteModal' . $admin->admin_id . '\')" class="px-2 py-1 font-bold text-white bg-red-500 rounded hover:bg-red-700">Delete</button>';
                })
                ->rawColumns(['billing', 'actions'])
                ->toJson();
        }

        $admins = Admin::with('user')->get();
        return view('CMS.Admin.admin', compact('admins'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('CMS.Admin.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        DB::transaction(function () use ($request) {
            // Create the user record
            $user = User::create([
                'email' => $request->input('email'),
                'password' => Hash::make($request->input('password')),
                'role' => 'Admin',
            ]);

            // Create the admin record
            Admin::create([
                'admin_name' => $request->input('admin_name'),
                'user_id' => $user->id,
            ]);
        });

        return redirect()->route('admin.index')->with('success', 'Admin created successfully.');
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\Admin  $admin
     * @return \Illuminate\Http\Response
     */
    public function show(Admin $admin)
    {
        return view('CMS.Admin.show', compact('admin'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\Admin  $admin
     * @return \Illuminate\Http\Response
     */
    public function edit(Admin $admin)
    {
        return view('CMS.Admin.edit', compact('admin'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\Admin  $admin
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Admin $admin)
    {
        // Update admin record with validated data
        $admin->admin_name = $request->input('admin_name');
        $admin->save();

        // Update the associated user
        $user = $admin->user;
        $user->email = $request->input('email');
        if ($request->filled('password')) {
            $user->password = Hash::make($request->input('password'));
        }

        $user->save();

        return redirect()->route('admin.index')->with('success', 'Admin and User updated successfully.');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\Admin  $admin
     * @return \Illuminate\Http\Response
     */
    public function destroy(Admin $admin)
    {
        $user = $admin->user;
        $admin->delete();
        $user->delete();

        return redirect()->route('admin.index')->with('success', 'Admin deleted successfully.');
    }
}
