<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Attendance;
use App\Models\Employee;
use Yajra\DataTables\Facades\DataTables;
use App\Imports\AttendanceImport;
use Maatwebsite\Excel\Facades\Excel;
use Illuminate\Support\Facades\Log;
use Carbon\Carbon;

class AttendanceController extends Controller
{



    public function index(Request $request)
    {
        if ($request->ajax()) {
            $startDate = $request->query('start_date');
            $endDate = $request->query('end_date');

            $query = Attendance::query();

            if ($startDate && $endDate) {
                $query->whereBetween('date', [$startDate, $endDate]);
            }

            $attendance = $query->with('employee')->get(); // Ensure employee relation is loaded

            return DataTables::of($attendance)
                ->addColumn('complete_name', function ($attendance) {
                    return $attendance->employee ? $attendance->employee->complete_name : 'N/A';
                })
                ->addColumn('actions', function ($attendance) {
                    return '<button class="px-4 py-2 font-bold text-white bg-blue-500 rounded hover:bg-blue-700"
                                    onclick="toggleModal(\'editAttendanceModal' . $attendance->id . '\')">Edit</button>
                                <button class="px-4 py-2 font-bold text-white bg-red-500 rounded hover:bg-red-700"
                                    onclick="toggleModal(\'deleteAttendanceModal' . $attendance->id . '\')">Delete</button>';
                })
                ->rawColumns(['actions'])
                ->make(true);
        }

        $attendances = Attendance::all();
        $employees = Employee::get();
        return view('CMS.Payroll.attendance', compact('employees', 'attendances'));
    }


    public function create()
    {
        $employees = Employee::all(); // Fetch employees for the select options

        return view('CMS.Payroll.attendance', compact('employees'));
    }

    public function store(Request $request)
    {
        $request->validate([
            'employee_id' => 'required|exists:employees,id',
            'date' => 'required|date',
            'clock_in' => 'required|date_format:H:i',
            'clock_out' => 'nullable|date_format:H:i',
            'notes' => 'nullable|string',
        ]);

        // Calculate hours worked if both clock_in and clock_out are provided
        $hoursWorked = 0;
        if ($request->clock_in && $request->clock_out) {
            $clockIn = Carbon::createFromFormat('H:i', $request->clock_in);
            $clockOut = Carbon::createFromFormat('H:i', $request->clock_out);
            $diffInMinutes = $clockOut->diffInMinutes($clockIn);
            $hoursWorked = $diffInMinutes / 60; // Convert minutes to hours
        }

        // Create the Attendance record with calculated hours worked
        Attendance::create([
            'employee_id' => $request->employee_id,
            'date' => $request->date,
            'clock_in' => $request->clock_in,
            'clock_out' => $request->clock_out,
            'hours_worked' => $hoursWorked,
            'notes' => $request->notes,
        ]);

        return redirect()->back()->with('success', 'Attendance record added successfully.');
    }


    public function import(Request $request)
    {
        $request->validate([
            'file' => 'required|mimes:xlsx,xls',
        ]);

        try {
            // Import the file
            Excel::import(new AttendanceImport, $request->file('file'), 'local', \Maatwebsite\Excel\Excel::XLSX);
            return redirect()->back()->with('success', 'Users imported successfully.');
        } catch (\Exception $e) {
            // Log the error message
            Log::error('Import failed: ' . $e->getMessage());
            return redirect()->back()->with('error', 'Failed to import users.');
        }
    }


    public function update(Request $request, Attendance $attendance)
    {
        $request->validate([
            'employee_id' => 'required|exists:employees,id',
            'date' => 'required|string',
            'clock_in' => 'required|string',
            'clock_out' => 'nullable|string',
            'notes' => 'nullable|string',
        ]);

        $attendance->update($request->only([
            'employee_id',
            'date',
            'clock_in',
            'clock_out',
            'notes',
        ]));

        return redirect()->back()->with('success', 'Attendance record updated successfully.');
    }

    public function destroy(Attendance $attendance)
    {
        $attendance->delete();

        return redirect()->back()->with('success', 'Attendance record deleted successfully.');
    }
}
