<?php

namespace App\Http\Controllers;

use App\Models\AdditionalFee;
use Illuminate\Http\Request;
use App\Models\BillingStatement;
use App\Models\Lease;
use App\Models\Payment;
use App\Models\NewPayment;
use Yajra\DataTables\Facades\DataTables;
use Carbon\Carbon;
use Matrix\Operators\Addition;

class BillingStatementController extends Controller
{
    public function index(Request $request)
    {

        $billingStatement = BillingStatement::with('lease')->get();
        $lease = Lease::with('client')->get();
        if ($request->ajax()) {
            $data = BillingStatement::with('lease')
                ->leftJoin('lease', 'billingstatements.lease_id', '=', 'lease.lease_id')
                ->leftJoin('clients', 'clients.client_id', '=', 'lease.client_id')
                ->select(
                    'billingstatements.billingstatement_id',
                    'billingstatements.lease_id',
                    'billingstatements.billing_date',
                    'billingstatements.due_date',
                    'billingstatements.start_date',
                    'billingstatements.end_date',
                    'clients.owners_name'
                )
                ->get();

            return DataTables::of($data)
                ->addColumn('date_range', function ($row) {
                    $startDate = Carbon::parse($row->start_date)->format('F j, Y');
                    $endDate = Carbon::parse($row->end_date)->format('F j, Y');
                    return $startDate . ' - ' . $endDate;
                })
                ->addColumn('actions', function ($row) {
                    return '<a href="' . url('/statementform', $row->lease_id) . '" class="px-2 py-1 font-bold text-white bg-blue-500 rounded hover:bg-blue-700">View</a>
                            <button onclick="openModaldelete(\'deleteModal' . $row->billingstatement_id . '\')" class="px-2 py-1 font-bold text-white bg-red-500 rounded hover:bg-red-700">Delete</button>';
                })
                ->rawColumns(['actions'])
                ->make(true);
        }



        return view('CMS.Payment.billingstatement', compact('billingStatement', 'lease'));
    }

    public function statementofaccount($id)
    {
        // $data = BillingStatement::with(['lease.client'])
        //     ->select(
        //         'billingstatements.billingstatement_id',
        //         'billingstatements.lease_id',
        //         'billingstatements.billing_date',
        //         'billingstatements.due_date',
        //         'billingstatements.start_date',
        //         'billingstatements.end_date'
        //     )
        //     ->leftJoin('lease', 'billingstatements.lease_id', '=', 'lease.lease_id')
        //     ->where('billingstatements.lease_id', $id)
        //     ->first();

        $data = Lease::with(['property', 'client', 'unit', 'payments', 'newpayments', 'payments.electricpayments', 'payments.waterpayments'])
            ->findOrFail($id);


        return view('CMS.Payment.statementform', compact('data'));
    }
    public function forclosure($id)
    {

        $data = Payment::with('electricPayments', 'waterPayments', 'lease.client.property')->findOrFail($id);

        return view('CMS.Payment.statementform', compact('data'));
    }

    // public function forclosure($id)
    // {
    //     $data = Payment::with('electricPayments', 'waterPayments', 'lease.client.property')->findOrFail($id);

    //     Calculate total electric bill amount
    //     $totalElectricAmount = 0;
    //     foreach ($data->electricPayments as $electricPayment) {
    //         $totalElectricAmount += $electricPayment->amount;
    //     }

    //     Calculate total water bill amount
    //     $totalWaterAmount = 0;
    //     foreach ($data->waterPayments as $waterPayment) {
    //         $totalWaterAmount += $waterPayment->amount;
    //     }

    //     Calculate grand total
    //     $grandTotal = $data->Amount + $totalElectricAmount + $totalWaterAmount;

    //     return view('CMS.Payment.statementform', compact('data', 'totalElectricAmount', 'totalWaterAmount', 'grandTotal'));
    // }



    public function soa($id, $paymentId)
    {
        $data = Payment::with('electricPayments', 'waterPayments', 'lease.unit.property', 'lease.client', 'additionalFees')
            ->findOrFail($paymentId);

        // Calculate total amounts
        $totalElectricAmount = $data->electricPayments->sum('amount');
        $totalWaterAmount = $data->waterPayments->sum('amount');
        $additional = $data->additionalFees->sum('amount');

        $Amount = $data->Amount;

        // Retrieve new payments and fees
        $newPayments = NewPayment::where('payment_id', $paymentId)->get();
        $fees = AdditionalFee::where('billing_id', $paymentId)->get();
        $previousRentalAmount = $newPayments->sum('rental_amount');
        $previousWaterAmount = $newPayments->sum('waterbill_amount');
        $previousElectricAmount = $newPayments->sum('electricbill_amount');
        $advance_payment = $newPayments->sum('advance_payment');
        $previousAdditional = $fees->sum('amount_paid');
        $Amountpaid = $previousRentalAmount + $previousWaterAmount + $previousElectricAmount + $previousAdditional;

        $lease = $data->lease;
        $currentDate = $data->payment_date;
        $leaseStartDate = $lease->lease_start_date;
        $yearlyEscalationPercentage = $lease->yearly_escalation; // Assuming this is a percentage (e.g., 5 for 5%)

        // Convert percentage to decimal
        $yearlyEscalationRate = $yearlyEscalationPercentage / 100;

        // Calculate escalation amount if applicable
        $yearsPassed = $currentDate->diffInYears($leaseStartDate);
        if ($yearsPassed >= 1) {
            $escalationAmount = $Amount * $yearlyEscalationRate;
            $Amount += $escalationAmount;
        }

        $client = $data->lease->client;
        $isVat = $client->vat === 'vat';
        $hasWithholdingTax = $client->w_holding_tax === 'true';

        $vat = 0;
        $withholdingTax = 0;
        $grandTotal = $Amount + $totalElectricAmount + $totalWaterAmount + $additional;

        if ($isVat) {
            $vat = $grandTotal * 0.12; // 12% VAT
        }
        if ($hasWithholdingTax) {
            $withholdingTax = $grandTotal * 0.05; // 5% Withholding Tax
        }

        $totalMonthlyRental = $grandTotal + $vat - $withholdingTax;

        $currentRentalBalance = $totalMonthlyRental - $Amountpaid;

        $leaseTerms = $data->lease->terms;
        $paymentDate = Carbon::parse($data->payment_date);
        $dueDate = $paymentDate->copy()->addDays($leaseTerms);



        $data->save();

        // Return the view with all the necessary data
        return view('CMS.Payment.forclosure', [
            'data' => $data,
            'advance_payment' => $advance_payment,
            'totalElectricAmount' => $totalElectricAmount,
            'totalWaterAmount' => $totalWaterAmount,
            'additional' => $additional,
            'grandTotal' => $grandTotal,
            'previousRentalAmount' => $previousRentalAmount,
            'previousWaterAmount' => $previousWaterAmount,
            'previousElectricAmount' => $previousElectricAmount,
            'previousAdditional' => $previousAdditional,
            'Amountpaid' => $Amountpaid,
            'Amount' => $Amount,
            'dueDate' => $dueDate->format('F j, Y'), // Format due date for display in the view
            'currentRentalBalance' => $currentRentalBalance,
            'vat' => $vat,
            'withholdingTax' => $withholdingTax,
            'totalMonthlyRental' => number_format($totalMonthlyRental, 2),
        ]);
    }




    public function demandletter($lease_id)
    {
        // Get the current date
        $currentDate = now();
        $startDate = $currentDate->copy()->subDays(60);
        $endDate = $currentDate->copy()->subDays(31);

        // Fetch the lease with related data
        $lease = Lease::with([
            'property',
            'unit',
            'client',
            'payments' => function ($query) use ($startDate, $endDate) {
                $query->whereBetween('payment_date', [$startDate, $endDate])
                    ->where('status', 'Unpaid');
            },
            'payments.electricPayments',
            'payments.waterPayments',
            'payments.additionalFees'
        ])->findOrFail($lease_id);

        return view('CMS.Letter.demand', [
            'lease' => $lease,
            'payments' => $lease->payments,
            'client' => $lease->client,
            'property' => $lease->property,
            'unit' => $lease->unit
        ]);
    }

    public function forclosurenotice($lease_id)
    {
        // Get the current date
        $currentDate = now();

        // Define the date ranges
        $startDateFor61to90Days = $currentDate->copy()->subDays(90);
        $endDateFor61to90Days = $currentDate->copy()->subDays(61);

        // Fetch the lease with related data
        $lease = Lease::with([
            'property',
            'unit',
            'client',
            'payments' => function ($query) use ($startDateFor61to90Days, $endDateFor61to90Days) {
                $query->where(function ($query) use ($startDateFor61to90Days, $endDateFor61to90Days) {
                    $query->whereBetween('payment_date', [$startDateFor61to90Days, $endDateFor61to90Days])
                        ->orWhere('payment_date', '<', $startDateFor61to90Days);
                })
                    ->where('status', 'Unpaid');
            },
            'payments.electricPayments',
            'payments.waterPayments',
            'payments.additionalFees'
        ])->findOrFail($lease_id);

        return view('CMS.Letter.forclosure', [
            'lease' => $lease,
            'payments' => $lease->payments,
            'client' => $lease->client,
            'property' => $lease->property,
            'unit' => $lease->unit
        ]);
    }
    public function invoice($id, $paymentId)
    {
        $data = Payment::with('electricPayments', 'waterPayments', 'lease.unit.property', 'lease.client', 'additionalFees')
            ->findOrFail($paymentId);

        // Calculate total amounts
        $totalElectricAmount = $data->electricPayments->sum('amount');
        $totalWaterAmount = $data->waterPayments->sum('amount');
        $additional = $data->additionalFees->sum('amount');

        $Amount = $data->Amount;

        // Retrieve new payments and fees
        $newPayments = NewPayment::where('payment_id', $paymentId)->get();
        $fees = AdditionalFee::where('billing_id', $paymentId)->get();
        $previousRentalAmount = $newPayments->sum('rental_amount');
        $previousWaterAmount = $newPayments->sum('waterbill_amount');
        $previousElectricAmount = $newPayments->sum('electricbill_amount');
        $advance_payment = $newPayments->sum('advance_payment');
        $previousAdditional = $fees->sum('amount_paid');
        $Amountpaid = $previousRentalAmount + $previousWaterAmount + $previousElectricAmount + $previousAdditional;

        $lease = $data->lease;
        $currentDate = $data->payment_date;
        $leaseStartDate = $lease->lease_start_date;
        $yearlyEscalationPercentage = $lease->yearly_escalation; // Assuming this is a percentage (e.g., 5 for 5%)

        // Convert percentage to decimal
        $yearlyEscalationRate = $yearlyEscalationPercentage / 100;

        // Calculate escalation amount if applicable
        $yearsPassed = $currentDate->diffInYears($leaseStartDate);
        if ($yearsPassed >= 1) {
            $escalationAmount = $Amount * $yearlyEscalationRate;
            $Amount += $escalationAmount;
        }

        $client = $data->lease->client;
        $isVat = $client->vat === 'vat';
        $hasWithholdingTax = $client->w_holding_tax === 'true';

        $vat = 0;
        $withholdingTax = 0;
        $grandTotal = $Amount + $totalElectricAmount + $totalWaterAmount + $additional;

        if ($isVat) {
            $vat = $grandTotal * 0.12; // 12% VAT
        }
        if ($hasWithholdingTax) {
            $withholdingTax = $grandTotal * 0.05; // 5% Withholding Tax
        }

        $totalMonthlyRental = $grandTotal + $vat - $withholdingTax;

        $currentRentalBalance = $totalMonthlyRental - $Amountpaid;

        $leaseTerms = $data->lease->terms;
        $paymentDate = Carbon::parse($data->payment_date);
        $dueDate = $paymentDate->copy()->addDays($leaseTerms);



        $data->save();

        // Return the view with all the necessary data
        return view('CMS.Letter.invoice', [
            'data' => $data,
            'advance_payment' => $advance_payment,
            'totalElectricAmount' => $totalElectricAmount,
            'totalWaterAmount' => $totalWaterAmount,
            'additional' => $additional,
            'grandTotal' => $grandTotal,
            'previousRentalAmount' => $previousRentalAmount,
            'previousWaterAmount' => $previousWaterAmount,
            'previousElectricAmount' => $previousElectricAmount,
            'previousAdditional' => $previousAdditional,
            'Amountpaid' => $Amountpaid,
            'Amount' => $Amount,
            'dueDate' => $dueDate->format('F j, Y'), // Format due date for display in the view
            'currentRentalBalance' => $currentRentalBalance,
            'vat' => $vat,
            'withholdingTax' => $withholdingTax,
            'totalMonthlyRental' => number_format($totalMonthlyRental, 2),
        ]);
    }

    // public function forclosure($id)
    // {
    //     $data = Payment::with('electricPayments', 'waterPayments', 'lease.client.property')->findOrFail($id);

    //     $totalElectricAmount = $data->electricPayments->sum('amount');
    //     $totalWaterAmount = $data->waterPayments->sum('amount');

    //     $grandTotal = $data->amount + $totalElectricAmount + $totalWaterAmount;

    //     $newPayments = NewPayment::where('payment_id', $id)->get();

    //     $previousRentalAmount = $newPayments->sum('rental_amount');
    //     $previousWaterAmount = $newPayments->sum('waterbill_amount');
    //     $previousElectricAmount = $newPayments->sum('electricbill_amount');

    //     // Calculate combined previous balance
    //     $previousBalance = $previousRentalAmount + $previousWaterAmount + $previousElectricAmount;

    //     return view('CMS.Payment.forclosure', compact(
    //         'data',
    //         'totalElectricAmount',
    //         'totalWaterAmount',
    //         'grandTotal',
    //         'previousRentalAmount',
    //         'previousWaterAmount',
    //         'previousElectricAmount',
    //         'previousBalance', // Include previous balance
    //         'rentalBalance',
    //         'waterBalance',
    //         'electricBalance'
    //     ));
    // }


    public function store(Request $request)
    {
        $validatedData = $request->validate([
            'lease_id' => 'required|exists:lease,lease_id',
            'billing_date' => 'required|date',
            'due_date' => 'required|date',
            'start_date' => 'nullable|date',
            'end_date' => 'nullable|date',
        ]);

        BillingStatement::create($validatedData);

        return redirect()->route('billing-statements.index')
            ->with('success', 'Billing statement created successfully.');
    }

    public function deletebillingstatement($id)
    {
        // Find payment by ID and delete
        $payment = BillingStatement::findOrFail($id);
        $payment->delete();

        return redirect()->back()->with('success', 'Billing Statement deleted successfully.');
    }
}
