<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;

use App\Models\Client;
use Illuminate\Support\Facades\DB;
use App\Models\Unit;
use App\Models\Lease;
use App\Models\Property;
use App\Models\User;
use App\Models\AuditLog;
use Yajra\DataTables\Facades\DataTables;
use App\Models\NewPayment;
use App\Models\Payment;
use Carbon\Carbon;
use App\Exports\UsersExport;
use Maatwebsite\Excel\Facades\Excel;

use Illuminate\Support\Facades\Hash;

class ClientController extends Controller
{


    public function index()
    {
        if (request()->ajax()) {
            $clients = Client::with('user')->get();
            return DataTables::of($clients)
                ->addColumn('billing', function ($client) {
                    return '<a href="' . url('/clients-billing-soa/' . $client->client_id) . '"  class="px-4 py-2 mb-2 font-bold text-white bg-blue-500 rounded hover:bg-blue-700">View Details</a>';
                })
                ->addColumn('actions', function ($client) {
                    return '<button onclick="openModal(\'editUnitModal' . $client->client_id . '\')" class="px-2 py-1 font-bold text-white bg-blue-500 rounded hover:bg-blue-700">Edit</button>
                            <button onclick="openModal(\'deleteModal' . $client->client_id . '\')" class="px-2 py-1 font-bold text-white bg-red-500 rounded hover:bg-red-700">Delete</button>';
                })
                ->rawColumns(['billing', 'actions'])
                ->toJson();
        }

        $clients = Client::with('user')->get();
        return view('CMS.Client.client', compact('clients'));
    }


    public function clientsoa($id)
    {
        $clientmain = Client::findOrFail($id);
        $alllease = Lease::where('client_id', $id)->get();

        // Assuming $table is received in the request or defined elsewhere
        $table = request()->get('table');

        // Load data based on $table value
        if ($table === 'newPayments') {
            $newpayments = NewPayment::with('payment')
                ->whereHas('payment.lease', function ($query) use ($id) {
                    $query->where('client_id', $id);
                })
                ->orderBy('created_at', 'desc')
                ->get();

            return DataTables::of($newpayments)
                ->addColumn('payment_id', function ($newPayment) {
                    return 'Soa ' . $newPayment->payment_id;
                })
                ->addColumn('newpayment_id', function ($newPayment) {
                    return 'Ref.' . $newPayment->newpayment_id;
                })
                ->addColumn('payment_method', function ($newPayment) {
                    return $newPayment->payment_method;
                })
                ->addColumn('bank', function ($newPayment) {
                    return $newPayment->bank;
                })
                ->addColumn('rental_amount', function ($newPayment) {
                    return number_format($newPayment->rental_amount, 2);
                })
                ->addColumn('waterbill_amount', function ($newPayment) {
                    return number_format($newPayment->waterbill_amount, 2);
                })
                ->addColumn('electricbill_amount', function ($newPayment) {
                    return number_format($newPayment->electricbill_amount, 2);
                })
                ->addColumn('status', function ($newPayment) {
                    return $newPayment->status;
                })
                ->addColumn('actions', function ($newPayment) {
                    return '<button onclick="openModal(\'deleteModal' . $newPayment->newpayment_id . '\')" class="px-2 py-1 font-bold text-white bg-red-500 rounded hover:bg-red-700">Delete</button>';
                })
                ->rawColumns(['actions'])
                ->make(true);
        } elseif ($table === 'contractsTable') {
            $lease = Lease::with('client', 'unit.property', 'payments')
                ->where('client_id', $id)
                ->get();

            return DataTables::of($lease)
                ->addColumn('property_name', function ($lease) {
                    $property = $lease->unit->property;
                    $propertyName = $property->property_name ?? 'N/A';
                    $streetAddress = $property->street_address ?? 'N/A';
                    $city = $property->city ?? 'N/A';
                    $state = $property->state ?? 'N/A';
                    $zip = $property->zip ?? 'N/A';

                    return "{$propertyName} {$streetAddress}, {$city}, {$state} {$zip}";
                })

                ->addColumn('address', function ($lease) {
                    // Retrieve the address parts from the related property
                    $streetAddress = $lease->unit->property->street_address ?? 'N/A';
                    $city = $lease->unit->property->city ?? 'N/A';
                    $state = $lease->unit->property->state ?? 'N/A';
                    $zip = $lease->unit->property->zip ?? 'N/A';

                    // Combine the address parts into a single string
                    return "{$streetAddress}, {$city}, {$state} {$zip}";
                })

                ->addColumn('unit_name', function ($lease) {
                    return $lease->unit->unit_name ?? 'N/A';
                })
                ->addColumn('lease_end_date', function ($lease) {
                    return \Carbon\Carbon::parse($lease->lease_start_date)
                        ->addMonths($lease->contract_type === 'Monthly' ? $lease->lease_duration : 0)
                        ->addWeeks($lease->contract_type === 'Weekly' ? $lease->lease_duration : 0)
                        ->addDays($lease->contract_type === 'Daily' ? $lease->lease_duration : 0)
                        ->format('F j, Y');
                })
                ->addColumn('lease_start_date', function ($lease) {
                    return \Carbon\Carbon::parse($lease->lease_start_date)->format('F j, Y');
                })

                ->addColumn('lease_status', function ($lease) {
                    return $lease->status;
                })
                ->addColumn('lease_actions', function ($lease) {
                    return '
                    <button onclick="openModal(\'viewModal' . $lease->lease_id . '\')" class="px-2 py-1 font-bold text-white bg-blue-500 rounded hover:bg-blue-700">View</button>
                    <button onclick="openModal(\'editItemModal' . $lease->lease_id . '\')" class="px-2 py-1 font-bold text-white bg-blue-500 rounded hover:bg-blue-700">Edit</button>
                    <button onclick="openModal(\'cancelModal' . $lease->lease_id . '\')" class="px-2 py-1 font-bold text-white bg-red-500 rounded hover:bg-red-700">Cancel</button>';
                })
                ->rawColumns(['lease_actions'])
                ->make(true);
        } elseif ($table === 'payments') {
            $payments = Payment::with(['lease.property', 'lease.unit'])
                ->whereHas('lease', function ($query) use ($id) {
                    $query->where('client_id', $id);
                })

                ->orderBy('payment_date', 'desc')
                ->get();

            return DataTables::of($payments)
                ->addColumn('payment_id', function ($payment) {
                    return 'Billing No. ' . $payment->payment_id;
                })
                ->addColumn('payment_schedule', function ($payment) {
                    return Carbon::parse($payment->payment_date)->format('F j, Y');
                })
                ->addColumn('due_date', function ($payment) {
                    return Carbon::parse($payment->payment_date)->addDays($payment->lease->terms)->format('F j, Y');
                })
                ->addColumn('amount', function ($payment) {
                    return number_format($payment->Amount, 2);
                })
                ->addColumn('status', function ($payment) {
                    return $payment->status;
                })
                ->addColumn('Action', function ($payment) {
                    return '<a href="' . url('/soa', [$payment->lease_id, $payment->payment_id]) . '" class="px-2 py-1 font-bold text-white bg-blue-500 rounded hover:bg-blue-700">View</a>
                            <button onclick="openModal(\'deleteModal' . $payment->payment_id . '\')" class="px-2 py-1 font-bold text-white bg-red-500 rounded hover:bg-red-700">Delete</button>';
                })
                ->rawColumns(['Action'])
                ->toJson();
        }
        $newpayments = NewPayment::all();
        $payments = Payment::all();



        $payment1 = Payment::with(['lease.property', 'lease.unit'])
            ->whereHas('lease', function ($query) use ($id) {
                $query->where('client_id', $id);
            })
            ->whereIn('status', ['Unpaid', 'Partial Payment'])
            ->orderBy('payment_date', 'asc')
            ->get();



        $lease = Lease::with('client', 'property', 'unit', 'payments')

            ->get();
        $editclients = Client::all();
        $editclients = Client::all();
        // Return view for non-AJAX requests
        return view('CMS.Client.clientbillingsoa', compact('clientmain', 'alllease', 'newpayments', 'payment1', 'payments', 'lease', 'editclients'));
    }





    public function clientdata()
    {
        $userId = auth()->id(); // Get the ID of the authenticated user


        $leases = Lease::whereHas('client.user', function ($query) use ($userId) {
            $query->where('id', $userId);
        })->with('client', 'property', 'unit')->get();

        return view('ClientCMS.client', compact('leases'));
    }


    public function showPaymentForm()
    {
        return view('ClientCMS.client');
    }

    public function redirectToPaymentLink(Request $request)
    {
        // Generate or retrieve the payment link from Paymongo dashboard
        $paymentLink = 'https://paymongo.com/link/to/your/payment';

        // Redirect user to the payment link
        return redirect()->away($paymentLink);
    }


    public function store(Request $request)
    {
        // Validate the request
        $validatedData = $request->validate([
            'business_name' => 'required|string|max:255',
            'business_type' => 'required|string|max:255',
            'home_address' => 'required|string|max:255',
            'owners_name' => 'required|string|max:255',
            'id_type' => 'required|string|max:255',
            'id_no' => 'required|string|max:255|unique:clients,id_no',
            'contact_no' => 'required|string|max:20',
            'phone_no' => 'nullable|string|max:20',
            'vat' => 'required|string|max:20',
            'withholding_tax' => 'nullable|string|max:100',
            'email' => 'nullable|string|max:100',
        ]);

        try {
            // Create the client
            $client = Client::create([
                'business_name' => $validatedData['business_name'],
                'business_type' => $validatedData['business_type'],
                'home_address' => $validatedData['home_address'],
                'owners_name' => $validatedData['owners_name'],
                'id_type' => $validatedData['id_type'],
                'id_no' => $validatedData['id_no'],
                'contact_no' => $validatedData['contact_no'],
                'phone_no' => $validatedData['phone_no'],
                'vat' => $validatedData['vat'],
                'w_holding_tax' => $validatedData['withholding_tax'],
                'email' => $validatedData['email'],
            ]);

            // Log the action in the audit log
            AuditLog::create([
                'user_id' => auth()->id(), // Assuming you are using authentication
                'action' => 'Create Client',
                'details' => 'Created client with ID: ' . $client->client_id . ' - ' . $client->business_name,
            ]);

            // Redirect back with success message
            return redirect()->back()->with('success', 'Client created successfully.');
        } catch (\Exception $e) {
            // Handle any exceptions, such as database errors
            return redirect()->back()->withErrors(['error' => 'Failed to create client. Please try again.'])->withInput();
        }
    }



    public function update(Request $request, $client_id)
    {
        // Validate the request
        $validatedData = $request->validate([
            'business_name' => 'required|string|max:255',
            'business_type' => 'required|string|max:255',
            'home_address' => 'required|string|max:255',
            'owners_name' => 'required|string|max:255',
            'id_type' => 'required|string|max:255',
            'id_no' => 'nullable|string|max:100',
            'contact_no' => 'required|string|max:20',
            'phone_no' => 'nullable|string|max:20',
            'vat' => 'required|string|max:20',
            'withholding_tax' => 'nullable|string|max:100',
            'email' => 'nullable|string|max:100',
        ]);

        try {
            // Find the client
            $client = Client::where('client_id', $client_id);

            // Update the client
            $client->update([
                'business_name' => $validatedData['business_name'],
                'business_type' => $validatedData['business_type'],
                'home_address' => $validatedData['home_address'],
                'owners_name' => $validatedData['owners_name'],
                'id_type' => $validatedData['id_type'],
                'id_no' => $validatedData['id_no'],
                'contact_no' => $validatedData['contact_no'],
                'phone_no' => $validatedData['phone_no'],
                'vat' => $validatedData['vat'],
                'w_holding_tax' => $validatedData['withholding_tax'],
                'email' => $validatedData['email'],
            ]);

            // Log the action in the audit log
            AuditLog::create([
                'user_id' => auth()->id(), // Assuming you are using authentication
                'action' => 'Update Client',
                'details' => 'Updated client with ID: ' . $client->client_id . ' - ' . $client->business_name,
            ]);

            // Redirect back with success message
            return redirect()->back()->with('success', 'Client updated successfully.');
        } catch (\Exception $e) {
            // Handle any exceptions, such as database errors
            return redirect()->back()->withErrors(['error' => 'Failed to update client. Please try again.'])->withInput();
        }
    }

    public function delete($id)
    {
        try {
            $client = Client::where('client_id', $id);
            $client->delete();

            return redirect()->back()->with('success', 'Client deleted successfully.');
        } catch (\Exception $e) {
            return redirect()->back()->with('error', 'Cannot delete Client. There are related records in other tables.');
        }
    }

    public function filterExport()
    {
        $tenants = Client::all(); // Fetch all tenants, adjust as per your Client model

        // Implement filtering logic if needed (example: filtering by business name)
        $filteredTenants = request()->has('business_name')
            ? Client::where('business_name', 'like', '%' . request('business_name') . '%')->get()
            : $tenants;

        // Implement export logic here (e.g., exporting to CSV or Excel)
        // Example: CSV Export
        if (request()->has('export')) {
            $headers = [
                'Content-Type' => 'text/csv',
                'Content-Disposition' => 'attachment; filename="tenants.csv"',
            ];

            $callback = function () use ($filteredTenants) {
                $file = fopen('php://output', 'w');

                // Headers
                fputcsv($file, ['Business Name', 'Owner\'s Name', 'TIN No.', 'Contact No.', 'Phone No.']);

                // Data
                foreach ($filteredTenants as $tenant) {
                    fputcsv($file, [
                        $tenant->business_name,
                        $tenant->owners_name,
                        $tenant->tin_no,
                        $tenant->contact_no,
                        $tenant->phone_no,
                    ]);
                }

                fclose($file);
            };

            return response()->stream($callback, 200, $headers);
        }

        return view('tenants.filter-export', compact('filteredTenants'));
    }

    public function exportClients()
    {
        return Excel::download(new UsersExport, 'clients.xlsx', \Maatwebsite\Excel\Excel::XLSX);
    }
}
