<?php

namespace App\Http\Controllers;

use App\Models\Client;
use App\Models\Unit;
use App\Models\Payment;
use Carbon\Carbon; // Make sure to import Carbon for date manipulation
use Illuminate\Http\Request;

class DashboardController extends Controller
{
    public function index()
    {
        // Total tenants
        $totalTenants = Client::count();

        // Total receivables
        $totalReceivables = Payment::where('status', 'Unpaid')->sum('Amount');

        // Total vacant and occupied units
        $totalVacantUnits = Unit::where('status', 'Vacant')->count();
        $totalOccupiedUnits = Unit::where('status', 'Occupied')->count();

        // Overdue payments
        $currentDate = Carbon::now();
        $startDateForDemandLetter = $currentDate->copy()->subDays(60);
        $endDateForDemandLetter = $currentDate->copy()->subDays(31);

        $overduePayments = Payment::where('status', 'Unpaid')
            ->whereBetween('payment_date', [$startDateForDemandLetter, $endDateForDemandLetter])
            ->with('lease.client') // Ensure you load the client relationship
            ->get();

        // For foreclosure notices
        $startDateForForeclosure = $currentDate->copy()->subDays(90);
        $endDateForForeclosure = $currentDate->copy()->subDays(61);

        $foreclosurePayments = Payment::where('status', 'Unpaid')
            ->where(function ($query) use ($startDateForForeclosure, $endDateForForeclosure) {
                $query->whereBetween('payment_date', [$startDateForForeclosure, $endDateForForeclosure])
                    ->orWhere('payment_date', '<', $startDateForForeclosure);
            })
            ->with('lease.client') // Ensure you load the client relationship
            ->get();

        return view('welcome', compact(
            'totalTenants',
            'totalReceivables',
            'totalVacantUnits',
            'totalOccupiedUnits',
            'overduePayments',
            'foreclosurePayments'
        ));
    }
}
