<?php

namespace App\Http\Controllers;

use App\Models\Deduction;
use App\Models\Employee;
use Illuminate\Http\Request;

class DeductionController extends Controller
{
    public function index()
    {
        $deductions = Deduction::with('employee')->get();
        $employees = Employee::all();
        return view('CMS.Payroll.deductions', compact('deductions', 'employees'));
    }


    public function store(Request $request)
    {
        $request->validate([
            'employee_id' => 'required|exists:employees,id',
            'benefit_name' => 'required|string',
            'date' => 'required|string',
            'amount' => 'required|numeric',
        ]);

        Deduction::create($request->all());
        return redirect()->back()->with('success', 'Deduction created successfully.');
    }


    public function show(Deduction $deduction)
    {
        return view('deductions.show', compact('deduction'));
    }

    public function edit(Deduction $deduction)
    {
        $employees = Employee::all();
        return view('deductions.edit', compact('deduction', 'employees'));
    }

    public function update(Request $request, Deduction $deduction)
    {
        $request->validate([
            'employee_id' => 'required|exists:employees,id',
            'benefit_name' => 'required|string',
            'amount' => 'required|numeric',
        ]);

        $deduction->update($request->all());
        return redirect()->route('deductions.index')->with('success', 'Deduction updated successfully.');
    }

    public function destroy(Deduction $deduction)
    {
        $deduction->delete();
        return redirect()->route('deductions.index')->with('success', 'Deduction deleted successfully.');
    }
}
