<?php

namespace App\Http\Controllers;

use App\Models\Earning;
use App\Models\Employee;
use Illuminate\Http\Request;
use Yajra\DataTables\Facades\DataTables;

class EarningController extends Controller
{


    public function index()
    {
        // Retrieve earnings with eager loading of 'employee' relation
        $earnings = Earning::with('employee')->get();

        if (request()->ajax()) {
            // Prepare DataTables response
            return DataTables::of($earnings)
                ->addColumn('employee_name', function ($earning) {
                    return $earning->employee->complete_name;
                })
                ->addColumn('actions', function ($earning) {
                    return '<button class="px-4 py-2 font-bold text-white bg-green-500 rounded hover:bg-green-700"
                                onclick="openModal(\'editModal\', ' . $earning->id . ')">Edit</button>
                            <button class="px-4 py-2 font-bold text-white bg-red-500 rounded hover:bg-red-700"
                                onclick="openModal(\'deleteModal\', ' . $earning->id . ')">Delete</button>';
                })
                ->rawColumns(['actions'])
                ->make(true);
        }

        // Fetch all employees to pass to the view
        $employees = Employee::all();

        // Return view with earnings and employees data
        return view('CMS.Payroll.earnings', compact('employees', 'earnings'));
    }



    public function store(Request $request)
    {
        $request->validate([
            'employee_id' => 'required|exists:employees,id',
            'totaldays' => 'required|numeric',
            'bonus' => 'nullable',
            'gross_earnings' => 'required|numeric',
            'notes' => 'nullable',
        ]);
        Earning::create([
            'employee_id' => $request->employee_id,
            'totaldays' => $request->totaldays,
            'bonus' => $request->bonus,
            'gross_earnings' => $request->gross_earnings,
            'status' => 'To Pay', // Set the status to a default value like 'active'
            'notes' => $request->notes,
        ]);
        return redirect()->back()->with('success', 'Earning created successfully.');
    }



    public function update(Request $request, Earning $earning)
    {
        $request->validate([
            'employee_id' => 'required|exists:employees,id',
            'totaldays' => 'required|numeric',
            'bonus' => 'numeric',
            'gross_earnings' => 'required|numeric',

        ]);

        $earning->update($request->all());
        return redirect()->back()->with('success', 'Earning updated successfully.');
    }

    public function destroy(Earning $earning)
    {
        $earning->delete();
        return redirect()->back()->with('success', 'Earning deleted successfully.');
    }
}
