<?php

namespace App\Http\Controllers;

use Yajra\DataTables\Facades\DataTables;
use App\Models\Employee;
use App\Models\AuditLog;
use Illuminate\Http\Request;

class EmployeeContorller extends Controller
{
    public function index()
    {
        if (request()->ajax()) {
            $employees = Employee::select('*');

            return DataTables::of($employees)
                ->addColumn('payroll', function ($employee) {
                    return '<a class="px-2 py-1 text-white bg-blue-500 rounded" href="' . url('/employeepayroll/' . $employee->id) . '">View Payroll Details</a>';
                })
                ->addColumn('image', function ($employee) {
                    // Generate the URL for the image
                    $imageUrl = asset('uploads/' . $employee->clearance);
                    return '<img src="' . $imageUrl . '" alt="Clearance" style="max-width: 100px;">';
                })
                ->addColumn('actions', function ($employee) {
                    return '<button class="px-2 py-1 text-white bg-blue-500 rounded"
                            onclick="toggleModal(\'editEmployeeModal' . $employee->id . '\')">Edit</button>
                        <form action="' . route('employees.destroy', $employee->id) . '" method="POST" class="inline">
                            ' . csrf_field() . '
                            ' . method_field('DELETE') . '
                            <button type="submit" class="px-2 py-1 text-white bg-red-500 rounded">Delete</button>
                        </form>';
                })
                ->rawColumns(['payroll', 'actions'])
                ->toJson();
        }
        $employees = Employee::all();
        return view('CMS.Payroll.employee', compact(['employees']));
    }
    public function store(Request $request)
    {
        $validatedData = $request->validate([
            'complete_name' => 'required|string',
            'address' => 'nullable|string',
            'contact_no' => 'required|string',
            'employee_type' => 'required|string|in:Contractual,Permanent,Casual,Temporary',
            'salary_rate' => 'required|numeric',
            'position' => 'nullable|string',
            'date_hired' => 'required|date',
            'clearance' => 'nullable|file|mimes:jpg,png,pdf|max:2048', // Adjust validation as needed
        ]);


        if ($request->hasFile('clearance')) {
            $file = $request->file('clearance');
            $file_name = time() . '.' . $file->getClientOriginalExtension();
            $destination = public_path('uploads');
            $file->move($destination, $file_name);

            // Add the file path to the validated data
            $validatedData['clearance'] =  $file_name;
        } else {
            // Remove the clearance key if no file is uploaded
            unset($validatedData['clearance']);
        }




        // Create the employee with the validated data
        $employee = Employee::create($validatedData);


        AuditLog::create([
            'user_id' => auth()->id(),
            'action' => 'Employee Created',
            'details' => 'Employee ID: ' . $employee->id . ' Employee: ' . $employee->complete_name,
        ]);

        return back()->with('success', 'Employee added successfully.');
    }



    public function update(Request $request, Employee $employee)
    {
        $validatedData = $request->validate([
            'complete_name' => 'required|string',
            'address' => 'nullable|string',
            'salary_rate' => 'required|numeric',
            'position' => 'nullable|string',
            'date_hired' => 'required|date',
        ]);

        $employee->update($validatedData);

        return back()->with('success', 'Employee updated successfully.');
    }

    public function destroy(Employee $employee)
    {
        $employee->delete();
        return back()->with('success', 'Employee deleted successfully.');
    }

    // Additional payroll-related functions can be added here
}
