<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Inventory;
use App\Models\StockInOut;
use App\Models\Consumable;
use Yajra\DataTables\Facades\DataTables;
use Carbon\Carbon;

class InventoryController extends Controller
{
    public function index(Request $request)
    {
        if ($request->ajax()) {
            $table = $request->get('table');

            if ($table === 'item') {
                $inventoryItems = Inventory::all();
                return DataTables::of($inventoryItems)
                    ->addColumn('actions', function ($inventoryItems) {
                        return '<button class="px-4 py-2 font-bold text-white bg-blue-500 rounded hover:bg-blue-700"
                                 onclick="openModal12(\'editModal' . $inventoryItems->id . '\')">Edit</button>
                                <button class="px-4 py-2 font-bold text-white bg-red-500 rounded hover:bg-red-700"
                                onclick="openModal12(\'deleteModal' . $inventoryItems->id . '\')">Delete</button>';
                    })
                    ->rawColumns(['actions'])
                    ->make(true);
            } elseif ($table === 'stocks') {
                $stockInOut = StockInOut::with('inventory')->get();
                return DataTables::of($stockInOut)
                    ->addColumn('actions', function ($stockInOut) {
                        return '<button class="px-4 py-2 font-bold text-white bg-blue-500 rounded hover:bg-blue-700"
                              onclick="openModal12(\'editstockModal\', ' . $stockInOut->id . ')">Edit</button>
                              <button class="px-4 py-2 font-bold text-white bg-red-500 rounded hover:bg-red-700"
                              onclick="openModal12(\'deletestockModal' . $stockInOut->id . '\')">Delete</button>';
                    })
                    ->rawColumns(['actions'])
                    ->make(true);
            } elseif ($table === 'consumables') {
                $consumables = Consumable::all();
                return DataTables::of($consumables)
                    ->addColumn('actions', function ($item) {
                        return '<button class="px-4 py-2 font-bold text-white bg-blue-500 rounded hover:bg-blue-700"
                                      onclick="openModal12(\'editmodalconsume' . $item->id . '\')">Edit</button>
                                      <button class="px-4 py-2 font-bold text-white bg-red-500 rounded hover:bg-red-700"
                                      onclick="openModal12(\'deleteconsumableModal' . $item->id . '\')">Delete</button>';
                    })
                    ->rawColumns(['actions'])
                    ->make(true);
            }
        }
        $inventoryItems = Inventory::all();
        $consumables = Consumable::all();
        $inventoryItems1 = Inventory::all();
        $stockInOut1 = StockInOut::all();
        $stockInOut = StockInOut::with('inventory')->get();

        return view('CMS.inventory.index', compact('inventoryItems', 'inventoryItems1', 'stockInOut1', 'consumables'));
    }

    public function create()
    {
        return view('inventory.create');
    }

    public function store(Request $request)
    {
        $request->validate([
            'category' => 'required|string|max:255',
            'item_name' => 'required|string|max:255',
            'quantity' => 'required|integer',
            'unit' => 'nullable|string|max:255',
        ]);

        Inventory::create($request->all());

        return redirect()->route('inventory.index')->with('success', 'Inventory item added successfully.');
    }
    public function storeconsumables(Request $request)
    {
        // Validate the request data
        $request->validate([
            'name' => 'required|string|max:255',
            'quantity' => 'required|integer|min:1',
            'amount_spent' => 'required|numeric|min:0', // Corrected from 'amount_specnt'
            'date' => 'required|date',
            'notes' => 'nullable|string|max:255',
        ]);

        // Create a new consumable entry
        Consumable::create([
            'name' => $request->input('name'),
            'quantity' => $request->input('quantity'),
            'amount_spent' => $request->input('amount_spent'),
            'date' => $request->input('date'),
            'notes' => $request->input('notes'),
        ]);

        // Redirect back with a success message
        return redirect()->back()->with('success', 'Consumable item added successfully.');
    }

    public function show(Inventory $inventory)
    {
        return view('inventory.show', compact('inventory'));
    }

    public function edit(Inventory $inventory)
    {
        return view('inventory.edit', compact('inventory'));
    }
    public function updateconsumables(Request $request, $id)
    {
        // Validate the request data
        $request->validate([
            'name' => 'required|string|max:255',
            'quantity' => 'required|integer|min:1',
            'amount_spent' => 'required|numeric|min:0',
            'date' => 'required|date',
            'notes' => 'nullable|string|max:255',
        ]);

        // Find the consumable item by ID
        $consumable = Consumable::findOrFail($id);

        // Update the consumable entry
        $consumable->update($request->only([
            'name',
            'quantity',
            'amount_spent',
            'date',
            'notes'
        ]));

        return redirect()->back()->with('success', 'Consumable item added successfully.');
    }
    public function update(Request $request, Inventory $inventory)
    {
        $request->validate([
            'category' => 'required|string|max:255',
            'item_name' => 'required|string|max:255',
            'quantity' => 'required|integer',
            'unit' => 'nullable|string|max:255',
        ]);

        $inventory->update($request->all());

        return redirect()->route('inventory.index')->with('success', 'Inventory item updated successfully.');
    }

    public function destroy($id)
    {
        // Find the inventory item by ID
        $inventory = Inventory::findOrFail($id);

        // Delete the inventory item
        $inventory->delete();

        // Redirect to the inventory index page with a success message
        return redirect()->route('inventory.index')
            ->with('success', 'Inventory item deleted successfully.');
    }

    public function delete($id)
    {

        $inventory = StockInOut::findOrFail($id);


        $inventory->delete();


        return redirect()->route('inventory.index')
            ->with('success', 'item deleted successfully.');
    }
    public function deleteconsumable($id)
    {

        $consumable = Consumable::findOrFail($id);


        $consumable->delete();


        return redirect()->route('inventory.index')
            ->with('success', 'Consumable item deleted successfully.');
    }

    public function stockInOut(Request $request, Inventory $inventory)
    {
        $request->validate([
            'quantity' => 'required|integer',
            'type' => 'required|string|in:in,out',

        ]);

        StockInOut::create([
            'inventory_id' => $inventory->id,
            'quantity' => $request->quantity,
            'type' => $request->type,
            'notes' => $request->notes,
            'date' => $request->date,
        ]);

        if ($request->type == 'in') {
            $inventory->quantity += $request->quantity;
        } else {
            $inventory->quantity -= $request->quantity;
        }

        $inventory->save();

        return redirect()->route('inventory.show', $inventory)->with('success', 'Stock updated successfully.');
    }
    public function storeStockMovement(Request $request)
    {
        // Validate the request
        $request->validate([
            'inventory_id' => 'required|exists:inventory,id',
            'type' => 'required|in:in,out',
            'quantity' => 'required|integer|min:1',
        ]);

        $inventory = Inventory::findOrFail($request->inventory_id);

        // Adjust inventory quantity based on type
        if ($request->type === 'in') {
            $inventory->quantity += $request->quantity;
        } elseif ($request->type === 'out') {
            $inventory->quantity -= $request->quantity;
        }

        // Save updated inventory
        $inventory->save();

        // Create stock movement record
        StockInOut::create($request->all());

        return redirect()->back()->with('success', 'Stock movement recorded successfully.');
    }
}
