<?php

namespace App\Http\Controllers;

use DateTime;
use DateInterval;
use Illuminate\Http\Request;
use App\Models\Client;
use App\Models\Property;
use App\Models\Unit;
use App\Models\lease;
use App\Models\Payment;
use App\Models\AuditLog;
use Illuminate\Support\Facades\DB;
use Yajra\DataTables\Facades\DataTables;
use Illuminate\Support\Facades\Redirect;
use Carbon\Carbon;

class LeaseController extends Controller
{


    public function index($id)
    {

        $clientmain = Lease::with('client', 'property', 'unit', 'payments')
            ->where('unit_id', $id)
            ->orderByRaw("CASE WHEN status = 'Active' THEN 1 ELSE 2 END") // Order by Active status first
            ->orderBy('status', 'asc')
            ->first();

        if (!$clientmain) {
            return Redirect::route('lease.create', ['unit_id' => $id]);
        }


        if (request()->ajax()) {
            $lease = Lease::with('client', 'property', 'unit', 'payments')
                ->where('unit_id', $id)
                ->orderByRaw("CASE WHEN status = 'Active' THEN 1 ELSE 2 END") // Order by Active status first
                ->orderBy('status', 'asc')
                ->get();

            return DataTables::of($lease)
                ->addColumn('client_name', function ($lease) {
                    return $lease->client->owners_name ?? 'N/A'; // Ensure to handle cases where client may not exist
                })
                ->addColumn('lease_start_date', function ($lease) {
                    return $lease->lease_start_date ? Carbon::parse($lease->lease_start_date)->format('F j, Y') : 'N/A';
                })
                ->addColumn('lease_end_date', function ($lease) {
                    return \Carbon\Carbon::parse($lease->lease_start_date)
                        ->addMonths($lease->contract_type === 'Monthly' ? $lease->lease_duration : 0)
                        ->addWeeks($lease->contract_type === 'Weekly' ? $lease->lease_duration : 0)
                        ->addDays($lease->contract_type === 'Daily' ? $lease->lease_duration : 0)
                        ->format('F j, Y');
                })
                ->addColumn('status', function ($lease) {
                    return $lease->status;
                })
                ->addColumn('actions', function ($lease) {
                    return '
                        <button onclick="openviewModal(\'viewModal' . $lease->lease_id . '\')" class="px-2 py-1 font-bold text-white bg-blue-500 rounded hover:bg-blue-700">View</button>
                        <button onclick="openModal1(\'editItemModal' . $lease->lease_id . '\')" class="px-2 py-1 font-bold text-white bg-blue-500 rounded hover:bg-blue-700">Edit</button>
                        <button onclick="opencancelModal(\'cancelModal' . $lease->lease_id . '\')" class="px-2 py-1 font-bold text-white bg-red-500 rounded hover:bg-red-700">Cancel</button>';
                })

                ->rawColumns(['actions'])
                ->make(true);
        }

        // If not AJAX request, return view with necessary data
        $clients = Client::all();
        $editclients = Client::all();
        $properties = Property::all();
        $units = Unit::all();
        $lease = Lease::with('client', 'property', 'unit', 'payments')
            ->where('unit_id', $id)
            ->get();

        return view('CMS.LeaseManagement.lease', compact('clients', 'editclients', 'clientmain', 'properties', 'units', 'lease'));
    }

    public function index1()
    {
        $clients = Client::all();
        $properties = Property::all();
        $units = Unit::all();
        $lease = Lease::all();
        $lease = Lease::with('client', 'property', 'unit', 'payments')->get();
        return view('CMS.LeaseManagement.lease', compact('clients',  'properties', 'units', 'lease'));
    }
    public function getUnitsByProperty($propertyId)
    {
        $units = Unit::where('property_id', $propertyId)
            ->where('status', 'Vacant')
            ->get();

        return response()->json($units);
    }
    public function getUnitDetails($unitId)
    {
        $unit = Unit::where($unitId);

        return response()->json([
            'rate' => $unit->rate,
            'rate_type' => $unit->rate_type,
            'size' => $unit->size,
        ]);
    }

    public function create($unit_id)
    {

        $clientmain = Unit::findOrFail($unit_id);
        $clients = Client::all();


        return view('CMS.leaseManagement.leasepage', compact('clientmain', 'clients'));
    }

    public function store(Request $request)
    {
        // Validate the request data
        $validatedData = $request->validate([
            'property_id' => 'required|exists:properties,id',
            'client_id' => 'required|exists:clients,client_id',
            'unit_id' => 'required|exists:units,unit_id',
            'lease_start_date' => 'required|date',
            'lease_duration' => 'required|numeric|min:1',
            'rate_type' => 'required|in:Daily,Weekly,Monthly',
            'payment_amount' => 'required|numeric|min:0',
            'yearly_escalation' => 'nullable|numeric|min:0',
            'terms' => 'required|numeric|min:1',
            'business_start' => 'nullable|date',
            'relief_rental' => 'nullable|numeric|min:0',
            'security_deposit' => 'nullable|numeric|min:0',
            'utilities' => 'nullable|string',
            'rules_and_regulations' => 'nullable|string',
        ]);

        $unit_id = $request->input('unit_id');

        $startDate = Carbon::parse($request->input('lease_start_date'));
        $leaseEndDate = $startDate->copy()->addDays($request->input('terms')); // Adjust this based on your terms logic

        // Create the new lease
        $lease = Lease::create([
            'property_id' => $request->input('property_id'),
            'client_id' => $request->input('client_id'),
            'unit_id' => $unit_id,
            'lease_start_date' => $startDate->format('Y-m-d'),
            'lease_end_date' => $leaseEndDate->format('Y-m-d'), // Store calculated lease end date
            'lease_duration' => $request->input('lease_duration'),
            'contract_type' => $request->input('rate_type'),
            'utilities' => $request->input('utilities'),
            'rules_and_regulations' => $request->input('rules_and_regulations'),
            'terms' => $request->input('terms'),
            'yearly_escalation' => $request->input('yearly_escalation'),
            'status' => 'Active', // Set the new lease as Active
            'security_deposit' => $request->input('security_deposit'),
            'business_start' => $request->input('business_start'),
            'relief_rental' => $request->input('relief_rental'),
            'rent_amount' => $request->input('payment_amount'),
        ]);

        // Update existing leases for the same unit to 'Inactive'
        Lease::where('unit_id', $unit_id)
            ->where('lease_id', '!=', $lease->lease_id) // Exclude the newly created lease
            ->where('status', '!=', 'Canceled') // Exclude canceled leases
            ->update(['status' => 'Inactive']);

        $unit = Unit::findOrFail($unit_id);

        // Check if it's the first active lease for this unit
        $activeLeasesCount = $unit->leases()->where('status', 'Active')->count();
        if ($activeLeasesCount === 1) {
            $unit->status = 'Occupied';
            $unit->save();
        }

        $paymentAmount = $request->input('payment_amount');

        $paymentSchedule = $this->calculatePaymentSchedule($lease); // Implement your own logic here
        foreach ($paymentSchedule as $paymentDate) {
            Payment::create([
                'lease_id' => $lease->lease_id,
                'payment_date' => $paymentDate,
                'Amount' => $paymentAmount,
                'status' => 'Unpaid',
            ]);
        }

        AuditLog::create([
            'user_id' => auth()->id(), // Assuming authentication is set up
            'action' => 'Lease Created',
            'details' => 'Lease ID: ' . $lease->lease_id . ' created for client ID: ' . $request->input('client_id'),
        ]);

        // Redirect back with success message
        return redirect()->back()->with('success', 'Lease created successfully.');
    }





    private function calculatePaymentSchedule(Lease $lease)
    {
        $paymentDates = [];
        $startDate = new DateTime($lease->lease_start_date);

        switch ($lease->contract_type) {
            case 'Daily':
                $interval = new DateInterval('P1D');
                $duration = $lease->lease_duration;
                for ($i = 0; $i < $duration; $i++) {
                    $paymentDates[] = $startDate->format('Y-m-d');
                    $startDate->add($interval);
                }
                break;
            case 'Weekly':
                $interval = new DateInterval('P1W');
                $duration = $lease->lease_duration;
                for ($i = 0; $i < $duration; $i++) {
                    $paymentDates[] = $startDate->format('Y-m-d');
                    $startDate->add($interval);
                }
                break;
            case 'Monthly':
                $interval = new DateInterval('P1M');
                $duration = $lease->lease_duration;
                for ($i = 0; $i < $duration; $i++) {
                    $paymentDates[] = $startDate->format('Y-m-d');
                    $startDate->add($interval);
                }
                break;
            default:
                // Handle other contract types if needed
                break;
        }

        return $paymentDates;
    }


    public function deletelease($id)
    {
        try {

            DB::table('lease')->where('lease_id', $id)->delete();

            return redirect()->back()->with('success', 'Unit deleted successfully.');
        } catch (\Exception $e) {
            return redirect()->back()->with('error', 'Cannot delete Unit. There are related records in other tables.');
        }
    }
    public function update(Request $request, $leaseId)
    {
        // Validate incoming request data
        $request->validate([
            'property_id' => 'required|exists:properties,id',
            'client_id' => 'required|exists:clients,client_id',
            'unit_id' => 'required|exists:units,unit_id',
            'lease_start_date' => 'required|date',
            'terms' => 'required|integer',
            'lease_duration' => 'required|integer',
            'rate_type' => 'required|string',
            'utilities' => 'nullable|string',
            'rules_and_regulations' => 'nullable|string',
            'yearly_escalation' => 'nullable|string',
            'security_deposit' => 'nullable|numeric',
            'business_start' => 'nullable|date',
            'relief_rental' => 'nullable|numeric',
            'payment_amount' => 'required|numeric',
        ]);

        // Find the lease to update
        $lease = Lease::findOrFail($leaseId);

        // Get the unit ID from the request
        $unit_id = $request->input('unit_id');

        // Calculate the lease end date based on terms
        $startDate = Carbon::parse($request->input('lease_start_date'));
        $leaseEndDate = $startDate->copy()->addDays($request->input('terms'));

        // Update lease details
        $lease->update([
            'property_id' => $request->input('property_id'),
            'client_id' => $request->input('client_id'),
            'unit_id' => $unit_id,
            'lease_start_date' => $startDate->format('Y-m-d'),
            'lease_end_date' => $leaseEndDate->format('Y-m-d'),
            'lease_duration' => $request->input('lease_duration'),
            'contract_type' => $request->input('rate_type'),
            'utilities' => $request->input('utilities'),
            'rules_and_regulations' => $request->input('rules_and_regulations'),
            'terms' => $request->input('terms'),
            'yearly_escalation' => $request->input('yearly_escalation'),
            'status' => 'Active',
            'security_deposit' => $request->input('security_deposit'),
            'business_start' => $request->input('business_start'),
            'relief_rental' => $request->input('relief_rental'),
        ]);

        // Update existing leases for the same unit to 'Inactive' if needed
        Lease::where('unit_id', $unit_id)
            ->where('lease_id', '!=', $lease->lease_id) // Exclude the updated lease
            ->update(['status' => 'Inactive']);

        // Update the unit status based on active leases
        $unit = Unit::findOrFail($unit_id);
        $activeLeasesCount = $unit->leases()->where('status', 'Active')->count();
        $unit->status = ($activeLeasesCount === 1) ? 'Occupied' : 'Available';
        $unit->save();

        // Delete existing unpaid payments for the lease
        Payment::where('lease_id', $lease->lease_id)
            ->where('status', 'Unpaid')
            ->delete();

        // Update the payment records for the lease
        $paymentSchedule = $this->calculatePaymentSchedule($lease);
        foreach ($paymentSchedule as $paymentDate) {
            Payment::create([
                'lease_id' => $lease->lease_id,
                'payment_date' => $paymentDate,
                'Amount' => $request->input('payment_amount'),
                'status' => 'Unpaid',
            ]);
        }

        // Log the update action
        AuditLog::create([
            'user_id' => auth()->id(),
            'action' => 'Lease Updated',
            'details' => 'Lease ID: ' . $lease->lease_id . ' updated for client ID: ' . $request->input('client_id'),
        ]);

        // Redirect back with success message
        return redirect()->back()->with('success', 'Lease updated successfully.');
    }

    public function unitcancel($id)
    {

        $lease = Lease::findOrFail($id);


        $lease->update(['status' => 'canceled']);


        Payment::where('lease_id', $id)
            ->where('status', 'Unpaid')
            ->update(['status' => 'Canceled']);


        AuditLog::create([
            'user_id' => auth()->id(),
            'action' => 'Lease Canceled',
            'details' => 'Lease ID: ' . $lease->lease_id . ' canceled',
        ]);


        $unit = Unit::findOrFail($lease->unit_id);
        $unit->status = 'Available';
        $unit->save();


        return redirect()->back()->with('success', 'Lease canceled successfully.');
    }


    public function updateStatus(Request $request, $payment_id)
    {
        try {
            $payment = Payment::findOrFail($payment_id);

            // Update payment amount if present
            if ($request->has('amount')) {
                $payment->amount = $request->input('amount');
            }

            // Update payment status based on new status input
            if ($request->has('new_status')) {
                $newStatus = $request->input('new_status');

                if ($newStatus === 'Paid') {
                    $payment->status = 'Paid';
                    // Ensure amount is saved if switching to 'Paid'
                    if ($request->has('amount')) {
                        $payment->amount = $request->input('amount');
                    }
                } elseif ($newStatus === 'Unpaid') {
                    $payment->status = 'Unpaid';
                    // Optionally handle setting amount to null or 0 when switching to 'Unpaid'
                    $payment->amount = null; // Clear the amount when unpaid
                }
            }

            $payment->save();

            return redirect()->back()->with('success', 'Status updated successfully.');
        } catch (\Exception $e) {
            return redirect()->back()->with('error', 'Status not updated.');
        }
    }
}
