<?php

namespace App\Http\Controllers;

use App\Models\MiscellaneousFee;
use Illuminate\Http\Request;
use Carbon\Carbon;
use App\Models\Property;

use Yajra\DataTables\Facades\DataTables;

use App\Models\Payment;
use Faker\Provider\ms_MY\Miscellaneous;

class MiscellaneousFeeController extends Controller
{
    // Display a listing of the resource
    public function index()
    {
        if (request()->ajax()) {
            $MiscellaneousFee = MiscellaneousFee::with('property')->get();

            return DataTables::of($MiscellaneousFee)
                ->addColumn('property_name', function ($MiscellaneousFee) {
                    return $MiscellaneousFee->property->property_name ?? 'N/A'; // Ensure to handle cases where client may not exist
                })
                ->addColumn('actions', function ($MiscellaneousFee) {
                    return '<button class="px-2 py-1 text-white bg-blue-500 rounded"
                           onclick="openModal(\'miscellaneousModal' . $MiscellaneousFee->id . '\')">Edit</button>
                          <button onclick="openModal(\'deleteModal' . $MiscellaneousFee->id . '\')" class="px-2 py-1 font-bold text-white bg-red-500 rounded hover:bg-red-700">Delete</button>';
                })
                ->rawColumns(['payroll', 'actions'])
                ->toJson();
        }
        $MiscellaneousFee = MiscellaneousFee::all();
        $property = Property::get();
        $properties = Property::get();
        return view('CMS.Recievable.miscellaneous_fee', compact('MiscellaneousFee', 'properties', 'property'));
    }

    // Show the form for creating a new resource
    public function create()
    {
        return view('miscellaneous_fees.create');
    }

    // Store a newly created resource in storage
    public function store(Request $request)
    {
        $request->validate([
            'property_id' => 'required|exists:properties,id',
            'type' => 'nullable|string|max:255',
            'amount' => 'nullable|numeric',
            'amount_paid' => 'nullable|numeric',
            'notes' => 'nullable|string',
            'date' => 'nullable|date',
            'status' => 'required|string|in:Pending,Paid,Overdue', // Added validation for status
        ]);

        MiscellaneousFee::create([
            'property_id' => $request->input('property_id'),
            'type' => $request->input('name'),
            'amount' => $request->input('amount'),
            'amount_paid' => $request->input('amount_paid'),
            'notes' => $request->input('notes'),
            'date' => $request->input('date'),
            'status' => $request->input('status'), // Include status field
        ]);

        return redirect()->back()->with('success', 'Miscellaneous Fee created successfully.');
    }
    public function report(Request $request)
    {
        // Get the month and year from the request, or default to the current month and year
        $month = $request->input('month', now()->month);
        $year = $request->input('year', now()->year);

        // Retrieve the miscellaneous fees for the specified month and year
        $fees = MiscellaneousFee::whereYear('date', $year)
            ->whereMonth('date', $month)
            ->get();

        // Convert the date strings to Carbon instances
        $fees->each(function ($fee) {
            $fee->formatted_date = Carbon::parse($fee->date)->format('Y-m-d');
        });

        // Calculate the total fees
        $totalFees = $fees->sum('amount_paid');

        return view('CMS.Recievable.miscellaneous_report', compact('fees', 'month', 'year', 'totalFees'));
    }
    // Display the specified resource
    public function show(MiscellaneousFee $miscellaneousFee)
    {
        return view('miscellaneous_fees.show', compact('miscellaneousFee'));
    }

    // Show the form for editing the specified resource
    public function edit(MiscellaneousFee $miscellaneousFee)
    {
        return view('miscellaneous_fees.edit', compact('miscellaneousFee'));
    }

    // Update the specified resource in storage
    public function update(Request $request, $id)
    {
        // Validate the request data
        $validatedData = $request->validate([
            'property_id' => 'required|exists:properties,id',
            'type' => 'required|string|max:255', // Change to 'type' to match the model
            'amount' => 'nullable|numeric|min:0',
            'amount_paid' => 'nullable|numeric|min:0',
            'notes' => 'nullable|string',
            'date' => 'nullable|date',
            'status' => 'required|string|in:Pending,Paid,Overdue',
        ]);

        // Find the MiscellaneousFee by ID or fail
        $miscellaneousFee = MiscellaneousFee::findOrFail($id);

        // Update the existing MiscellaneousFee record
        $miscellaneousFee->update([
            'property_id' => $validatedData['property_id'],
            'type' => $validatedData['type'], // Ensure 'type' is used here
            'amount' => $validatedData['amount'],
            'amount_paid' => $validatedData['amount_paid'],
            'notes' => $validatedData['notes'],
            'date' => $validatedData['date'],
            'status' => $validatedData['status'],
        ]);

        // Redirect back with a success message
        return redirect()->back()->with('success', 'Miscellaneous Fee updated successfully.');
    }


    // Remove the specified resource from storage
    public function destroy(MiscellaneousFee $miscellaneousFee)
    {
        $miscellaneousFee->delete();

        return redirect()->route('miscellaneous_fees.index')->with('success', 'Miscellaneous Fee deleted successfully.');
    }
}
