<?php

namespace App\Http\Controllers;

use Yajra\DataTables\Facades\DataTables;
use App\Models\Payable;
use Illuminate\Http\Request;

class PayableController extends Controller
{
    public function index(Request $request)
    {
        if (request()->ajax()) {
            $payables = Payable::all();

            return DataTables::of($payables)


                ->addColumn('actions', function ($payables) {
                    return '<button class="px-2 py-1 text-white bg-blue-500 rounded"
                            onclick="openModal(\'payableModal' . $payables->id . '\')">Edit</button>
                         <button onclick="openModal(\'deleteModal' . $payables->id . '\')" class="px-2 py-1 font-bold text-white bg-red-500 rounded hover:bg-red-700">Delete</button>';
                })
                ->rawColumns(['payroll', 'actions'])
                ->toJson();
        }
        $type = $request->query('type');


        $payables = Payable::all();


        return view('CMS.Payables.payable', compact('payables'));
    }



    public function store(Request $request)
    {
        $validatedData = $request->validate([
            'type' => 'required|in:Monthly,Quarterly,Annual',
            'amount' => 'required|numeric',
            'notes' => 'nullable|string',
            'date_of_payable' => 'required|date',
            'category' => 'nullable|string',
        ]);

        Payable::create($validatedData);

        return redirect()->back()->with('success', 'Payable created successfully.');
    }

    public function show(Payable $payable)
    {
        return view('payables.show', compact('payable'));
    }

    public function edit(Payable $payable)
    {
        return view('payables.edit', compact('payable'));
    }

    public function update(Request $request, $id)
    {
        $validatedData = $request->validate([
            'type' => 'required|in:Monthly,Quarterly,Annual',
            'amount' => 'required|numeric',
            'notes' => 'nullable|string',
            'date_of_payable' => 'required|date',
            'category' => 'nullable|string',
        ]);

        $payable = Payable::findOrFail($id);
        $payable->update($validatedData);

        return redirect()->route('payables.index')->with('success', 'Payable updated successfully.');
    }

    public function destroy(Payable $payable)
    {
        $payable->delete();

        return redirect()->route('payables.index')->with('success', 'Payable deleted successfully.');
    }
    public function generateReport(Request $request)
    {
        $type = $request->query('type');
        $month = $request->query('month');
        $year = $request->query('year');
        $quarter = $request->query('quarter');
        $category = $request->query('category');

        $query = Payable::query();

        // Filter by type
        if ($type === 'Quarterly') {
            $query->whereIn('type', ['Monthly', 'Other']); // Include all types except Quarterly and Annual
        } elseif ($type === 'Monthly') {
            $query->where('type', 'Monthly');
        } elseif ($type === 'Annual') {
            $query->where('type', 'Annual');
        } elseif ($type === 'All') {
            $query->whereIn('type', ['Monthly', 'Other']); // Include all types except Quarterly and Annual
        }

        // Filter by date range if applicable
        if ($year) {
            if ($type === 'Quarterly' && $quarter) {
                $startMonth = [
                    'Q1' => 1,
                    'Q2' => 4,
                    'Q3' => 7,
                    'Q4' => 10,
                ][$quarter];
                $endMonth = $startMonth + 2;

                $query->whereBetween('date_of_payable', [
                    \Carbon\Carbon::create($year, $startMonth, 1)->startOfMonth(),
                    \Carbon\Carbon::create($year, $endMonth, 1)->endOfMonth()
                ]);
            } elseif ($type === 'Monthly' && $month) {
                $query->whereMonth('date_of_payable', $month);
            } elseif ($type === 'Annual') {
                $query->whereYear('date_of_payable', $year);
            } else {
                // For 'All' type or any type with year and quarter
                $query->whereYear('date_of_payable', $year);
            }
        }

        // Filter by category if provided
        if ($category) {
            $query->where('category', $category);
        }

        // Fetch filtered payables
        $payables = $query->get();

        // Calculate total amount
        $totalAmount = $payables->sum('amount');

        // VAT and withholding tax calculations
        $vatRate = 0.12; // VAT rate of 12%
        $withholdingTaxRate = 0.05; // Withholding tax rate of 5%
        $percentageTaxRate = 0.03; // Percentage tax rate of 3%

        $totalVAT = $totalWithholdingTax = $totalPercentageTax = 0;

        if ($type === 'Quarterly') {
            $totalVAT = $totalAmount * $vatRate;
            $totalPercentageTax = $totalAmount * $percentageTaxRate;
        } elseif ($type === 'Monthly') {
            $totalWithholdingTax = $totalAmount * $withholdingTaxRate;
        }

        return view('CMS.Payables.report', compact('payables', 'totalAmount', 'totalVAT', 'totalWithholdingTax', 'totalPercentageTax', 'type', 'month', 'year', 'quarter'));
    }
}
