<?php

namespace App\Http\Controllers;

use App\Models\AdditionalFee;
use DateTime;
use DateInterval;
use Illuminate\Http\Request;
use App\Models\Client;
use App\Models\Property;
use App\Models\Unit;
use App\Models\Lease;
use App\Models\Payment;
use Illuminate\Support\Facades\DB;
use App\Models\NewPayment;
use App\Models\Waterbill;
use App\Models\Electricbill;
use App\Models\AuditLog;
use PhpParser\Node\Expr\New_;
use Yajra\DataTables\Facades\DataTables;
use Carbon\Carbon;

class PaymentController extends Controller
{
    public function index(Request $request, $id)
    {
        // Fetch lease information
        $lease = Lease::with('client', 'unit')->findOrFail($id);
        $payments = Payment::with(['lease.property', 'lease.unit'])
            ->orderBy('payment_date', 'desc')
            ->where('lease_id', $id)
            ->get();
        if ($request->ajax()) {
            // Fetch payments related to the lease
            $payments = Payment::with(['lease.property', 'lease.unit'])
                ->orderBy('payment_date', 'desc')
                ->where('lease_id', $id)
                ->get();

            return DataTables::of($payments)
                ->addColumn('payment_schedule', function ($payment) {
                    return \Carbon\Carbon::parse($payment->payment_date)->format('F j, Y');
                })
                ->addColumn('status', function ($payment) {
                    return $payment->status;
                })
                ->addColumn('amount', function ($payment) {
                    return $payment->amount; // Ensure column name matches what DataTables expects
                })
                ->addColumn('balance', function ($payment) {
                    return $payment->balance; // Ensure column name matches what DataTables expects
                })
                ->addColumn('payment_type', function ($payment) {
                    return $payment->payment_type; // Ensure column name matches what DataTables expects
                })
                ->addColumn('light', function ($payment) {
                    return $payment->light; // Ensure column name matches what DataTables expects
                })
                ->addColumn('water', function ($payment) {
                    return $payment->water; // Ensure column name matches what DataTables expects
                })
                ->addColumn('voucher', function ($payment) {
                    return $payment->voucher; // Ensure column name matches what DataTables expects
                })
                ->addColumn('remarks', function ($payment) {
                    return $payment->remarks; // Ensure column name matches what DataTables expects
                })
                ->addColumn('Action', function ($payment) {
                    return '<button onclick="openModal1(\'editItemModal' . $payment->payment_id . '\')" class="px-2 py-1 font-bold text-white bg-blue-500 rounded hover:bg-blue-700">Edit</button>';
                })
                ->rawColumns(['Action']) // Ensure 'Action' column is treated as raw HTML
                ->toJson();
        }

        return view('CMS.Payment.viewpayment', compact('lease', 'payments'));
    }
    public function updatepayment(Request $request, $payment_id)
    {
        // Validate the request
        $validatedData = $request->validate([
            'lease_id' => 'required|exists:lease,lease_id',
            'amount' => 'required|numeric',
            'payment_date' => 'required|date',
            'status' => 'required|string|max:255',
            'billing_notes' => 'nullable|string',
        ]);

        try {
            // Find the payment
            $payment = Payment::findOrFail($payment_id);

            // Update the payment
            $payment->update([
                'lease_id' => $validatedData['lease_id'],
                'Amount' => $validatedData['amount'],
                'payment_date' => $validatedData['payment_date'],
                'status' => $validatedData['status'],
                'billing_notes' => $validatedData['billing_notes'],
            ]);

            // Log the action in the audit log
            AuditLog::create([
                'user_id' => auth()->id(), // Assuming you are using authentication
                'action' => 'Update Payment',
                'details' => 'Updated payment with ID: ' . $payment->id,
            ]);

            // Redirect back with success message
            return redirect()->back()->with('success', 'Payment updated successfully.');
        } catch (\Exception $e) {
            // Handle any exceptions, such as database errors
            return redirect()->back()->withErrors(['error' => 'Failed to update payment. Please try again.'])->withInput();
        }
    }
    public function index2(Request $request, $unit_id)
    {

        $lease = Lease::with('client', 'unit')->where('unit_id', '4')->firstOrFail();



        $payments = Payment::with(['lease.property', 'lease.unit'])
            ->join('lease', 'payment.lease_id', '=', 'lease.lease_id')
            ->where('lease.unit_id', $unit_id)
            ->orderBy('payment.payment_date', 'desc')
            ->get();
        if ($request->ajax()) {

            $payments = Payment::with(['lease.property', 'lease.unit'])
                ->join('lease', 'payment.lease_id', '=', 'lease.lease_id')
                ->where('lease.unit_id', $unit_id)
                ->orderBy('payment.payment_date', 'desc')
                ->get();
            return DataTables::of($payments)
                ->addColumn('payment_schedule', function ($payment) {
                    return \Carbon\Carbon::parse($payment->payment_date)->format('F j, Y');
                })
                ->addColumn('status', function ($payment) {
                    return $payment->status;
                })
                ->addColumn('amount', function ($payment) {
                    return $payment->amount; // Ensure column name matches what DataTables expects
                })
                ->addColumn('balance', function ($payment) {
                    return $payment->balance; // Ensure column name matches what DataTables expects
                })
                ->addColumn('payment_type', function ($payment) {
                    return $payment->payment_type; // Ensure column name matches what DataTables expects
                })
                ->addColumn('light', function ($payment) {
                    return $payment->light; // Ensure column name matches what DataTables expects
                })
                ->addColumn('water', function ($payment) {
                    return $payment->water; // Ensure column name matches what DataTables expects
                })
                ->addColumn('voucher', function ($payment) {
                    return $payment->voucher; // Ensure column name matches what DataTables expects
                })
                ->addColumn('remarks', function ($payment) {
                    return $payment->remarks; // Ensure column name matches what DataTables expects
                })
                ->addColumn('Action', function ($payment) {
                    return '<button onclick="openModal1(\'editItemModal' . $payment->payment_id . '\')" class="px-2 py-1 font-bold text-white bg-blue-500 rounded hover:bg-blue-700">Edit</button>';
                })
                ->rawColumns(['Action']) // Ensure 'Action' column is treated as raw HTML
                ->toJson();
        }


        return view('CMS.Payment.viewpayment', compact('lease', 'payments'));
    }


    public function clientsoa()
    {
        $clientmain = Client::all();


        $payment1 = Payment::with('electricPayments', 'waterPayments', 'lease.client')
            ->whereIn('status', ['Unpaid', 'Partial Payment', 'Advance Payment'])
            ->get();


        $newpayments = NewPayment::with(['payment.lease.unit.property', 'payment.lease.client'])
            ->orderBy('created_at', 'desc')
            ->get();
        if (request()->ajax()) {
            $table = request()->get('table');

            if ($table === 'newPayments') {
                return DataTables::of($newpayments)
                    ->addColumn('payment_id', function ($newPayment) {
                        return 'Billing No. ' . $newPayment->payment_id;
                    })
                    ->addColumn('newpayment_id', function ($newPayment) {
                        return 'Ref.' . $newPayment->newpayment_id;
                    })
                    ->addColumn('renter', function ($newPayment) {
                        return $newPayment->payment->lease->client->owners_name;
                    })
                    ->addColumn('property', function ($newPayment) {
                        return $newPayment->payment->lease->unit->unit_name . '-' . $newPayment->payment->lease->unit->property->property_name;
                    })

                    ->addColumn('payment_method', function ($newPayment) {
                        return $newPayment->payment_method;
                    })
                    ->addColumn('bank', function ($newPayment) {
                        return $newPayment->bank;
                    })
                    ->addColumn('rental_amount', function ($newPayment) {
                        return number_format($newPayment->rental_amount, 2); // Format as needed
                    })
                    ->addColumn('waterbill_amount', function ($newPayment) {
                        return number_format($newPayment->waterbill_amount, 2); // Format as needed
                    })
                    ->addColumn('electricbill_amount', function ($newPayment) {
                        return number_format($newPayment->electricbill_amount, 2); // Format as needed
                    })
                    ->addColumn('status', function ($newPayment) {
                        return $newPayment->status;
                    })
                    ->addColumn('actions', function ($newPayment) {
                        return '<button onclick="openModaldelete(\'EditModal' . $newPayment->newpayment_id . '\')" class="px-2 py-1 font-bold text-white bg-blue-500 rounded hover:bg-blue-700">Edit</button>
                        <button onclick="openModaldelete(\'deleteModal' . $newPayment->newpayment_id . '\')" class="px-2 py-1 font-bold text-white bg-red-500 rounded hover:bg-red-700">Delete</button>';
                    })
                    ->rawColumns(['actions'])
                    ->make(true);
            }
        }

        return view('CMS.Payment.managepayment', compact('clientmain', 'payment1', 'newpayments'));
    }


    public function allpayments(Request $request)
    {
        if ($request->ajax()) {
            $table = $request->get('table');
            $currentDate = Carbon::now();

            // Define the base query
            $query = Payment::select(
                'payment.*',
                'payment.Amount as rental_amount',
                'lease.*',
                'clients.*',
                'payment.status as payment_status',

            )
                ->with(['lease.property', 'lease.unit', 'electricPayments', 'waterPayments'])
                ->leftJoin('lease', 'payment.lease_id', '=', 'lease.lease_id')
                ->leftJoin('clients', 'clients.client_id', '=', 'lease.client_id');



            if ($table === 'paymentsRange1Table') {
                $query->whereDate('payment_date', '>=', $currentDate);
                $query->whereNot('payment.status', 'Paid');
            } elseif ($table === 'paymentsRange2Table') {
                $startDate = $currentDate->copy()->subDays(90);
                $endDate = $currentDate->copy()->subDays(31);
                $query->whereBetween('payment_date', [$startDate, $endDate]);
                $query->whereNot('payment.status', 'Paid');
            } elseif ($table === 'paymentsRange4Table') {
                $startDate = $currentDate->copy()->subDays(30);
                $endDate = $currentDate;
                $query->whereBetween('payment_date', [$startDate, $endDate]);
                $query->whereNot('payment.status', 'Paid');
            } elseif ($table === 'paymentsRange3Table') {
                $startDate = $currentDate->copy()->subDays(90);
                $endDate = $currentDate->copy()->subDays(180);

                $query->whereBetween('payment_date', [$startDate, $endDate])
                    ->orWhere(function ($query) use ($startDate) {
                        // Include payments more than 90 days overdue
                        $query->where('payment_date', '<', $startDate);
                    });
                $query->whereNot('payment.status', 'Paid');
            } elseif ($table === 'paymentsRange5Table') {
                $query->where('payment.status', 'Paid');
            } else {
                return response()->json(['error' => 'Invalid table parameter'], 400);
            }

            // Execute the query
            $payments = $query->orderBy('payment_date', 'asc')->get();

            // Handle empty responses
            if ($payments->isEmpty()) {
                return response()->json(['data' => []]);
            }

            return DataTables::of($payments)
                ->addColumn('payment_schedule', function ($payment) {
                    return \Carbon\Carbon::parse($payment->payment_date)->format('F j, Y');
                })
                ->addColumn('due_date', function ($payment) {
                    $dueDate = \Carbon\Carbon::parse($payment->payment_date)->addDays($payment->lease->terms);
                    return $dueDate->format('F j, Y');
                })
                ->addColumn('payment_id', function ($payment) {
                    return 'Billing ID:' . $payment->payment_id;
                })
                ->addColumn('client_name', function ($payment) {
                    return $payment->owners_name ?? 'N/A'; // Adjust according to your actual column name
                })
                ->addColumn('Amount', function ($payment) {
                    return $payment->rental_amount ?? 'N/A';
                })
                ->addColumn('water_amount', function ($payment) {
                    return $payment->waterPayments->isEmpty() ? 'N/A' : $payment->waterPayments->first()->amount;
                })
                ->addColumn('electric_amount', function ($payment) {
                    return $payment->electricPayments->isEmpty() ? 'N/A' : $payment->electricPayments->first()->amount;
                })
                ->addColumn('view', function ($payment) use ($table) {
                    if ($table === 'paymentsRange1Table') {
                        return '<a href="' . url('/soa', [$payment->lease_id, $payment->payment_id]) . '" class="px-2 py-1 font-bold text-white bg-blue-500 rounded hover:bg-blue-700">View</a>';
                    } elseif ($table === 'paymentsRange2Table') {
                        return '<a href="' . url('/demand_letter', $payment->lease_id) . '" class="px-2 py-1 font-bold text-white bg-green-500 rounded hover:bg-green-700">View</a>';
                    } elseif ($table === 'paymentsRange3Table') {
                        return '<a href="' . url('/foreclosure_letter', $payment->lease_id) . '" class="px-2 py-1 font-bold text-white bg-red-800 rounded hover:bg-yellow-700">View</a>';
                    } elseif ($table === 'paymentsRange4Table') {
                        return '<a href="' . url('/soa', [$payment->lease_id, $payment->payment_id]) . '" class="px-2 py-1 font-bold text-white bg-blue-500 rounded hover:bg-blue-700">View</a>';
                    } elseif ($table === 'paymentsRange5Table') {
                        return '<a href="' . url('/soa', [$payment->lease_id, $payment->payment_id]) . '" class="px-2 py-1 font-bold text-white bg-purple-500 rounded hover:bg-purple-700">View</a>';
                    }
                    return '<a href="' . url('/default', [$payment->payment_id]) . '" class="px-2 py-1 font-bold text-white bg-gray-500 rounded hover:bg-gray-700">Default</a>';
                })
                ->addColumn('Action', function ($payment) use ($table) {
                    if ($table === 'paymentsRange5Table') {
                        return '<a href="' . url('/invoice', [$payment->lease_id, $payment->payment_id]) . '" class="px-2 py-1 font-bold text-white bg-blue-500 rounded hover:bg-blue-700">Invoice</a>
                        <button onclick="openModal(\'editPaymentModal' . $payment->payment_id . '\')" class="px-2 py-1 font-bold text-white bg-blue-500 rounded hover:bg-blue-700">Edit</button>';
                    }
                    return '<button onclick="openModal(\'editPaymentModal' . $payment->payment_id . '\')" class="px-2 py-1 font-bold text-white bg-blue-500 rounded hover:bg-blue-700">Edit</button>';
                })
                ->rawColumns(['view', 'Action'])
                ->toJson();
        }

        // Fetch all payments for initial page load
        $payments = Payment::with(['lease.property', 'lease.unit'])
            ->orderBy('payment_date', 'desc')
            ->get();
        $payment1 = Payment::with('electricPayments', 'waterPayments', 'lease.client')
            ->whereIn('status', ['Unpaid', 'Partial Payment', 'Advance Payment'])
            ->get();
        return view('CMS.Payment.allpayments', compact('payments', 'payment1'));
    }




    public function update(Request $request, $id)
    {
        $validatedData = $request->validate([
            'payment_method' => 'nullable|string',
            'bank' => 'nullable|string',
            'check_no' => 'nullable|string',
            'rental_amount' => 'required|numeric',
            'waterbill_amount' => 'nullable|numeric',
            'electricbill_amount' => 'nullable|numeric',

            'advance_payment_amount' => 'nullable|numeric',
            'remarks' => 'nullable|string',
            'status' => 'required|in:Unpaid,Paid', // Add validation for status if needed
        ]);

        // Find the payment record by $id
        $payment = NewPayment::where('newpayment_id', $id)->firstOrFail();

        // Update fields
        $payment->rental_amount = $validatedData['rental_amount'];
        $payment->waterbill_amount = $validatedData['waterbill_amount'] ?? $payment->waterbill_amount;
        $payment->electricbill_amount = $validatedData['electricbill_amount'] ?? $payment->electricbill_amount;
        $payment->advance_payment = $validatedData['advance_payment_amount'] ?? $payment->advance_payment;
        $payment->payment_method = $validatedData['payment_method'] ?? $payment->payment_method;
        $payment->bank = $validatedData['bank'] ?? $payment->bank;
        $payment->check_no = $validatedData['check_no'] ?? $payment->check_no;
        $payment->remarks = $validatedData['remarks'] ?? $payment->remarks;
        $payment->status = $validatedData['status'] ?? $payment->status; // Ensure status is updated if provided

        $payment->save();

        return redirect()->back()->with('success', 'Payment details updated successfully');
    }



    public function store(Request $request)
    {
        $validatedData = $request->validate([
            'payment_id' => 'required|exists:payment,payment_id',
            'payment_method' => 'nullable|string',
            'bank' => 'nullable|string',
            'check_no' => 'nullable|string',
            'rental_amount' => 'required|numeric',
            'waterbill_amount' => 'nullable|numeric',
            'electricbill_amount' => 'nullable|numeric',
            'additionalfees_amount' => 'nullable|numeric',
            'advance_payment_amount' => 'nullable|numeric',
            'remarks' => 'nullable|string',
        ]);

        // Retrieve the payment record
        $payment = Payment::findOrFail($validatedData['payment_id']);

        $paymentAmountToPay = $payment->Amount;
        $waterAmountToPay = $payment->waterPayments->sum('amount') ?? 0;
        $electricAmountToPay = $payment->electricPayments->sum('amount') ?? 0;

        // Get amounts already paid from NewPayments
        $totalRentalPaid = NewPayment::where('payment_id', $validatedData['payment_id'])->sum('rental_amount');
        $totalWaterPaid = NewPayment::where('payment_id', $validatedData['payment_id'])->sum('waterbill_amount');
        $totalElectricPaid = NewPayment::where('payment_id', $validatedData['payment_id'])->sum('electricbill_amount');

        // Calculate current amounts after deductions
        $currentRentalAmount = $paymentAmountToPay - $totalRentalPaid;
        $currentWaterAmount = $waterAmountToPay - $totalWaterPaid;
        $currentElectricAmount = $electricAmountToPay - $totalElectricPaid;

        // Fetch additional fees and calculate the total amount paid
        $additionalFees = AdditionalFee::where('billing_id', $validatedData['payment_id'])->get();
        $totalAdditionalFeeAmount = $additionalFees->sum('amount');
        $totalAdditionalFeePaid = $additionalFees->sum('amount_paid');
        $currentAdditionalFee = $totalAdditionalFeeAmount - $totalAdditionalFeePaid;

        // Determine the payment status based on the amounts
        $status = 'Partial Payment';
        if (
            $validatedData['rental_amount'] >= $currentRentalAmount &&
            $validatedData['waterbill_amount'] == $currentWaterAmount &&
            $validatedData['electricbill_amount'] == $currentElectricAmount &&
            (!$additionalFees->isEmpty() || $validatedData['additionalfees_amount'] >= $currentAdditionalFee)
        ) {
            $status = 'Paid';
            $payment->update(['status' => 'Paid']);
        }

        // Create a new NewPayment record without updating existing ones
        NewPayment::create([
            'payment_id' => $validatedData['payment_id'],
            'rental_amount' => $validatedData['rental_amount'],
            'payment_method' => $validatedData['payment_method'],
            'bank' => $validatedData['bank'],
            'check_no' => $validatedData['check_no'],
            'waterbill_amount' => $validatedData['waterbill_amount'] ?? 0,
            'electricbill_amount' => $validatedData['electricbill_amount'] ?? 0,
            'additionalfees_amount' => $validatedData['additionalfees_amount'] ?? 0,
            'advance_payment' => $validatedData['advance_payment_amount'] ?? 0,
            'status' => $status,
            'remarks' => $validatedData['remarks'],
        ]);

        // Update additional fees
        if (isset($validatedData['additionalfees_amount']) && $validatedData['additionalfees_amount'] > 0) {
            $remainingAdditionalFeeAmount = $validatedData['additionalfees_amount'];

            foreach ($additionalFees as $additionalFee) {
                if ($remainingAdditionalFeeAmount <= 0) break;

                $amountToApply = min($remainingAdditionalFeeAmount, $additionalFee->amount - $additionalFee->amount_paid);
                $additionalFee->update(['amount_paid' => $additionalFee->amount_paid + $amountToApply]);
                $remainingAdditionalFeeAmount -= $amountToApply;
            }
        }

        // Process advance payments
        if (isset($validatedData['advance_payment_amount']) && $validatedData['advance_payment_amount'] > 0) {
            $advancePaymentAmount = $validatedData['advance_payment_amount'];

            while ($advancePaymentAmount > 0) {
                // Find the next payment with a higher ID and the same lease_id
                $nextPayment = Payment::where('lease_id', $payment->lease_id)
                    ->where('payment_id', '>', $payment->payment_id)
                    ->orderBy('payment_id', 'asc')
                    ->first();

                if (!$nextPayment) {
                    break;
                }

                // Apply the entire advance payment amount to the next payment
                NewPayment::create([
                    'payment_id' => $nextPayment->payment_id,
                    'rental_amount' => $advancePaymentAmount,
                    'waterbill_amount' => 0,
                    'electricbill_amount' => 0,
                    'additionalfees_amount' => 0,
                    'advance_payment' => $advancePaymentAmount,
                    'status' => 'Advance Payment'
                ]);

                $advancePaymentAmount = 0; // All advance payment amount has been used
            }
        }

        // Create audit log entry
        AuditLog::create([
            'user_id' => auth()->id(),
            'action' => 'Payment Created',
            'details' => 'Payment ID: ' . $validatedData['payment_id'] . ' created with method: ' . $validatedData['payment_method'],
        ]);

        return redirect()->back()->with('success', 'Payment inserted successfully.');
    }











    public function updatenewpayment(Request $request, $id)
    {

        $payment = NewPayment::findOrFail($id);


        $validatedData = $request->validate([
            'lease_id' => 'required|exists:lease,lease_id',
            'payment_method' => 'required|string',
            'bank' => 'required|string',
            'Amount' => 'nullable|string',
            'status' => 'nullable|string',
        ]);


        $payment->update($validatedData);

        return response()->json(['message' => 'Payment updated successfully', 'payment' => $payment], 200);
    }

    public function deletenewpayment($id)
    {
        // Find payment by ID and delete
        $payment = NewPayment::findOrFail($id);
        $payment->delete();

        return redirect()->back()->with('success', 'Payment deleted successfully.');
    }
    public function deletepayment($id)
    {
        // Find payment by ID and delete
        $payment = Payment::findOrFail($id);
        $payment->delete();

        return redirect()->back()->with('success', 'Payment deleted successfully.');
    }
    public function searchClients(Request $request)
    {
        $searchTerm = $request->get('q');

        // Fetch clients based on the search term
        $clients = Client::where('name', 'LIKE', "%{$searchTerm}%")
            ->orWhere('tin', 'LIKE', "%{$searchTerm}%")
            ->get(['id', 'name', 'tin']);

        return response()->json([
            'results' => $clients->map(function ($client) {
                return [
                    'id' => $client->id,
                    'text' => "{$client->name} (TIN: {$client->tin})"
                ];
            })
        ]);
    }
    public function getPaymentAmount($payment_id)
    {
        $payment = Payment::with(['lease.client', 'lease.unit', 'lease.property', 'waterPayments', 'electricPayments', 'additionalFees'])
            ->find($payment_id);

        if ($payment) {
            $paymentAmountDue = $payment->Amount;
            $waterAmountDue = $payment->waterPayments->sum('amount');
            $electricAmountDue = $payment->electricPayments->sum('amount');
            $additionalFeesDue = $payment->additionalFees->sum('amount');

            $totalRentalPaid = NewPayment::where('payment_id', $payment_id)->sum('rental_amount');
            $totalWaterPaid = NewPayment::where('payment_id', $payment_id)->sum('waterbill_amount');
            $totalElectricPaid = NewPayment::where('payment_id', $payment_id)->sum('electricbill_amount');
            $totalAdditionalFeesPaid = AdditionalFee::where('billing_id', $payment_id)->sum('amount_paid');
            $advancePayment = NewPayment::where('payment_id', $payment_id)->sum('advance_payment');


            $lease = $payment->lease;
            $currentDate = $payment->payment_date;
            $leaseStartDate = $lease->lease_start_date;
            $yearlyEscalationPercentage = $lease->yearly_escalation; // Assuming this is a percentage (e.g., 5 for 5%)

            // Convert percentage to decimal
            $yearlyEscalationRate = $yearlyEscalationPercentage / 100;

            $yearsPassed = $currentDate->diffInYears($leaseStartDate);
            if ($yearsPassed >= 1) {
                // Calculate escalation amount
                $escalationAmount = $paymentAmountDue * $yearlyEscalationRate;
                $paymentAmountDue += $escalationAmount;
            }

            $currentRentalAmount = max($paymentAmountDue - $totalRentalPaid, 0);
            $currentWaterAmount = max($waterAmountDue - $totalWaterPaid, 0);
            $currentElectricAmount = max($electricAmountDue - $totalElectricPaid, 0);
            $currentAdditionalFeesAmount = max($additionalFeesDue - $totalAdditionalFeesPaid, 0);

            $client = $payment->lease->client;
            $vatApplicable = $client ? $client->vat === 'vat' : false;
            $withholdingTaxApplicable = $client ? $client->w_holding_tax === 'true' : false;

            $vatRate = 0.12;
            $withholdingTaxRate = 0.05;

            $terms = $payment->lease->terms;
            $paymentDate = $payment->payment_date;
            $dueDate = $paymentDate ? $paymentDate->copy()->addDays($terms) : null;

            $penaltyAmount = 0;
            if ($dueDate && now()->isAfter($dueDate)) {
                $monthsPastDue = now()->diffInMonths($dueDate);
                $penaltyAmount = $currentRentalAmount * 0.02 * $monthsPastDue;
            }

            $totalAmountDue = $paymentAmountDue + $waterAmountDue + $electricAmountDue + $additionalFeesDue + $penaltyAmount;

            $totalpay = $totalRentalPaid + $totalWaterPaid + $totalElectricPaid + $totalAdditionalFeesPaid;
            $totalotherpay = $waterAmountDue + $electricAmountDue + $additionalFeesDue;
            $vatAmount = $vatApplicable ? $totalAmountDue * $vatRate : 0;
            $withholdingTaxAmount = $withholdingTaxApplicable ? $totalAmountDue * $withholdingTaxRate : 0;


            $adjustedPaymentAmount = $totalAmountDue + $vatAmount - $withholdingTaxAmount - $totalpay;

            $adjustedPaymentAmount1 = $totalAmountDue + $vatAmount - $withholdingTaxAmount - $totalotherpay - $totalRentalPaid;

            $unit = $payment->lease->unit;
            $property = $payment->lease->property;

            return response()->json([
                'grandtotal' => round($adjustedPaymentAmount, 2),
                'paymentAmount' => round($currentRentalAmount, 2),
                'waterAmount' => round($currentWaterAmount, 2),
                'electricAmount' => round($currentElectricAmount, 2),
                'penaltyAmount' => round($penaltyAmount, 2),
                'additionalFeesAmount' => round($currentAdditionalFeesAmount, 2),
                'vatAmount' => round($vatAmount, 2),
                'withholdingTaxAmount' => round($withholdingTaxAmount, 2),
                'adjustedPaymentAmount' => round($adjustedPaymentAmount1, 2),
                'client' => $client ? $client->owners_name : '',
                'unit' => $unit ? $unit->unit_name : '',
                'property' => $property ? $property->property_name : '',
                'billingdate' => $paymentDate,
                'dueDate' => $dueDate,
                'advancePayment' => $advancePayment,
            ]);
        }

        return response()->json([
            'paymentAmount' => 0,
            'waterAmount' => 0,
            'electricAmount' => 0,
            'penaltyAmount' => 0,
            'vatAmount' => 0,
            'withholdingTaxAmount' => 0,
            'adjustedPaymentAmount' => 0,
            'additionalFeesAmount' => 0,
            'client' => '',
            'unit' => '',
            'property' => '',
            'dueDate' => null,
        ]);
    }
}
