<?php

namespace App\Http\Controllers;

use App\Models\Payroll;
use App\Models\AuditLog;
use App\Models\Deduction;
use App\Models\Employee;
use Carbon\Carbon;
use App\Models\Attendance;
use Illuminate\Http\Request;
use Yajra\DataTables\Facades\DataTables;

class PayrollController extends Controller
{
    public function index()
    {
        if (request()->ajax()) {
            $payrolls = Payroll::with('employee', 'employee.deductions')->get();
            $payrolls->each(function ($payroll) {
                $payroll->total_deductions = $payroll->employee->deductions->sum('amount');
            });
            return DataTables::of($payrolls)
                ->addColumn('employee_name', function ($payroll) {
                    return $payroll->employee->complete_name;
                })
                ->addColumn('total_deductions', function ($payroll) {
                    return '' . number_format($payroll->total_deductions, 2);
                })
                ->addColumn('view', function ($payroll) {
                    return '<button class="px-4 py-2 font-bold text-white bg-blue-500 rounded hover:bg-blue-700"
                                onclick="openModal(\'viewpayroll' . $payroll->id . '\')">view</button>';
                })
                ->addColumn('actions', function ($payroll) {
                    return '<button class="px-4 py-2 font-bold text-white bg-blue-500 rounded hover:bg-blue-700"
                                onclick="openModal(\'editPayrollModal' . $payroll->id . '\')">Edit</button>
                            <button class="px-4 py-2 font-bold text-white bg-red-500 rounded hover:bg-red-700"
                                onclick="openModal(\'deletePayrollModal' . $payroll->id . '\')">Delete</button>';
                })
                ->rawColumns(['actions', 'view'])
                ->make(true);
        }
        $employees = Employee::all();
        $payrolls = Payroll::with('employee')->get();

        return view('CMS.Payroll.payroll', compact(['employees', 'payrolls']));
    }
    public function individualpayroll($id)
    {
        $deductions = Deduction::where('employee_id', $id)->get();
        $employees = Employee::all();
        $employee = Employee::findOrFail($id);
        $attendances = Attendance::where('employee_id', $id)->get();
        $table = request()->get('table');


        $startDate = request()->get('start_date');
        $endDate = request()->get('end_date');

        if ($table === 'payroll') {
            $payrolls = Payroll::where('employee_id', $id)->with('employee', 'employee.deductions')->get();

            return DataTables::of($payrolls)
                ->addColumn('employee_name', function ($payroll) {
                    return $payroll->employee->complete_name;
                })
                ->addColumn('total_deductions', function ($payroll) {
                    return '' . number_format($payroll->total_deductions, 2);
                })
                ->addColumn('view', function ($payroll) {
                    return '<button class="px-4 py-2 font-bold text-white bg-blue-500 rounded hover:bg-blue-700"
                                    onclick="openModal(\'viewpayroll' . $payroll->id . '\')">view</button>';
                })
                ->addColumn('actions', function ($payroll) {
                    return '<button class="px-4 py-2 font-bold text-white bg-blue-500 rounded hover:bg-blue-700"
                                    onclick="openModal(\'editPayrollModal' . $payroll->id . '\')">Edit</button>
                                <button class="px-4 py-2 font-bold text-white bg-red-500 rounded hover:bg-red-700"
                                    onclick="openModal(\'deletePayrollModal' . $payroll->id . '\')">Delete</button>';
                })
                ->rawColumns(['actions', 'view'])
                ->make(true);
        }

        // For Deductions DataTable
        elseif ($table === 'deductions') {
            $deductions = Deduction::where('employee_id', $id)->get();
            return DataTables::of($deductions)
                ->addColumn('actions', function ($deduction) {
                    return '
                                <button class="px-4 py-2 font-bold text-white bg-red-500 rounded hover:bg-red-700"
                                    onclick="openModal(\'deletedeductionModal' . $deduction->id . '\')">Delete</button>';
                })
                ->rawColumns(['actions'])
                ->make(true);
        } elseif ($table === 'attendance') {
            $query = Attendance::where('employee_id', $id);

            if ($startDate && $endDate) {
                $query->whereBetween('date', [$startDate, $endDate]);
            }

            $attendance = $query->get();
            return DataTables::of($attendance)
                ->addColumn('actions', function ($attendance) {
                    return '<button class="px-4 py-2 font-bold text-white bg-blue-500 rounded hover:bg-blue-700"
                                    onclick="openModal(\'editAttendanceModal' . $attendance->id . '\')">Edit</button>
                                <button class="px-4 py-2 font-bold text-white bg-red-500 rounded hover:bg-red-700"
                                    onclick="openModal(\'deleteAttendanceModal' . $attendance->id . '\')">Delete</button>';
                })
                ->rawColumns(['actions'])
                ->make(true);
        }


        $payrolls = Payroll::with('employee.deductions')->where('employee_id', $id)->get();

        return view('CMS.Payroll.employeepayroll', compact('employee', 'attendances', 'payrolls', 'employees', 'deductions'));
    }

    public function store(Request $request)
    {
        // Validate the request data
        $request->validate([
            'employee_id' => 'required|exists:employees,id',
            'start_date' => 'required|date',
            'end_date' => 'required|date',
            'bonuses' => 'nullable|numeric|min:0',
            'cash_advances' => 'nullable|numeric|min:0',
            'sss' => 'nullable|string',
            'philhealth' => 'nullable|string',
            'pagibig' => 'nullable|string',
            'notes' => 'nullable|string',
        ]);

        $employee = Employee::find($request->employee_id);

        // Get the attendance records within the specified date range
        $attendances = Attendance::where('employee_id', $employee->id)
            ->whereBetween('date', [$request->start_date, $request->end_date])
            ->get();

        $daysWorked = $attendances->count();

        // Initialize totals
        $totalLateness = 0;
        $totalEarlyOut = 0;

        foreach ($attendances as $attendance) {
            // Parse clock-in and clock-out times
            $scheduledStart = Carbon::parse($attendance->date . ' 08:00:00'); // Scheduled start time
            $actualStart = Carbon::parse($attendance->date . ' ' . $attendance->clock_in); // Actual clock-in time

            // Calculate lateness
            if ($actualStart->greaterThan($scheduledStart)) {
                $totalLateness += $actualStart->diffInMinutes($scheduledStart);
            }

            $scheduledEnd = Carbon::parse($attendance->date . ' 17:00:00'); // Scheduled end time
            $actualEnd = $attendance->clock_out ? Carbon::parse($attendance->date . ' ' . $attendance->clock_out) : $scheduledEnd;

            // Calculate early out
            if ($actualEnd->lessThan($scheduledEnd)) {
                $totalEarlyOut += $scheduledEnd->diffInMinutes($actualEnd);
            }
        }

        // Total undertime in minutes
        $totalUndertime = $totalLateness + $totalEarlyOut;

        // Calculate deductions
        $ratePerHour = $employee->salary_rate / 8; // Assuming 8 hours workday
        $undertimePenalty = ($totalUndertime / 60) * $ratePerHour; // Convert minutes to hours and apply rate


        $grossEarnings = ($daysWorked * $employee->salary_rate) + ($request->bonuses ?? 0);


        $sssRate = 0.09;
        $philhealthRate = 0.05; // Example PhilHealth rate (3%)
        $pagibigRate = 0.03; // Example Pag-IBIG rate (1%)

        // Calculate benefits deductions
        $sssDeduction = $request->sss ? ($grossEarnings * $sssRate) : 0;
        $philhealthDeduction = $request->philhealth ? ($grossEarnings * $philhealthRate) : 0;
        $pagibigDeduction = $request->pagibig ? ($grossEarnings * $pagibigRate) : 0;

        // Calculate total benefits deduction
        $totalBenefitsDeduction = $sssDeduction + $philhealthDeduction + $pagibigDeduction;

        // Filter custom deductions (cash advances and others) within the date range
        $customDeductions = Deduction::where('employee_id', $employee->id)
            ->whereBetween('date', [$request->start_date, $request->end_date])
            ->get();

        // Initialize custom deduction totals
        $customDeductionTotal = 0;

        // Calculate total custom deductions
        foreach ($customDeductions as $deduction) {
            $customDeductionTotal += $deduction->amount;
        }

        // Calculate net pay
        $netPay = $grossEarnings - $undertimePenalty - $customDeductionTotal - $totalBenefitsDeduction - ($request->cash_advances ?? 0);

        $employeeid = $request->input('employee_id');



        $payroll = Payroll::create([
            'employee_id' => $employeeid,
            'payroll_date' => now(),
            'days_worked' => $daysWorked,
            'gross_earnings' => $grossEarnings,
            'bonuses' => $request->bonuses ?? 0,
            'cash_advances' => $request->cash_advances ?? 0,
            'late_undertime' => $totalUndertime,
            'sss_deduction' => $sssDeduction,
            'philhealth_deduction' => $philhealthDeduction,
            'pagibig_deduction' => $pagibigDeduction,
            'custom_deductions' => $customDeductionTotal,
            'net_pay' => $netPay,
            'status' => 'Unpaid',
            'notes' => $request->notes,
            'start_date' => $request->start_date,
            'end_date' => $request->end_date,
        ]);

        AuditLog::create([
            'user_id' => auth()->id(),
            'action' => 'Payroll Created',
            'details' => 'Payroll ID: ' . $payroll->id . ' created for employee: ' . $employee->complete_name,
        ]);


        return redirect()->back()->with('success', 'Payroll created successfully.');
    }






    public function show(Payroll $payroll)
    {
        return view('payrolls.show', compact('payroll'));
    }

    public function edit(Payroll $payroll)
    {
        $employees = Employee::all();
        return view('payrolls.edit', compact('payroll', 'employees'));
    }

    public function update(Request $request, Payroll $payroll)
    {
        $request->validate([
            'employee_id' => 'required|exists:employees,id',
            'total_deductions' => 'required|numeric',
            'net_pay' => 'required|numeric',
            'notes' => 'nullable|string',
        ]);

        $payroll->update($request->all());
        return redirect()->back()->with('success', 'Payroll updated successfully.');
    }

    public function destroy(Payroll $payroll)
    {
        $payroll->delete();
        return redirect()->back()->with('success', 'Payroll deleted successfully.');
    }
}
