<?php

namespace App\Http\Controllers;

use App\Models\NewPayment;
use App\Models\Payment;
use App\Models\Waterbill;
use App\Models\Electricbill;
use Illuminate\Http\Request;
use App\Models\Unit;
use App\Models\Property;
use App\Models\Payable;
use App\Services\ReportService;
use Carbon\Carbon;
use App\Exports\MonthlyRevenueExport;
use App\Exports\AttendanceExport;
use App\Exports\ElectricbillExport;
use App\Exports\WaterbillExport;
use App\Exports\CombinedPaymentExport;
use App\Exports\ConsumablesExport;
use App\Exports\InventoryExport;
use App\Exports\PropertyExport;
use Maatwebsite\Excel\Facades\Excel;

use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\DB;

class ReportsController extends Controller
{

    public function accountsReport(Request $request)
    {

        $year = $request->input('year', date('Y'));
        $propertyId = $request->input('property_id', '');

        // Query to get units based on filters
        $query = Unit::query();

        if ($propertyId) {
            $query->where('property_id', $propertyId);
        }

        $units = $query->with('leases.payments')->get();
        $properties = Property::all();

        return view('CMS.Report.accountrecievables', compact('units', 'properties', 'year', 'propertyId'));
    }



    public function monthlyrevenue(Request $request)
    {
        $month = $request->input('month');
        $year = $request->input('year');

        $query = NewPayment::with(['payment.lease.client', 'payment.lease.unit', 'payment.additionalFees']);
        $payablesQuery = Payable::query(); // Query builder for payables

        if ($month && $year) {
            $query->whereMonth('created_at', $month)
                ->whereYear('created_at', $year);
            $payablesQuery->whereMonth('date_of_payable', $month)
                ->whereYear('date_of_payable', $year);
        }

        $newPayments = $query->get();
        $payables = $payablesQuery->get();

        // Aggregate amounts for payables
        $totalWaterBillPayables = $payables->where('category', 'Water')->sum('amount');
        $totalElectricBillPayables = $payables->where('category', 'Electric')->sum('amount');
        $othersPayables = $payables->whereNotIn('category', ['Water', 'Electric'])->sum('amount');

        // Aggregate amounts for new payments
        $totalRentalAmount = $newPayments->sum('rental_amount');
        $totalWaterbillAmount = $newPayments->sum('waterbill_amount');
        $totalElectricbillAmount = $newPayments->sum('electricbill_amount');

        // Calculate total fees amount
        $totalfeesAmount = $newPayments->reduce(function ($carry, $payment) {
            return $carry + $payment->payment->additionalFees->sum('amount_paid');
        }, 0);

        $totalRevenue = $totalRentalAmount + $totalWaterbillAmount + $totalElectricbillAmount;

        // Initialize VAT and withholding tax amounts
        $vatAmount = 0;
        $withholdingTaxAmount = 0;

        // Calculate VAT and withholding tax for all related clients
        foreach ($newPayments as $payment) {
            $client = $payment->payment->lease->client;

            if ($client) {
                $vatApplicable = $client->vat === 'vat';
                $withholdingTaxApplicable = $client->w_holding_tax === 'true';

                $vatRate = 0.12; // 12%
                $withholdingTaxRate = 0.05; // 5%

                $totalPaymentAmount = $payment->rental_amount + $payment->waterbill_amount + $payment->electricbill_amount;

                if ($vatApplicable) {
                    $vatAmount += $totalPaymentAmount * $vatRate;
                }

                if ($withholdingTaxApplicable) {
                    $withholdingTaxAmount += $totalPaymentAmount * $withholdingTaxRate;
                }
            }
        }

        // Calculate total amount due
        $totalAmountDue = $totalRevenue + $vatAmount - $withholdingTaxAmount;

        // Pass data to the view
        return view('CMS.Report.remittancereport', compact(
            'newPayments',
            'payables',
            'totalRentalAmount',
            'totalWaterbillAmount',
            'totalElectricbillAmount',
            'totalWaterBillPayables',
            'totalElectricBillPayables',
            'othersPayables',
            'totalfeesAmount',
            'totalRevenue',
            'vatAmount',
            'withholdingTaxAmount',
            'totalAmountDue'
        ));
    }




    public function combinedReport(Request $request)
    {
        $year = $request->input('year', date('Y'));
        $propertyId = $request->input('property_id', '');
        $reportType = $request->input('report_type', 'monthly'); // Default to 'monthly' if not provided

        // Query to get units based on filters
        $query = Unit::query();

        if ($propertyId) {
            $query->where('property_id', $propertyId);
        }

        $units = $query->with([
            'leases.payments.waterPayments',
            'leases.payments.electricPayments',
            'leases.payments.additionalFees'
        ])->get();
        $properties = Property::all();


        return view('CMS.Report.vat', [
            'units' => $units,
            'properties' => $properties,
            'year' => $year,
            'propertyId' => $propertyId,
            'reportType' => $reportType
        ]);
    }

    public function withholdingTaxReport(Request $request)
    {
        $year = $request->input('year', date('Y'));
        $propertyId = $request->input('property_id', '');
        $reportType = $request->input('report_type', 'monthly'); // Default to 'monthly' if not provided

        // Query to get units based on filters
        $query = Unit::query();

        if ($propertyId) {
            $query->where('property_id', $propertyId);
        }

        $units = $query->with([
            'leases.payments.waterPayments',
            'leases.payments.electricPayments',
            'leases.payments.additionalFees'
        ])->get();
        $properties = Property::all();

        return view('CMS.Report.withholding_tax', [
            'units' => $units,
            'properties' => $properties,
            'year' => $year,
            'propertyId' => $propertyId,
            'reportType' => $reportType
        ]);
    }



    private function getVatQuarterlyReport($year)
    {
        $quarters = [
            1 => ['start' => "$year-01-01", 'end' => "$year-03-31"],
            2 => ['start' => "$year-04-01", 'end' => "$year-06-30"],
            3 => ['start' => "$year-07-01", 'end' => "$year-09-30"],
            4 => ['start' => "$year-10-01", 'end' => "$year-12-31"],
        ];

        $data = collect(); // Initialize as a collection
        foreach ($quarters as $quarter => $dates) {
            $data[$quarter] = Payable::where('category', 'VAT')
                ->whereBetween('date_of_payable', [$dates['start'], $dates['end']])
                ->get();
        }

        return $data;
    }

    private function calculateVatQuarterlyTotals($data)
    {
        // $data is a collection of collections, sum each quarter's amounts
        return $data->map(function ($quarter) {
            return $quarter->sum('amount');
        });
    }

    private function getExpandedWithholdingTaxMonthlyReport($year, $month)
    {
        return Payable::where('category', 'Withholding Tax')
            ->whereYear('date_of_payable', $year)
            ->whereMonth('date_of_payable', $month)
            ->get();
    }

    private function calculateExpandedWithholdingTaxTotals($data)
    {
        return $data->sum('amount');
    }

    public function exportRevenue(Request $request)
    {
        $month = $request->input('month');
        $year = $request->input('year');

        return Excel::download(new MonthlyRevenueExport($month, $year), 'units.xlsx', \Maatwebsite\Excel\Excel::XLSX);
    }
    public function InventoryExport()
    {
        return Excel::download(new InventoryExport, 'InventoryExport.xlsx', \Maatwebsite\Excel\Excel::XLSX);
    }
    public function PropertyExport()
    {
        return Excel::download(new PropertyExport, 'PropertyExport.xlsx', \Maatwebsite\Excel\Excel::XLSX);
    }
    public function E_billExport(Request $request)
    {
        $month = $request->input('month', date('m')); // Default to current month
        $year = $request->input('year', date('Y')); // Default to current year

        return Excel::download(new ElectricbillExport($month, $year), 'ElectricbillExport.xlsx', \Maatwebsite\Excel\Excel::XLSX);
    }
    public function W_billExport(Request $request)
    {
        $month = $request->input('month', date('m')); // Default to current month
        $year = $request->input('year', date('Y')); // Default to current year

        return Excel::download(new WaterbillExport($month, $year), 'WaterbillExport.xlsx', \Maatwebsite\Excel\Excel::XLSX);
    }
    public function exportCombinedPayment(Request $request)
    {
        $month = $request->input('month', date('m')); // Default to current month
        $year = $request->input('year', date('Y')); // Default to current year
        return Excel::download(new CombinedPaymentExport($month, $year), 'Rental.xlsx', \Maatwebsite\Excel\Excel::XLSX);
    }
    public function exportConsumables(Request $request)
    {
        // Retrieve the month and year from the request, default to current month and year if not provided
        $month = $request->input('month', date('m')); // e.g., '08' for August
        $year = $request->input('year', date('Y'));   // e.g., '2024'

        // Validate month and year values
        $validated = $request->validate([
            'month' => 'nullable|integer|min:1|max:12',
            'year' => 'nullable|integer|min:1900|max:2100',
        ]);

        // Download the Excel file with the provided month and year
        return Excel::download(new ConsumablesExport($validated['year'], $validated['month']), 'ConsumablesExport.xlsx');
    }


    public function exportAttendance(Request $request)
    {
        $month = $request->input('month'); // For example: 8 for August
        $year = $request->input('year');   // For example: 2024
        return Excel::download(new AttendanceExport($month, $year), 'attendance.xlsx', \Maatwebsite\Excel\Excel::XLSX);
    }
}
