<?php

namespace App\Http\Controllers;

use App\Models\Electricbill;
use Illuminate\Http\Request;
use Carbon\Carbon;
use App\Models\Waterbill;
use App\Models\Client;
use App\Models\Property;
use Yajra\DataTables\Facades\DataTables;
use Illuminate\Support\Facades\DB;

class UtilitiesController extends Controller
{
    public function index(Request $request)

    {
        $client = Client::leftJoin('lease', 'lease.client_id', '=', 'clients.client_id')
            ->leftJoin('payment', 'payment.lease_id', '=', 'lease.lease_id')
            ->leftJoin('units', 'units.unit_id', '=', 'lease.unit_id')
            ->whereNotNull('payment.payment_id')
            ->orWhereNotNull('lease.lease_id')
            ->get();
        $property = Property::all();
        if ($request->ajax()) {
            $data = Waterbill::with('billing.lease.client', 'billing.lease.unit', 'billing.lease.unit.property')
                ->select(['waterbill_id', 'payment_id', 'location', 'consumption', 'rate', 'amount', 'start_date', 'end_date'])->get();


            return DataTables::of($data)
                ->addColumn('renters', function ($row) {
                    return $row->billing->lease->client->owners_name ?? 'N/A';
                })
                ->addColumn('unit_location', function ($row) {
                    // Check if the unit and property relationships exist before accessing their attributes
                    $unit = $row->billing->lease->unit ?? null;
                    $property = $unit ? $unit->property : null;

                    return $unit && $property ? $unit->unit_name . ' - ' . $property->property_name : 'N/A';
                })
                ->addColumn('date_range', function ($row) {
                    $startDate = Carbon::parse($row->start_date)->format('F j, Y');
                    $endDate = Carbon::parse($row->end_date)->format('F j, Y');
                    return $startDate . ' - ' . $endDate;
                })
                ->addColumn('actions', function ($row) {
                    return '<button onclick="openModaldelete(\'deleteModal' . $row->waterbill_id . '\')" class="px-2 py-1 font-bold text-white bg-red-500 rounded hover:bg-red-700">Delete</button>';
                })
                ->rawColumns(['actions'])
                ->make(true);
        }

        $bill = Waterbill::all();


        return view('CMS.Utilitybills.water', compact('client', 'property', 'bill'));
    }
    public function electricbillview(Request $request)
    {
        $property = Property::all();

        $client = Client::leftJoin('lease', 'lease.client_id', '=', 'clients.client_id')
            ->leftJoin('payment', 'payment.lease_id', '=', 'lease.lease_id')
            ->leftJoin('units', 'units.unit_id', '=', 'lease.unit_id')
            ->whereNotNull('payment.payment_id') // Clients must have payments
            ->orWhereNotNull('lease.lease_id') // Clients with leases connected to payments
            ->distinct('clients.client_id') // Ensure unique clients
            ->get();

        if ($request->ajax()) {
            // Ensure you load necessary relationships for Electricbill
            $data = Electricbill::with('billing.lease.client', 'billing.lease.unit', 'billing.lease.unit.property')
                ->select(['electricbill_id', 'payment_id', 'location', 'consumption', 'rate', 'amount', 'start_date', 'end_date'])
                ->get();

            return DataTables::of($data)
                ->addColumn('renters', function ($row) {
                    return $row->billing->lease->client->owners_name ?? 'N/A';
                })
                ->addColumn('unit_location', function ($row) {
                    // Check if the unit and property relationships exist before accessing their attributes
                    $unit = $row->billing->lease->unit ?? null;
                    $property = $unit ? $unit->property : null;

                    return $unit && $property ? $unit->unit_name . ' - ' . $property->property_name : 'N/A';
                })
                ->addColumn('date_range', function ($row) {
                    $startDate = Carbon::parse($row->start_date)->format('F j, Y');
                    $endDate = Carbon::parse($row->end_date)->format('F j, Y');
                    return $startDate . ' - ' . $endDate;
                })
                ->addColumn('actions', function ($row) {
                    return '<button onclick="openModaldelete(\'deleteModal' . $row->electricbill_id . '\')" class="px-2 py-1 font-bold text-white bg-red-500 rounded hover:bg-red-700">Delete</button>';
                })
                ->rawColumns(['actions'])
                ->make(true);
        }

        $bill = Electricbill::all();

        return view('CMS.Utilitybills.Electric', compact('client', 'property', 'bill'));
    }






    public function store(Request $request)
    {
        // Validate the incoming request data
        $validatedData = $request->validate([
            'payment_id' => 'required|exists:payment,payment_id', // Assuming 'clients' is your clients table
            'location' => 'required|string',
            'consumption' => 'required|string',
            'rate' => 'required|string',
            'amount' => 'required|string',
            'start_date' => 'required|date',
            'end_date' => 'required|date',

        ]);


        Waterbill::create($validatedData);

        // Redirect back to the index page or any other appropriate route
        return redirect()->back()->with('success', 'New Bill created successfully.');
    }
    public function storeelectricbill(Request $request)
    {
        // Validate the incoming request data
        $validatedData = $request->validate([
            'payment_id' => 'required|exists:payment,payment_id', // Assuming 'clients' is your clients table
            'location' => 'required|string',
            'consumption' => 'required|string',
            'rate' => 'required|string',
            'amount' => 'required|string',
            'start_date' => 'required|date',
            'end_date' => 'required|date',

        ]);

        Electricbill::create($validatedData);

        // Redirect back to the index page or any other appropriate route
        return redirect()->back()->with('success', 'New Bill created successfully.');
    }

    public function edit(Waterbill $waterbill)
    {
        return view('waterbills.edit', compact('waterbill'));
    }

    public function update(Request $request, Waterbill $waterbill)
    {
        $waterbill->update($request->all());
        return redirect()->route('waterbills.index');
    }

    public function deletewaterbill($id)
    {
        try {

            DB::table('waterbill')->where('waterbill_id', $id)->delete();

            return redirect()->back()->with('success', 'bill deleted successfully.');
        } catch (\Exception $e) {
            return redirect()->back()->with('error', 'Cannot delete Unit. There are related records in other tables.');
        }
    }
    public function deleteElectricbill($id)
    {
        try {

            DB::table('electricbill')->where('electricbill_id', $id)->delete();

            return redirect()->back()->with('success', 'bill deleted successfully.');
        } catch (\Exception $e) {
            return redirect()->back()->with('error', 'Cannot delete Unit. There are related records in other tables.');
        }
    }
}
