<?php

namespace App\Imports;

use App\Models\Attendance;
use App\Models\Employee;
use Maatwebsite\Excel\Concerns\ToModel;
use Illuminate\Support\Facades\Log;

class AttendanceImport implements ToModel
{
    public function model(array $row)
    {
        // Skip the header row
        if ($this->isHeaderRow($row)) {
            return null;
        }

        // Find the employee by name
        $employee = Employee::where('complete_name', $row[0])->first();

        if (!$employee) {
            // Handle case where employee is not found
            Log::warning('Employee not found: ' . $row[0]);
            return null;
        }

        return new Attendance([
            'employee_id' => $employee->id,
            'date' => \Carbon\Carbon::parse($row[1])->format('Y-m-d'),
            'clock_in' => $row[2],
            'clock_out' => $row[3],
            'hours_worked' => $this->calculateHoursWorked($row[2], $row[3]),
            'notes' => $row[5],
        ]);
    }

    protected function isHeaderRow($row)
    {
        return $row[0] === 'Employee Name' && $row[1] === 'Date'; // Check for your header values
    }

    protected function calculateHoursWorked($clockIn, $clockOut)
    {
        // Ensure clock in and clock out times are in proper format
        $clockInTime = \Carbon\Carbon::createFromFormat('H:i:s', $clockIn);
        $clockOutTime = \Carbon\Carbon::createFromFormat('H:i:s', $clockOut);

        // Calculate the difference between clock in and clock out
        $diff = $clockInTime->diff($clockOutTime);

        // Return the total hours and minutes as a decimal
        return $diff->h + ($diff->i / 60);
    }
}
