<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Carbon\Carbon;

class Lease extends Model
{
    use HasFactory;

    protected $table = 'lease'; // Assuming your table name is 'leases', adjust if necessary
    protected $primaryKey = 'lease_id';
    protected $fillable = [
        'property_id', 'client_id', 'unit_id', 'lease_start_date', 'lease_duration',
        'utilities', 'rules_and_regulations', 'terms', 'contract_type', 'yearly_escalation', 'status',
        'security_deposit', 'business_start', 'relief_rental', 'rent_amount'
    ];

    public function property()
    {
        return $this->belongsTo(Property::class, 'property_id', 'id');
    }

    public function client()
    {
        return $this->belongsTo(Client::class, 'client_id', 'client_id');
    }

    public function unit()
    {
        return $this->belongsTo(Unit::class, 'unit_id', 'unit_id');
    }

    public function payments()
    {
        return $this->hasMany(Payment::class, 'lease_id', 'lease_id');
    }
    public function newpayments()
    {
        return $this->hasMany(NewPayment::class, 'lease_id', 'lease_id');
    }



    public function scopeVacantUnits($query)
    {
        return $query->whereHas('unit', function ($query) {
            $query->where('status', 'Vacant');
        });
    }
}
