<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;
use Illuminate\Support\Facades\DB;

return new class extends Migration
{
    /**
     * Run the migrations.
     *
     * @return void
     */
    public function up()
    {
        Schema::create('lease', function (Blueprint $table) {
            $table->id('lease_id');
            $table->unsignedBigInteger('property_id');
            $table->unsignedBigInteger('client_id');
            $table->unsignedBigInteger('unit_id');
            $table->foreign('property_id')->references('id')->on('properties')->onDelete('cascade');
            $table->foreign('client_id')->references('client_id')->on('clients')->onDelete('cascade');
            $table->foreign('unit_id')->references('unit_id')->on('units')->onDelete('cascade');
            $table->string('lease_start_date');
            $table->string('lease_duration');
            $table->text('utilities')->nullable();
            $table->text('rules_and_regulations')->nullable();
            $table->text('terms')->nullable();
            $table->string('contract_type')->nullable();
            $table->string('yearly_escalation')->nullable();
            $table->string('status')->nullable();
            $table->string('rent_amount')->nullable();
            $table->string('security_deposit')->nullable();
            $table->date('business_start')->nullable();
            $table->string('relief_rental')->nullable();
            $table->timestamps();
        });
        Schema::create('payment', function (Blueprint $table) {
            $table->id('payment_id');
            $table->unsignedBigInteger('lease_id');
            $table->foreign('lease_id')->references('lease_id')->on('lease')->onDelete('cascade');
            $table->string('Amount');
            $table->date('payment_date');
            $table->string('status');
            $table->string('billing_notes')->nullable();
            $table->timestamps();
        });

        Schema::create('newpayment', function (Blueprint $table) {
            $table->id('newpayment_id');
            $table->unsignedBigInteger('payment_id');
            $table->foreign('payment_id')->references('payment_id')->on('payment')->onDelete('cascade');
            $table->string('payment_method')->nullable();
            $table->string('bank')->nullable();
            $table->string('advance_payment')->nullable();
            $table->string('rental_amount')->nullable();
            $table->string('waterbill_amount')->nullable();
            $table->string('electricbill_amount')->nullable();
            $table->string('status')->nullable();
            $table->string('remarks')->nullable();
            $table->string('check_no')->nullable();


            $table->timestamps();
        });

        Schema::create('additionalfees', function (Blueprint $table) {
            $table->id();
            $table->unsignedBigInteger('billing_id');
            $table->foreign('billing_id')->references('payment_id')->on('payment')->onDelete('cascade');
            $table->string('charge_type')->nullable();
            $table->decimal('amount', 10, 2)->nullable();
            $table->decimal('amount_paid', 10, 2)->nullable();
            $table->text('notes')->nullable()->nullable();
            $table->date('date_of_payable')->nullable();
            $table->timestamps();
        });


        DB::statement('ALTER TABLE payment AUTO_INCREMENT = 100;');
        DB::statement('ALTER TABLE newpayment AUTO_INCREMENT = 100000;');
    }

    /**
     * Reverse the migrations.
     *
     * @return void
     */
    public function down()
    {
        //
    }
};
