<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class extends Migration
{
    /**
     * Run the migrations.
     *
     * @return void
     */
    public function up()
    {
        // Create Employees Table
        Schema::create('employees', function (Blueprint $table) {
            $table->id(); // employee_id
            $table->string('complete_name');
            $table->string('address')->nullable();
            $table->string('contact_no')->nullable(); // Fixed column name
            $table->decimal('salary_rate', 10, 2);
            $table->string('position')->nullable();
            $table->date('date_hired');
            $table->string('employee_type');
            $table->string('clearance')->nullable(); // Assuming this will store the file path

            $table->timestamps();
        });



        Schema::create('deductions', function (Blueprint $table) {
            $table->id();
            $table->foreignId('employee_id')->constrained('employees')->onDelete('cascade'); // Foreign key
            $table->string('benefit_name')->nullable();
            $table->decimal('amount', 10, 2)->default(0);
            $table->date('date');
            $table->timestamps();
        });




        Schema::create('loans', function (Blueprint $table) {
            $table->id(); // loan_id
            $table->foreignId('employee_id')->constrained('employees')->onDelete('cascade'); // Foreign key
            $table->decimal('loan_amount', 10, 2)->default(0);
            $table->decimal('repayment_amount', 10, 2)->default(0);
            $table->timestamps();
        });


        Schema::create('payroll', function (Blueprint $table) {
            $table->id();
            $table->foreignId('employee_id')->constrained('employees')->onDelete('cascade'); // Foreign key
            $table->date('payroll_date');
            $table->integer('days_worked');
            $table->decimal('gross_earnings', 10, 2);
            $table->decimal('bonuses', 10, 2)->default(0);
            $table->decimal('cash_advances', 10, 2)->default(0);
            $table->decimal('sss_deduction', 10, 2)->default(0); // SSS Deduction
            $table->decimal('philhealth_deduction', 10, 2)->default(0); // PhilHealth Deduction
            $table->decimal('pagibig_deduction', 10, 2)->default(0); // Pag-IBIG Deduction
            $table->decimal('custom_deductions', 10, 2)->default(0); // Custom Deductions
            $table->decimal('late_undertime', 10, 2)->default(0); // Convert to decimal for better calculation
            $table->decimal('net_pay', 10, 2);
            $table->enum('status', ['Unpaid', 'Paid'])->default('Unpaid');
            $table->text('notes')->nullable();
            $table->date('start_date')->nullable();
            $table->date('end_date')->nullable();
            $table->timestamps();
        });


        Schema::create('attendances', function (Blueprint $table) {
            $table->id();
            $table->foreignId('employee_id')->constrained('employees')->onDelete('cascade'); // Foreign key
            $table->date('date');
            $table->time('clock_in')->nullable();
            $table->time('clock_out')->nullable();
            $table->string('hours_worked')->nullable(); // Optional, can be computed
            $table->text('notes')->nullable();
            $table->timestamps();
        });
    }


    public function down()
    {
        Schema::dropIfExists('payroll');
        Schema::dropIfExists('loans');
        Schema::dropIfExists('deductions');
        Schema::dropIfExists('earnings');
        Schema::dropIfExists('employees');
    }
};
