@extends('layouts.sidebar') <!-- Use your layout template as per your application setup -->

@section('content')
    <div class=" containe mx-80">
        <div class="text-center">
            <h2 class="mb-4 text-3xl font-bold">Add lease</h2>
            @if (session('success'))
                <div class="text-center text-red-900 alert alert-success">
                    {{ session('success') }}
                </div>
            @endif
            <form method="POST" action="{{ route('lease.store') }}" class="p-6 bg-white rounded">
                @csrf
                <input type="hidden" id="property_id" name="property_id"
                    value="{{ old('property_id', $clientmain->property->id) }}">
                <input type="hidden" id="unit_id" name="unit_id" value="{{ old('unit_id', $clientmain->unit_id) }}">

                <div class="overflow-x-auto">
                    <table class="w-full border-collapse border border-gray-200">
                        <thead>
                            <tr class="bg-gray-100 text-left">
                                <th class="px-4 py-2 border border-gray-300">Field</th>
                                <th class="px-4 py-2 border border-gray-300">Value</th>
                            </tr>
                        </thead>
                        <tbody>
                            <tr>
                                <td class="px-4 py-2 border border-gray-300 font-bold">Tenant Name:</td>
                                <td class="px-4 py-2 border border-gray-300">
                                    <select id="client_id" name="client_id"
                                        class="w-full px-3 py-2 leading-tight text-gray-700 border border-gray-300 rounded shadow-sm focus:outline-none focus:shadow-outline"
                                        required>
                                        <option value="">Select Client</option>
                                        @foreach ($clients as $client)
                                            <option value="{{ $client->client_id }}"
                                                {{ old('client_id') == $client->client_id ? 'selected' : '' }}>
                                                {{ $client->owners_name }}
                                            </option>
                                        @endforeach
                                    </select>
                                    @error('client_id')
                                        <p class="text-red-500 text-sm mt-1">{{ $message }}</p>
                                    @enderror
                                </td>
                            </tr>
                            <tr>
                                <td class="px-4 py-2 border border-gray-300 font-bold">Lease Start Date:</td>
                                <td class="px-4 py-2 border border-gray-300">
                                    <input type="date" id="lease_start_date" name="lease_start_date"
                                        class="w-full px-3 py-2 leading-tight text-gray-700 border border-gray-300 rounded shadow-sm focus:outline-none focus:shadow-outline"
                                        value="{{ old('lease_start_date') }}" required>
                                    @error('lease_start_date')
                                        <p class="text-red-500 text-sm mt-1">{{ $message }}</p>
                                    @enderror
                                </td>
                            </tr>
                            <tr>
                                <td class="px-4 py-2 border border-gray-300 font-bold">Contract Type:</td>
                                <td class="px-4 py-2 border border-gray-300">
                                    <select id="rate_type" name="rate_type"
                                        class="w-full px-3 py-2 leading-tight text-gray-700 border border-gray-300 rounded shadow-sm focus:outline-none focus:shadow-outline">
                                        <option value="" disabled selected>Select Contract Type</option>
                                        <option value="Daily" {{ old('rate_type') == 'Daily' ? 'selected' : '' }}>Daily
                                        </option>
                                        <option value="Weekly" {{ old('rate_type') == 'Weekly' ? 'selected' : '' }}>Weekly
                                        </option>
                                        <option value="Monthly" {{ old('rate_type') == 'Monthly' ? 'selected' : '' }}>
                                            Monthly</option>
                                    </select>
                                    @error('rate_type')
                                        <p class="text-red-500 text-sm mt-1">{{ $message }}</p>
                                    @enderror
                                </td>
                            </tr>
                            <tr>
                                <td class="px-4 py-2 border border-gray-300 font-bold">Lease Duration:</td>
                                <td class="px-4 py-2 border border-gray-300">
                                    <input type="number" id="lease_duration" name="lease_duration"
                                        class="w-full px-3 py-2 leading-tight text-gray-700 border border-gray-300 rounded shadow-sm focus:outline-none focus:shadow-outline"
                                        placeholder="Enter Duration" value="{{ old('lease_duration') }}" required>
                                    @error('lease_duration')
                                        <p class="text-red-500 text-sm mt-1">{{ $message }}</p>
                                    @enderror
                                </td>
                            </tr>
                            <tr>
                                <td class="px-4 py-2 border border-gray-300 font-bold">Rent Amount:</td>
                                <td class="px-4 py-2 border border-gray-300">
                                    <input type="text" id="payment_amount" name="payment_amount"
                                        class="w-full px-3 py-2 leading-tight text-gray-700 border border-gray-300 rounded shadow-sm focus:outline-none focus:shadow-outline"
                                        placeholder="Enter Monthly Rent Amount"
                                        value="{{ old('payment_amount', $clientmain->rate_type == 'Per Square Meter' ? $clientmain->rate * $clientmain->size : $clientmain->rate) }}">
                                    @error('payment_amount')
                                        <p class="text-red-500 text-sm mt-1">{{ $message }}</p>
                                    @enderror
                                </td>
                            </tr>
                            <tr>
                                <td class="px-4 py-2 border border-gray-300 font-bold">Yearly Escalation:</td>
                                <td class="px-4 py-2 border border-gray-300">
                                    <input type="number" id="yearly_escalation" name="yearly_escalation"
                                        class="w-full px-3 py-2 leading-tight text-gray-700 border border-gray-300 rounded shadow-sm focus:outline-none focus:shadow-outline"
                                        placeholder="Yearly Escalation" value="{{ old('yearly_escalation') }}">
                                    @error('yearly_escalation')
                                        <p class="text-red-500 text-sm mt-1">{{ $message }}</p>
                                    @enderror
                                </td>
                            </tr>
                            <tr>
                                <td class="px-4 py-2 border border-gray-300 font-bold">Terms:</td>
                                <td class="px-4 py-2 border border-gray-300">
                                    <input type="number" id="terms" name="terms"
                                        class="w-full px-3 py-2 leading-tight text-gray-700 border border-gray-300 rounded shadow-sm focus:outline-none focus:shadow-outline"
                                        placeholder="Terms" value="{{ old('terms') }}">
                                    @error('terms')
                                        <p class="text-red-500 text-sm mt-1">{{ $message }}</p>
                                    @enderror
                                </td>
                            </tr>
                            <tr>
                                <td class="px-4 py-2 border border-gray-300 font-bold">Business Start Date:</td>
                                <td class="px-4 py-2 border border-gray-300">
                                    <input type="date" id="business_start_date" name="business_start"
                                        class="w-full px-3 py-2 leading-tight text-gray-700 border border-gray-300 rounded shadow-sm focus:outline-none focus:shadow-outline"
                                        placeholder="Business Start Date" value="{{ old('business_start') }}">
                                    @error('business_start')
                                        <p class="text-red-500 text-sm mt-1">{{ $message }}</p>
                                    @enderror
                                </td>
                            </tr>
                            <tr>
                                <td class="px-4 py-2 border border-gray-300 font-bold">Annual (Rental Relief):</td>
                                <td class="px-4 py-2 border border-gray-300">
                                    <input type="text" id="relief_rental" name="relief_rental"
                                        class="w-full px-3 py-2 leading-tight text-gray-700 border border-gray-300 rounded shadow-sm focus:outline-none focus:shadow-outline"
                                        placeholder="" value="{{ old('relief_rental') }}">
                                    @error('relief_rental')
                                        <p class="text-red-500 text-sm mt-1">{{ $message }}</p>
                                    @enderror
                                </td>
                            </tr>
                            <tr>
                                <td class="px-4 py-2 border border-gray-300 font-bold">Security Deposit:</td>
                                <td class="px-4 py-2 border border-gray-300">
                                    <input type="text" id="security_deposit" name="security_deposit"
                                        class="w-full px-3 py-2 leading-tight text-gray-700 border border-gray-300 rounded shadow-sm focus:outline-none focus:shadow-outline"
                                        placeholder="Deposit" value="{{ old('security_deposit') }}">
                                    @error('security_deposit')
                                        <p class="text-red-500 text-sm mt-1">{{ $message }}</p>
                                    @enderror
                                </td>
                            </tr>
                            <tr>
                                <td class="px-4 py-2 border border-gray-300 font-bold">Utilities:</td>
                                <td class="px-4 py-2 border border-gray-300">
                                    <textarea id="utilities" name="utilities" rows="3"
                                        class="w-full px-3 py-2 text-gray-700 border border-gray-300 rounded-md shadow-sm focus:outline-none focus:ring-indigo-500 focus:border-indigo-500">{{ old('utilities') }}</textarea>
                                    @error('utilities')
                                        <p class="text-red-500 text-sm mt-1">{{ $message }}</p>
                                    @enderror
                                </td>
                            </tr>
                            <tr>
                                <td class="px-4 py-2 border border-gray-300 font-bold">Rules and Regulations:</td>
                                <td class="px-4 py-2 border border-gray-300">
                                    <textarea id="rules" name="rules_and_regulations" rows="3"
                                        class="w-full px-3 py-2 text-gray-700 border border-gray-300 rounded-md shadow-sm focus:outline-none focus:ring-indigo-500 focus:border-indigo-500">{{ old('rules_and_regulations') }}</textarea>
                                    @error('rules_and_regulations')
                                        <p class="text-red-500 text-sm mt-1">{{ $message }}</p>
                                    @enderror
                                </td>
                            </tr>
                            <tr>
                                <td class="px-4 py-2 border border-gray-300 font-bold">Payment Schedule:</td>
                                <td class="px-4 py-2 border border-gray-300">
                                    <div id="payment_schedule"
                                        class="w-full h-40 px-3 py-2 overflow-x-auto text-gray-700 border border-gray-300 rounded shadow-sm">
                                        <!-- Payment schedule content here -->
                                    </div>
                                </td>
                            </tr>
                        </tbody>
                    </table>
                </div>

                <!-- Submit Button -->
                <div class="mt-4">
                    <button type="submit" class="w-full px-4 py-2 text-white bg-blue-500 rounded hover:bg-blue-700">Save
                        Lease Agreement</button>
                </div>
            </form>


            <a href="{{ url('/lease', $clientmain->unit_id) }}"
                class="inline-block px-4 py-2 mt-4 text-white bg-blue-500 rounded hover:bg-blue-700">Go to list</a>
        </div>
    </div>
    @extends('CMS.unitmodal.modal')
@endsection
