@extends('layouts.sidebar')

@section('content')
    <style>
        @media print {
            body * {
                visibility: hidden;
            }

            .print-content,
            .print-content * {
                visibility: visible;
                font-size: 10px;
                /* Adjust the font size as needed */
            }

            .print-content {
                position: absolute;
                left: 0;
                top: 0;
                width: 210mm;
                /* A4 width */
                height: 350mm;
                /* A4 height */
                padding: 10mm;
                /* Add padding to simulate margin */
                box-sizing: border-box;
            }

            .print-content table td,
            .print-content table th {
                padding: 2px;
                /* Adjust the padding as needed */
            }
        }
    </style>
    <div class="max-w-4xl p-8 mx-auto text-sm bg-white border border-gray-200 shadow-lg print-content">
        <div class="mb-8 text-center">
            <h1 class="text-xl font-bold">San Roque Hermanas Inc.</h1>
            <p class="text-gray-700">MGR BLDG. II, Matina Crossing, Davao City</p>
            <p class="text-gray-700">Tel: (082)299-4103</p>
            <p class="text-gray-700">Cell # 0910-651-1604</p>
        </div>

        <div class="mb-8">
            <h2 class="pb-2 mb-4 text-lg font-semibold border-b">Foreclosure Notice</h2>
            <p class="mb-4 text-gray-700">Date: {{ now()->format('F j, Y') }}</p>
        </div>

        <div class="mb-8">
            <p class="font-semibold">To:</p>
            <p class="text-gray-700">{{ $lease->client->business_name }}</p>
            <p class="text-gray-700">{{ $lease->unit->unit_name }}</p>
            <p class="text-gray-700">{{ $lease->property->street_address }}, {{ $lease->property->city }},
                {{ $lease->property->state }}, {{ $lease->property->zip }}</p>
        </div>

        <div class="mb-8">
            <p class="text-gray-700">Sir / Madam:</p>
            <p class="mt-4 text-gray-700">This is to inform you of your unpaid monthly rentals and utility bills as detailed
                below:</p>
        </div>

        <table class="w-full mt-4 border border-collapse border-gray-300">
            <thead>
                <tr class="bg-gray-200">
                    <th class="px-4 py-2 text-left border border-gray-300">Billing No.</th>
                    <th class="px-4 py-2 text-left border border-gray-300">Description</th>
                    <th class="px-4 py-2 text-right border border-gray-300">Amount</th>
                </tr>
            </thead>
            <tbody>
                @php
                    $totalAmount = 0;
                    $vatAmount = 0;
                    $withholdingTaxAmount = 0;
                @endphp

                @foreach ($lease->payments as $payment)
                    @php
                        $dueDate = $payment->payment_date->copy()->addDays($payment->lease->terms);
                        $isPastDue = now()->isAfter($dueDate);
                        $monthsPastDue = $isPastDue ? now()->diffInMonths($dueDate) : 0;
                        $penalty = $payment->Amount * 0.02 * $monthsPastDue;
                        $totalAmount += $payment->Amount + $penalty;
                    @endphp
                    <tr>
                        <td class="px-4 py-2 border border-gray-300">
                            Billing No. {{ $payment->payment_id }}
                        </td>
                        <td class="px-4 py-2 border border-gray-300">
                            Rent Due for
                            ({{ $payment->payment_date->format('M d, Y') }} -
                            {{ $dueDate->format('M d, Y') }})
                        </td>
                        <td class="px-4 py-2 text-right border border-gray-300">
                            {{ number_format($payment->Amount, 2) }}
                        </td>
                    </tr>

                    @foreach ($payment->electricPayments as $electricPayment)
                        <tr>
                            <td class="px-4 py-2 border border-gray-300"></td>
                            <td class="px-4 py-2 border border-gray-300">Electric Bill
                                ({{ $electricPayment->start_date->format('M d, Y') }} -
                                {{ $electricPayment->end_date->format('M d, Y') }})
                            </td>
                            <td class="px-4 py-2 text-right border border-gray-300">
                                {{ number_format($electricPayment->amount, 2) }}
                            </td>
                        </tr>
                        @php
                            $totalAmount += $electricPayment->amount;
                        @endphp
                    @endforeach

                    @foreach ($payment->waterPayments as $waterPayment)
                        <tr>
                            <td class="px-4 py-2 border border-gray-300"></td>
                            <td class="px-4 py-2 border border-gray-300">Water Bill
                                ({{ $waterPayment->start_date->format('M d, Y') }} -
                                {{ $waterPayment->end_date->format('M d, Y') }})
                            </td>
                            <td class="px-4 py-2 text-right border border-gray-300">
                                {{ number_format($waterPayment->amount, 2) }}
                            </td>
                        </tr>
                        @php
                            $totalAmount += $waterPayment->amount;
                        @endphp
                    @endforeach

                    @foreach ($payment->additionalFees as $fee)
                        <tr>
                            <td class="px-4 py-2 border border-gray-300"></td>
                            <td class="px-4 py-2 border border-gray-300">Additional Fee: {{ $fee->notes }}</td>
                            <td class="px-4 py-2 text-right border border-gray-300">
                                {{ number_format($fee->amount, 2) }}
                            </td>
                        </tr>
                        @php
                            $totalAmount += $fee->amount;
                        @endphp
                    @endforeach

                    @if ($isPastDue)
                        <tr>
                            <td class="px-4 py-2 border border-gray-300"></td>
                            <td class="px-4 py-2 border border-gray-300">Penalty for {{ $monthsPastDue }} month(s) past
                                due</td>
                            <td class="px-4 py-2 text-right border border-gray-300">
                                {{ number_format($penalty, 2) }}
                            </td>
                        </tr>
                    @endif
                @endforeach

                <tr class="font-bold">
                    <td class="px-4 py-2 border border-gray-300"></td>
                    <td class="px-4 py-2 border border-gray-300">Total Payables</td>
                    <td class="px-4 py-2 text-right border border-gray-300">
                        {{ number_format($totalAmount, 2) }}
                    </td>
                </tr>

                @if ($lease->client->vat === 'vat')
                    @php
                        // Calculate VAT amount (assuming VAT rate is 12%)
                        $vatAmount = $totalAmount * 0.12;
                        $totalAmountWithVAT = $totalAmount + $vatAmount;
                    @endphp
                    <tr class="font-bold">
                        <td class="px-4 py-2 border border-gray-300"></td>
                        <td class="px-4 py-2 border border-gray-300">VAT (12%)</td>
                        <td class="px-4 py-2 text-right border border-gray-300">
                            {{ number_format($vatAmount, 2) }}
                        </td>
                    </tr>
                    <tr class="font-bold">
                        <td class="px-4 py-2 border border-gray-300"></td>
                        <td class="px-4 py-2 border border-gray-300">Total Amount with VAT</td>
                        <td class="px-4 py-2 text-right border border-gray-300">
                            {{ number_format($totalAmountWithVAT, 2) }}
                        </td>
                    </tr>
                @else
                    @php
                        $totalAmountWithVAT = $totalAmount;
                    @endphp
                    <tr class="font-bold">
                        <td class="px-4 py-2 border border-gray-300"></td>
                        <td class="px-4 py-2 border border-gray-300">Total Amount</td>
                        <td class="px-4 py-2 text-right border border-gray-300">
                            {{ number_format($totalAmountWithVAT, 2) }}
                        </td>
                    </tr>
                @endif

                @if ($lease->client->w_holding_tax === 'true')
                    @php
                        // Calculate withholding tax (assuming withholding tax rate is 2%)
                        $withholdingTaxAmount = $totalAmount * 0.05;
                        $totalAmountAfterWithholdingTax = $totalAmountWithVAT - $withholdingTaxAmount;
                    @endphp
                    <tr class="font-bold">
                        <td class="px-4 py-2 border border-gray-300"></td>
                        <td class="px-4 py-2 border border-gray-300">Withholding Tax (5%)</td>
                        <td class="px-4 py-2 text-right border border-gray-300">
                            {{ number_format($withholdingTaxAmount, 2) }}
                        </td>
                    </tr>
                    <tr class="font-bold">
                        <td class="px-4 py-2 border border-gray-300"></td>
                        <td class="px-4 py-2 border border-gray-300">Total Amount after Withholding Tax</td>
                        <td class="px-4 py-2 text-right border border-gray-300">
                            {{ number_format($totalAmountAfterWithholdingTax, 2) }}
                        </td>
                    </tr>
                @else
                    @php
                        $totalAmountAfterWithholdingTax = $totalAmountWithVAT;
                    @endphp
                @endif
            </tbody>
        </table>

        <div class="mb-8">
            <p class="mb-4 text-gray-700">Note:</p>
            @foreach ($lease->payments ?? collect() as $payment)
                @if ($payment->is_bounced_check)
                    <p class="text-gray-700">{{ $payment->description }} {{ number_format($payment->amount, 2) }}</p>
                @endif
            @endforeach
        </div>

        <div class="mb-8">
            <p class="text-gray-700">It is stipulated in the Contract of Lease that in the event the LESSEE fails to pay two
                (2) monthly rental payments, the LESSOR is hereby authorized, and the LESSEE agrees, to padlock the leased
                premises without incurring any liability, civil or criminal. It must also be stated here that your security
                deposit with Us cannot be applied to or answer for any unpaid monthly rentals, electricity or water bills at
                this time.</p>
            <p class="mt-4 text-gray-700">Accordingly, we demand that you pay in cash or issue checks in the total amount as
                shown above on or before ________________ from receipt of this notice. Otherwise, much to our regret, we
                will be constrained to take appropriate action against you which includes the possible padlocking of your
                premises and/or cutting off your water or electricity connection with Us, without prejudice to other further
                actions as may be allowed by law.</p>
        </div>

        <div class="flex justify-between mt-8">
            <div>
                <p class="font-semibold">Prepared by:</p>
                <p class="text-gray-700">Theresa G. Sabate</p>
                <p class="text-gray-700">Admin Staff</p>
            </div>
            <div>
                <p class="font-semibold">Noted by:</p>
                <p class="text-gray-700">Heracleo S. Roque</p>
                <p class="text-gray-700">Lessor</p>
            </div>
        </div>

        <div class="mt-8">
            <p class="font-semibold">Received By:</p>
            <p class="text-gray-700">________________________</p>
            <p class="text-gray-700">Signature over Printed Name</p>
        </div>
    </div>
    <div class="mt-4 text-center">
        <button onclick="window.print()" class="px-4 py-2 font-bold text-white bg-blue-500 rounded hover:bg-blue-700">
            Print Statement
        </button>
    </div>
@endsection
