@extends('layouts.sidebar')

@section('content')
    <style>
        @media print {
            body * {
                visibility: hidden;
            }

            .print-content,
            .print-content * {
                visibility: visible;
                font-size: 10px;
                /* Maintain small font size */
            }

            .print-content {
                position: absolute;
                left: 0;
                top: 0;
                width: 210mm;
                /* A4 width */
                height: 297mm;
                /* A4 height */
                padding: 10mm;
                /* Reduce padding to create more space */
                box-sizing: border-box;
                margin: 0;
                /* Remove default margin */
            }

            .print-header {
                font-size: 10px;
                /* Smaller font size for header */
                font-weight: bold;
                margin-bottom: 2mm;
                /* Minimal bottom margin for header */
                text-align: center;
            }

            .print-content table {
                width: 100%;
                border-collapse: collapse;
            }

            .print-content table th,
            .print-content table td {
                padding: 2px;
                /* Keep padding compact */
                border: 1px solid black;
                /* Maintain border for clarity */
                text-align: left;
            }

            .print-footer {
                position: fixed;
                bottom: 5mm;
                /* Reduce margin at bottom */
                width: 100%;
                text-align: center;
                font-size: 10px;
                margin-top: 2mm;
                /* Minimize space above the footer */
            }
        }
    </style>
    @php
        $vatAmount = 0;
        $withholdingTaxAmount = 0;
        $dueDate = $data->payment_date->copy()->addDays($data->lease->terms);
        $isPastDue = now()->isAfter($dueDate);
        $monthsPastDue = $isPastDue ? now()->diffInMonths($dueDate) : 0;
        $penalty = $data->Amount * 0.02 * $monthsPastDue;
        if ($data->lease->client->vat === 'vat') {
            $subtotal = $data->Amount + $totalElectricAmount + $totalWaterAmount + $additional;
            $vatAmount = $subtotal * 0.12;
        }

        if ($data->lease->client->w_holding_tax === 'true') {
            $withholdingTaxAmount = $subtotal * 0.05;
        }

        $subtotal = $data->Amount + $totalElectricAmount + $totalWaterAmount + $additional;
        $grandTotal = $subtotal + $vatAmount - $withholdingTaxAmount + $penalty;
    @endphp

    <div class="max-w-4xl p-8 mx-auto mt-8 text-sm text-gray-800 bg-white rounded shadow-lg print-content">
        <div class="text-center mb-4">
            <h1 class="text-xl font-bold">INVOICE</h1>
        </div>
        <div class="mb-4">
            <p class="font-bold">San Roque Hermanas Inc.</p>
            <p>MGR BLDG. II, Matina Crossing, Davao City</p>
            <p>Email: srhimgr@yahoo.com | Tel: (082)299-4103 | Cell #: 0910-651-1604 | TIN: 006-040-261</p>
        </div>
        <div class="mb-4">
            <p><span class="font-bold">Invoice Number:</span> {{ $data->invoice_number }}</p>
            <p><span class="font-bold">Invoice Date:</span> {{ date('F j, Y', strtotime($data->payment_date)) }}</p>
            <p><span class="font-bold">Due Date:</span> {{ date('F j, Y', strtotime($dueDate)) }}</p>
        </div>
        <div class="mb-4">
            <p class="font-bold">Bill To:</p>
            <p>{{ $data->lease->client->owners_name }}</p>
            <p>{{ $data->lease->property->street_address }}</p>
            <p>{{ $data->lease->property->city }}</p>
        </div>
        <table class="w-full border border-gray-400 mb-4">
            <thead>
                <tr>
                    <th class="border-b px-2 py-1 text-left">Description</th>
                    <th class="border-b px-2 py-1 text-left">Quantity</th>
                    <th class="border-b px-2 py-1 text-left">Unit Price</th>
                    <th class="border-b px-2 py-1 text-left">Total</th>
                </tr>
            </thead>
            <tbody>
                <tr>
                    <td class="border-b px-2 py-1">Advance Payment Last Advanced</td>
                    <td class="border-b px-2 py-1"></td>
                    <td class="border-b px-2 py-1"></td>
                    <td class="border-b px-2 py-1">₱{{ number_format($advance_payment, 2) }}</td>
                </tr>
                <tr>
                    <td class="border-b px-2 py-1">Previous Balance</td>
                    <td class="border-b px-2 py-1"></td>
                    <td class="border-b px-2 py-1"></td>
                    <td class="border-b px-2 py-1">₱{{ number_format($currentRentalBalance, 2) }}</td>
                </tr>
                <tr>
                    <td class="border-b px-2 py-1">Payments Received</td>
                    <td class="border-b px-2 py-1"></td>
                    <td class="border-b px-2 py-1"></td>
                    <td class="border-b px-2 py-1">₱{{ number_format($Amountpaid, 2) }}</td>
                </tr>
                <tr>
                    <td class="border-b px-2 py-1">Current Charges</td>
                    <td class="border-b px-2 py-1"></td>
                    <td class="border-b px-2 py-1"></td>
                    <td class="border-b px-2 py-1">
                        ₱{{ number_format($data->amount + $totalWaterAmount + $totalElectricAmount + $additional, 2) }}</td>
                </tr>
                @if ($data->lease->client->vat === 'vat')
                    <tr>
                        <td class="border-b px-2 py-1">VAT (12%)</td>
                        <td class="border-b px-2 py-1"></td>
                        <td class="border-b px-2 py-1"></td>
                        <td class="border-b px-2 py-1">₱{{ number_format($vatAmount, 2) }}</td>
                    </tr>
                @endif
                @if ($data->lease->client->w_holding_tax === 'true')
                    <tr>
                        <td class="border-b px-2 py-1">Withholding Tax (5%)</td>
                        <td class="border-b px-2 py-1"></td>
                        <td class="border-b px-2 py-1"></td>
                        <td class="border-b px-2 py-1">₱{{ number_format($withholdingTaxAmount, 2) }}</td>
                    </tr>
                @endif
                @if ($penalty > 0)
                    <tr>
                        <td class="border-b px-2 py-1">Penalty</td>
                        <td class="border-b px-2 py-1"></td>
                        <td class="border-b px-2 py-1"></td>
                        <td class="border-b px-2 py-1">₱{{ number_format($penalty, 2) }}</td>
                    </tr>
                @endif
                <tr>
                    <td colspan="3" class="font-bold text-right border-t py-2">Total Amount Due:</td>
                    <td class="font-bold text-left border-t py-2">₱{{ number_format($grandTotal, 2) }}</td>
                </tr>
            </tbody>
        </table>
        <div class="mb-4">
            <p class="font-bold">Payment Instructions:</p>
            <p>Please make payment to the following bank account:</p>
            <p>Bank: XYZ Bank</p>
            <p>Account Number: 123-456-789</p>
            <p>Account Name: San Roque Hermanas Inc.</p>
        </div>
        <div class="mb-4">
            <p class="font-bold">Notes:</p>
            <p>{{ $data->billing_notes }}</p>
        </div>
        <div class="text-center">
            <p class="mt-4">Thank you for your prompt payment.</p>
            <p>Sincerely,</p>
            <p>San Roque Hermanas Inc.</p>
        </div>
    </div>

    <div class="mt-4 text-center">
        <button onclick="window.print()" class="px-4 py-2 font-bold text-white bg-blue-500 rounded hover:bg-blue-700">
            Print Invoice
        </button>
    </div>
@endsection
