@extends('layouts.sidebar')

@section('content')
    <div class="mb-6">
        <form action="{{ route('payables.report') }}" method="GET" class="flex justify-center space-x-4">
            <!-- Type Filter -->
            <select id="filterType" name="type"
                class="text-sm text-gray-600 border-2 border-gray-300 rounded-md shadow-sm focus:border-blue-500 focus:ring focus:ring-blue-500 focus:ring-opacity-50"
                onchange="handleFilterTypeChange()">
                <option value="">Select Type</option>
                <option value="Monthly" {{ request('type') == 'Monthly' ? 'selected' : '' }}>Monthly</option>
                <option value="Quarterly" {{ request('type') == 'Quarterly' ? 'selected' : '' }}>Quarterly</option>
                <option value="Annual" {{ request('type') == 'Annual' ? 'selected' : '' }}>Annual</option>
            </select>

            <!-- Month Filter -->
            <select id="monthFilter" name="month"
                class="text-sm text-gray-600 border-2 border-gray-300 rounded-md shadow-sm focus:border-blue-500 focus:ring focus:ring-blue-500 focus:ring-opacity-50"
                style="display: none;">
                <option value="">Select Month</option>
                @foreach (range(1, 12) as $month)
                    <option value="{{ $month }}" {{ request('month') == $month ? 'selected' : '' }}>
                        {{ \Carbon\Carbon::create()->month($month)->format('F') }}
                    </option>
                @endforeach
            </select>

            <!-- Year Filter -->
            <select id="yearFilter" name="year"
                class="text-sm text-gray-600 border-2 border-gray-300 rounded-md shadow-sm focus:border-blue-500 focus:ring focus:ring-blue-500 focus:ring-opacity-50">
                <option value="">Select Year</option>
                @foreach (range(date('Y') - 10, date('Y') + 10) as $year)
                    <option value="{{ $year }}" {{ request('year') == $year ? 'selected' : '' }}>
                        {{ $year }}
                    </option>
                @endforeach
            </select>

            <!-- Quarter Filter -->
            <select id="quarterFilter" name="quarter"
                class="text-sm text-gray-600 border-2 border-gray-300 rounded-md shadow-sm focus:border-blue-500 focus:ring focus:ring-blue-500 focus:ring-opacity-50"
                style="display: none;">
                <option value="">Select Quarter</option>
                <option value="Q1" {{ request('quarter') == 'Q1' ? 'selected' : '' }}>Q1</option>
                <option value="Q2" {{ request('quarter') == 'Q2' ? 'selected' : '' }}>Q2</option>
                <option value="Q3" {{ request('quarter') == 'Q3' ? 'selected' : '' }}>Q3</option>
                <option value="Q4" {{ request('quarter') == 'Q4' ? 'selected' : '' }}>Q4</option>
            </select>

            <select id="categoryFilter" name="category"
                class="text-sm text-gray-600 border-2 border-gray-300 rounded-md shadow-sm focus:border-blue-500 focus:ring focus:ring-blue-500 focus:ring-opacity-50">
                <option value="">Select Category</option>
                <option value="" disabled selected>Select category</option>
                <option value="Electric">Electric</option>
                <option value="Water">Water</option>
                <option value="PLDT">PLDT</option>
                <option value="Sky">Sky</option>
                <option value="Professional Fee">Professional Fee</option>
                <option value="Withholding Tax">Withholding Tax</option>
                <option value="Business Tax">Business Tax</option>
                <option value="VAT">VAT</option>
                <option value="Percentage Tax">Percentage Tax</option>
                <option value="Income Tax">Income Tax</option>
                <option value="Business Permit">Business Permit</option>
                <option value="Real Property Tax">Real Property Tax</option>
                <option value="Others">Others</option>
            </select>
            <button type="submit"
                class="px-4 py-2 text-sm text-white transition duration-300 bg-green-600 rounded-lg hover:bg-green-700 ">Generate
                Report</button>
        </form>
    </div>

    <script>
        function handleFilterTypeChange() {
            const type = document.getElementById('filterType').value;
            const monthFilter = document.getElementById('monthFilter');
            const quarterFilter = document.getElementById('quarterFilter');

            if (type === 'Monthly') {
                monthFilter.style.display = 'inline-block';
                quarterFilter.style.display = 'none';
            } else if (type === 'Quarterly') {
                monthFilter.style.display = 'none';
                quarterFilter.style.display = 'inline-block';
            } else if (type === 'Annual') {
                monthFilter.style.display = 'none';
                quarterFilter.style.display = 'none';
            } else {
                monthFilter.style.display = 'none';
                quarterFilter.style.display = 'none';
            }
        }

        // Initialize visibility based on the current selection
        document.addEventListener('DOMContentLoaded', handleFilterTypeChange);
    </script>

    <div class="mt-12">
        <div class="flex justify-between">
            <div>
                <h2 class="mb-4 text-2xl font-semibold">Accounts Payable List</h2>
            </div>

            <div class="">
                <button id="openModalButton"
                    class="px-4 py-2 text-white transition duration-300 bg-blue-600 rounded-lg hover:bg-blue-700">
                    Payable Form</button>
            </div>
        </div>
        <div class="overflow-x-auto">
            <table id="payablesTable" class="min-w-full text-center bg-white border-collapse rounded shadow-md">
                <thead class="bg-gray-200">
                    <tr>

                        <th class="px-6 py-3 text-xs font-medium tracking-wider text-gray-700 uppercase">Type</th>
                        <th class="px-6 py-3 text-xs font-medium tracking-wider text-gray-700 uppercase">Category</th>
                        <th class="px-6 py-3 text-xs font-medium tracking-wider text-gray-700 uppercase">Amount (PHP)</th>
                        <th class="px-6 py-3 text-xs font-medium tracking-wider text-gray-700 uppercase">Notes</th>
                        <th class="px-6 py-3 text-xs font-medium tracking-wider text-gray-700 uppercase">Due Date</th>
                        <th class="px-6 py-3 text-xs font-medium tracking-wider text-gray-700 uppercase">Actions</th>
                    </tr>
                </thead>
                <tbody class="text-sm text-gray-600">

                </tbody>
            </table>
        </div>
    </div>

    <div id="payableModal" class="fixed inset-0 flex items-center justify-center hidden bg-gray-800 bg-opacity-75">
        <div class="relative w-full max-w-3xl p-6 bg-white rounded-lg shadow-lg">
            <div class="flex items-center justify-between pb-4 mb-4 border-b">
                <h2 class="text-2xl font-semibold">Accounts Payable Form</h2>
                <button id="closeModalButton" class="text-2xl text-gray-500 hover:text-gray-700">&times;</button>
            </div>

            <form action="" method="POST">
                @csrf

                <div class="mb-4">
                    <label for="type" class="block font-medium text-gray-700">Payable Type</label>
                    <select id="type" name="type"
                        class="block w-full mt-1 border border-gray-300 rounded-lg shadow-sm focus:border-blue-500 focus:ring focus:ring-blue-500 focus:ring-opacity-50"
                        required>
                        <option value="" disabled selected>Select type</option>
                        <option value="Monthly">Monthly</option>
                        <option value="Quarterly">Quarterly</option>
                        <option value="Annual">Annual</option>
                    </select>
                </div>

                <div class="mb-4">
                    <label for="category" class="block font-medium text-gray-700">Category</label>
                    <select id="category" name="category"
                        class="block w-full mt-1 border border-gray-300 rounded-lg shadow-sm focus:border-blue-500 focus:ring focus:ring-blue-500 focus:ring-opacity-50">
                        <option value="" disabled selected>Select category</option>
                        <option value="Electric">Electric</option>
                        <option value="Water">Water</option>
                        <option value="PLDT">PLDT</option>
                        <option value="Sky">Sky</option>
                        <option value="Professional Fee">Professional Fee</option>
                        <option value="Withholding Tax">Withholding Tax</option>
                        <option value="Business Tax">Business Tax</option>
                        <option value="VAT">VAT</option>
                        <option value="Percentage Tax">Percentage Tax</option>
                        <option value="Income Tax">Income Tax</option>
                        <option value="Business Permit">Business Permit</option>
                        <option value="Real Property Tax">Real Property Tax</option>
                        <option value="Others">Others</option>
                    </select>
                </div>

                <!-- Amount -->
                <div class="mb-4">
                    <label for="amount" class="block font-medium text-gray-700">Amount (PHP)</label>
                    <input type="number" id="amount" name="amount"
                        class="block w-full mt-1 border border-gray-300 rounded-lg shadow-sm focus:border-blue-500 focus:ring focus:ring-blue-500 focus:ring-opacity-50"
                        required>
                </div>

                <!-- Notes -->
                <div class="mb-4">
                    <label for="notes" class="block font-medium text-gray-700">Notes</label>
                    <textarea id="notes" name="notes"
                        class="block w-full mt-1 border border-gray-300 rounded-lg shadow-sm focus:border-blue-500 focus:ring focus:ring-blue-500 focus:ring-opacity-50"></textarea>
                </div>

                <!-- Due Date -->
                <div class="mb-4">
                    <label for="date_of_payable" class="block font-medium text-gray-700">Date</label>
                    <input type="date" id="date_of_payable" name="date_of_payable"
                        class="block w-full mt-1 border border-gray-300 rounded-lg shadow-sm focus:border-blue-500 focus:ring focus:ring-blue-500 focus:ring-opacity-50"
                        required>
                </div>

                <div class="mt-6 text-center">
                    <button type="submit"
                        class="px-6 py-2 text-white transition duration-300 bg-blue-600 rounded-lg hover:bg-blue-700">Submit</button>
                </div>
            </form>
        </div>
    </div>



    @foreach ($payables as $payable)
        <div id="payableModal{{ $payable->id }}"
            class="fixed inset-0 flex items-center justify-center hidden bg-gray-800 bg-opacity-75">
            <div class="relative w-full max-w-3xl p-6 bg-white rounded-lg shadow-lg">
                <div class="flex items-center justify-between pb-4 mb-4 border-b">
                    <h2 class="text-2xl font-semibold">Edit Payable</h2>
                    <button onclick="closeModal('payableModal{{ $payable->id }}')"
                        class="text-2xl text-gray-500 hover:text-gray-700">&times;</button>
                </div>

                <form action="{{ route('payables.update', $payable->id) }}" method="POST">
                    @csrf
                    @method('PUT')

                    <div class="mb-4">
                        <label for="type{{ $payable->id }}" class="block font-medium text-gray-700">Payable Type</label>
                        <select id="type{{ $payable->id }}" name="type"
                            class="block w-full mt-1 border border-gray-300 rounded-lg shadow-sm focus:border-blue-500 focus:ring focus:ring-blue-500 focus:ring-opacity-50"
                            required>
                            <option value="" disabled>Select type</option>
                            <option value="Monthly" {{ $payable->type == 'Monthly' ? 'selected' : '' }}>Monthly</option>
                            <option value="Quarterly" {{ $payable->type == 'Quarterly' ? 'selected' : '' }}>Quarterly
                            </option>
                            <option value="Annual" {{ $payable->type == 'Annual' ? 'selected' : '' }}>Annual</option>
                        </select>
                    </div>

                    <div class="mb-4">
                        <label for="category{{ $payable->id }}" class="block font-medium text-gray-700">Category</label>
                        <select id="category{{ $payable->id }}" name="category"
                            class="block w-full mt-1 border border-gray-300 rounded-lg shadow-sm focus:border-blue-500 focus:ring focus:ring-blue-500 focus:ring-opacity-50">
                            <option value="" disabled>Select category</option>
                            <option value="Electric" {{ $payable->category == 'Electric' ? 'selected' : '' }}>Electric
                            </option>
                            <option value="Water" {{ $payable->category == 'Water' ? 'selected' : '' }}>Water</option>
                            <option value="PLDT" {{ $payable->category == 'PLDT' ? 'selected' : '' }}>PLDT</option>
                            <option value="Sky" {{ $payable->category == 'Sky' ? 'selected' : '' }}>Sky</option>
                            <option value="Professional Fee"
                                {{ $payable->category == 'Professional Fee' ? 'selected' : '' }}>Professional Fee</option>
                            <option value="Withholding Tax"
                                {{ $payable->category == 'Withholding Tax' ? 'selected' : '' }}>Withholding Tax</option>
                            <option value="Business Tax" {{ $payable->category == 'Business Tax' ? 'selected' : '' }}>
                                Business Tax</option>
                            <option value="VAT" {{ $payable->category == 'VAT' ? 'selected' : '' }}>VAT</option>
                            <option value="Percentage Tax" {{ $payable->category == 'Percentage Tax' ? 'selected' : '' }}>
                                Percentage Tax</option>
                            <option value="Income Tax" {{ $payable->category == 'Income Tax' ? 'selected' : '' }}>Income
                                Tax</option>
                            <option value="Business Permit"
                                {{ $payable->category == 'Business Permit' ? 'selected' : '' }}>Business Permit</option>
                            <option value="Real Property Tax"
                                {{ $payable->category == 'Real Property Tax' ? 'selected' : '' }}>Real Property Tax
                            </option>
                            <option value="Others" {{ $payable->category == 'Others' ? 'selected' : '' }}>Others
                            </option>
                        </select>
                    </div>

                    <div class="mb-4">
                        <label for="amount{{ $payable->id }}" class="block font-medium text-gray-700">Amount
                            (PHP)
                        </label>
                        <input type="number" id="amount{{ $payable->id }}" name="amount"
                            class="block w-full mt-1 border border-gray-300 rounded-lg shadow-sm focus:border-blue-500 focus:ring focus:ring-blue-500 focus:ring-opacity-50"
                            value="{{ $payable->amount }}" required>
                    </div>

                    <div class="mb-4">
                        <label for="notes{{ $payable->id }}" class="block font-medium text-gray-700">Notes</label>
                        <textarea id="notes{{ $payable->id }}" name="notes"
                            class="block w-full mt-1 border border-gray-300 rounded-lg shadow-sm focus:border-blue-500 focus:ring focus:ring-blue-500 focus:ring-opacity-50">{{ $payable->notes }}</textarea>
                    </div>

                    <div class="mb-4">
                        <label for="date_of_payable{{ $payable->id }}"
                            class="block font-medium text-gray-700">Date</label>
                        <input type="date" id="date_of_payable{{ $payable->id }}" name="date_of_payable"
                            class="block w-full mt-1 border border-gray-300 rounded-lg shadow-sm focus:border-blue-500 focus:ring focus:ring-blue-500 focus:ring-opacity-50"
                            value="{{ $payable->date_of_payable }}" required>
                    </div>

                    <div class="mt-6 text-center">
                        <button type="submit"
                            class="px-6 py-2 text-white transition duration-300 bg-blue-600 rounded-lg hover:bg-blue-700">Update</button>
                    </div>
                </form>
            </div>
        </div>




        <div id="deleteModal{{ $payable->id }}"
            class="fixed inset-0 flex items-center justify-center hidden bg-black bg-opacity-50">
            <!-- Modal dialog -->
            <div class="max-w-md mx-auto overflow-hidden bg-white rounded-lg shadow-xl">
                <!-- Modal header -->
                <div class="flex items-center justify-between px-4 py-2 bg-red-500">
                    <h5 class="font-bold text-white">Confirm Delete</h5>
                    <button onclick="closeModal('deleteModal{{ $payable->id }}')" class="text-white">&times;</button>
                </div>

                <!-- Modal body -->
                <div class="px-4 py-4">
                    <p>Are you sure you want to delete this Fee?</p>
                </div>

                <!-- Modal footer -->
                <div class="flex items-center justify-end px-4 py-3 bg-gray-100">
                    <button onclick="closeModal('deleteModal{{ $payable->id }}')"
                        class="px-3 py-1 mr-2 text-gray-800 bg-gray-300 rounded hover:bg-gray-400">Cancel</button>

                    <!-- Form for delete -->
                    <form id="deleteForm{{ $payable->id }}" action="{{ route('payables.destroy', $payable->id) }}"
                        method="POST">
                        @csrf
                        @method('DELETE')
                        <button type="submit"
                            class="px-3 py-1 text-white bg-red-500 rounded hover:bg-red-600">Delete</button>
                    </form>
                </div>
            </div>
        </div>
    @endforeach

    <script src="https://cdn.ckeditor.com/4.22.1/standard/ckeditor.js"></script>

    <script>
        CKEDITOR.replace('notes');
    </script>

    <script>
        $(document).ready(function() {
            $('#payablesTable').DataTable({
                processing: true,
                serverSide: true,
                ajax: "{{ route('payables.index') }}",
                columns: [{
                        data: 'category',
                        name: 'category'
                    },
                    {
                        data: 'type',
                        name: 'type'
                    },
                    {
                        data: 'amount',
                        name: 'amount'
                    },
                    {
                        data: 'notes',
                        name: 'notes',
                        render: function(data, type, row) {
                            // Safely render HTML content in the notes column
                            return $('<div/>').html(data).text();
                        }
                    },
                    {
                        data: 'date_of_payable',
                        name: 'date_of_payable',
                        render: function(data, type, row) {
                            // Convert the date string to a Date object and format it
                            let date = new Date(data);
                            let options = {
                                year: 'numeric',
                                month: 'long',
                                day: 'numeric'
                            };
                            return date.toLocaleDateString('en-US', options);
                        }
                    },

                    {
                        data: 'actions',
                        name: 'actions',
                        orderable: false,
                        searchable: false
                    }
                ]
            });
        });
        document.getElementById('openModalButton').addEventListener('click', function() {
            document.getElementById('payableModal').classList.remove('hidden');
        });

        // Close Modal
        document.getElementById('closeModalButton').addEventListener('click', function() {
            document.getElementById('payableModal').classList.add('hidden');
        });

        // Close Modal on outside click
        window.addEventListener('click', function(event) {
            if (event.target === document.getElementById('payableModal')) {
                document.getElementById('payableModal').classList.add('hidden');
            }
        });

        function openModal(modalId) {
            var modal = document.getElementById(modalId);
            modal.classList.remove('hidden');
            modal.classList.add('flex');
        }

        // Function to close a modal
        function closeModal(modalId) {
            var modal = document.getElementById(modalId);
            modal.classList.add('hidden');
            modal.classList.remove('flex');
        }
    </script>
@endsection
