@extends('layouts.sidebar')

@section('content')
    <style>
        @media print {
            body * {
                visibility: hidden;
            }

            .print-content,
            .print-content * {
                visibility: visible;
                font-size: 10px;
                /* Maintain small font size */
            }

            .print-content {
                position: absolute;
                left: 0;
                top: 0;
                width: 210mm;
                /* A4 width */
                height: 297mm;
                /* A4 height */
                padding: 10mm;
                /* Reduce padding to create more space */
                box-sizing: border-box;
                margin: 0;
                /* Remove default margin */
            }

            .print-header {
                font-size: 10px;
                /* Smaller font size for header */
                font-weight: bold;
                margin-bottom: 2mm;
                /* Minimal bottom margin for header */
                text-align: center;
            }

            .print-content table {
                width: 100%;
                border-collapse: collapse;
            }

            .print-content table th,
            .print-content table td {
                padding: 2px;
                /* Keep padding compact */
                border: 1px solid black;
                /* Maintain border for clarity */
                text-align: left;
            }

            .print-footer {
                position: fixed;
                bottom: 5mm;
                /* Reduce margin at bottom */
                width: 100%;
                text-align: center;
                font-size: 10px;
                margin-top: 2mm;
                /* Minimize space above the footer */
            }
        }
    </style>

    @php
        $vatAmount = 0;
        $withholdingTaxAmount = 0;
        $dueDate = $data->payment_date->copy()->addDays($data->lease->terms);
        $isPastDue = now()->isAfter($dueDate);
        $monthsPastDue = $isPastDue ? now()->diffInMonths($dueDate) : 0;
        $penalty = $data->Amount * 0.02 * $monthsPastDue;
        if ($data->lease->client->vat === 'vat') {
            $subtotal = $data->Amount + $totalElectricAmount + $totalWaterAmount + $additional;
            $vatAmount = $subtotal * 0.12;
        }

        if ($data->lease->client->w_holding_tax === 'true') {
            $withholdingTaxAmount = $subtotal * 0.05;
        }

        $subtotal = $data->Amount + $totalElectricAmount + $totalWaterAmount + $additional;
        $grandTotal = $subtotal + $vatAmount - $withholdingTaxAmount + $penalty;

    @endphp

    <div class="max-w-4xl p-8 mx-auto mt-8 text-sm text-gray-800 bg-white rounded shadow-lg print-content">
        <!-- Header Section -->
        <div class="mb-8 text-center">
            <h1 class="text-2xl font-bold">San Roque Hermanas Inc.</h1>
            <p>MGR BLDG. II, Matina Crossing, Davao City</p>
            <p>Email: <a href="mailto:srhimgr@yahoo.com" class="text-blue-500">srhimgr@yahoo.com</a> | Tel: (082)299-4103 |
                Cell #: 0910-651-1604 | TIN: 006-040-261</p>
            <hr class="my-4">
        </div>

        <!-- Recipient Information -->
        <div class="mb-4">
            <p class="font-bold">{{ $data->lease->client->owners_name }}</p>
            <p>Owners Name</p>
            <p>{{ $data->lease->client->business_name }}</p>
            <p>{{ $data->lease->unit->unit_name }} & {{ $data->lease->property->property_name }}
            </p>
            <p>{{ $data->lease->property->street_address }},{{ $data->lease->property->city }},
                {{ $data->lease->property->state }}, {{ $data->lease->property->zip }}</p>
        </div>

        <!-- Statement Title -->
        <div class="mb-4">
            <p class="text-xl font-bold">STATEMENT OF ACCOUNT</p>
        </div>

        <!-- Statement Date -->
        <div class="mb-4">
            <p class="font-bold"> {{ date('F j, Y', strtotime($data->payment_date)) }}</p>
        </div>

        <!-- Greetings -->
        <div class="mb-8">
            <p>Madam:</p>
            <p>Greetings!</p>
            <p>Please be informed of your monthly rental obligation as shown below:</p>

            <table class="w-full border border-collapse border-gray-200">
                <thead>
                    <tr class="bg-gray-200">
                        <th class="px-4 py-2 border border-gray-300">Description & Amount</th>
                    </tr>
                </thead class="">

                <tbody>

                    <tr>
                        <td class="px-4 py-2 border border-gray-300">Advance Payment Last advanced
                            ₱{{ number_format($advance_payment, 2) }}
                        </td>
                    </tr>
                    <tr>
                        <td class="px-4 py-2 border border-gray-300">Previous Balance:
                            ₱{{ number_format($currentRentalBalance, 2) }}</td>
                    </tr>
                    <tr>
                        <td class="px-4 py-2 border border-gray-300">Payments Received:
                            ₱{{ number_format($Amountpaid, 2) }}
                        </td>
                    </tr>
                    <tr>
                        <td class="px-4 py-2 border border-gray-300">Current Charges:
                            ₱{{ number_format($data->amount + $totalWaterAmount + $totalElectricAmount + $additional, 2) }}
                        </td>
                    </tr>
                    @if ($data->lease->client->vat === 'vat')
                        <tr>
                            <td class="px-4 py-2 border border-gray-300">Add: VAT ₱({{ number_format($data->Amount, 2) }} x
                                12%): {{ number_format($vatAmount, 2) }}</td>
                        </tr>
                    @endif
                    @if ($data->lease->client->w_holding_tax === 'true')
                        <tr>
                            <td class="px-4 py-2 border border-gray-300">Less: W/TAX
                                ₱({{ number_format($data->Amount, 2) }}
                                x 5%): {{ number_format($withholdingTaxAmount, 2) }}</td>
                        </tr>
                    @endif
                    @if ($penalty > 0)
                        <tr>
                            <td class="px-4 py-2 border border-gray-300">Penalty: ₱{{ number_format($penalty, 2) }}</td>
                        </tr>
                    @endif
                    <tr class="font-bold">
                        <td class="px-4 py-2 border border-gray-300">Total Due:
                            ₱{{ number_format($currentRentalBalance + $penalty, 2) }}
                        </td>
                    </tr>
                </tbody>

            </table>

            <table class="w-full mt-10 border border-collapse border-gray-200">
                <thead>
                    <tr class="bg-gray-200">
                        <th class="px-4 py-2 border border-gray-300 text-start">Particularls</th>
                    </tr>
                </thead>
                <tbody>
                    <tr>
                        <td class="px-4 py-2 border border-gray-300">Rent due for 1 –
                            {{ date('F j, Y', strtotime($data->payment_date)) }}: ₱{{ number_format($data->Amount, 2) }}
                        </td>
                    </tr>
                    @if ($data->lease->client->vat === 'vat')
                        <tr>
                            <td class="px-4 py-2 border border-gray-300">Add: VAT ₱({{ number_format($data->Amount, 2) }} x
                                12%): {{ number_format($vatAmount, 2) }}</td>
                        </tr>
                    @endif

                    @if ($data->lease->client->w_holding_tax === 'true')
                        <tr>
                            <td class="px-4 py-2 border border-gray-300">Less: W/TAX
                                ₱({{ number_format($data->Amount, 2) }}
                                x 5%): {{ number_format($withholdingTaxAmount, 2) }}</td>
                        </tr>
                    @endif

                    @forelse ($data->waterPayments as $waterbill)
                        <tr>
                            <td class="px-4 py-2 border border-gray-300">Water bill
                                ({{ \Carbon\Carbon::parse($waterbill->start_date)->format('F j, Y') }} to
                                {{ \Carbon\Carbon::parse($waterbill->end_date)->format('F j, Y') }})
                                :
                                ₱ {{ number_format($waterbill->amount, 2) }}</td>
                        </tr>
                    @empty
                        <tr>
                            <td class="px-4 py-2 border border-gray-300">Water bill: N/A</td>
                        </tr>
                    @endforelse

                    @forelse ($data->electricPayments as $electricbill)
                        <tr>
                            <td class="px-4 py-2 border border-gray-300">Electric bill
                                ({{ \Carbon\Carbon::parse($electricbill->start_date)->format('F j, Y') }} to
                                {{ \Carbon\Carbon::parse($electricbill->end_date)->format('F j, Y') }})
                                :
                                ₱{{ number_format($electricbill->amount, 2) }}</td>
                        </tr>
                    @empty
                        <tr>
                            <td class="px-4 py-2 border border-gray-300">Electric bill: N/A</td>
                        </tr>
                    @endforelse

                    @forelse ($data->additionalFees as $fee)
                        <tr>
                            <td class="px-4 py-2 border border-gray-300">{{ $fee->charge_type }}:
                                ₱{{ number_format($fee->amount, 2) }}</td>
                        </tr>
                    @empty
                        <tr>
                            <td class="px-4 py-2 border border-gray-300">Additional Fees: N/A</td>
                        </tr>
                    @endforelse


                    @if ($isPastDue)
                        <tr>

                            <td class="px-4 py-2 border border-gray-300">Penalty for {{ $monthsPastDue }} month(s) past
                                due {{ number_format($penalty, 2) }}</td>

                        </tr>
                    @endif

                    <tr class="font-bold">
                        <td class="px-4 py-2 border border-gray-300">Grand Total: ₱{{ number_format($grandTotal, 2) }}</td>
                    </tr>
                </tbody>
            </table>

            <div class="mt-8 mb-8">
                <p>Note:{{ $data->billing_notes }}</p>
            </div>

            <!-- Closing and Signatory -->
            <div class="mt-8">
                <p>Thank you for your prompt attention to this matter.</p>
                <p class="mt-4 font-bold">Very truly yours,</p>
                <p class="mt-4">San Roque Hermanas Inc.</p>
            </div>
        </div>
    </div>
    <div class="mt-4 text-center">
        <button onclick="window.print()" class="px-4 py-2 font-bold text-white bg-blue-500 rounded hover:bg-blue-700">
            Print Statement
        </button>
    </div>
@endsection
