@extends('layouts.sidebar')

@section('content')
    <div class="container px-4 py-8 mx-auto">
        <div class=" flex justify-between">
            <h1 class="mb-4 text-2xl font-bold">Payroll Management</h1>

            <!-- Add Payroll Modal Trigger -->
            <button class="px-4 py-2 font-bold text-white bg-blue-500 rounded hover:bg-blue-700"
                onclick="openModal('addPayrollModal')">Add Payroll</button>
        </div>


        <!-- Payroll Table -->
        <div class="mt-4">
            <table id="payrollTable" class="min-w-full divide-y divide-gray-200 text-center">
                <thead class="bg-gray-50">
                    <tr>
                    <tr>
                        <th scope="col" class="px-6 py-3 text-xs font-medium tracking-wider text-gray-500 uppercase">
                            ID</th>
                        <th scope="col" class="px-6 py-3 text-xs font-medium tracking-wider text-gray-500 uppercase">
                            Employee
                        </th>
                        <th scope="col" class="px-6 py-3 text-xs font-medium tracking-wider text-gray-500 uppercase">
                            Start Date</th>
                        <th scope="col" class="px-6 py-3 text-xs font-medium tracking-wider text-gray-500 uppercase">
                            End Date
                        </th>
                        <th scope="col" class="px-6 py-3 text-xs font-medium tracking-wider text-gray-500 uppercase">
                            Net Pay
                        </th>
                        <th scope="col" <th class="px-6 py-3 text-xs font-medium tracking-wider text-gray-700 uppercase">
                            Actions
                        </th>
                    </tr>
                    </tr>
                </thead>
                <tbody class="text-sm text-gray-600">

                </tbody>
            </table>
        </div>
    </div>












    <div id="addPayrollModal" class="fixed inset-0 z-10 hidden overflow-y-auto">
        <div class="flex items-center justify-center min-h-screen px-4 pt-4 pb-20 text-center sm:block sm:p-0">
            <div class="fixed inset-0 transition-opacity" aria-hidden="true">
                <div class="absolute inset-0 bg-gray-500 opacity-75"></div>
            </div>

            <!-- Modal Content -->
            <div
                class="inline-block overflow-hidden text-left align-bottom transition-all transform bg-white rounded-lg shadow-xl sm:my-8 sm:align-middle sm:max-w-lg sm:w-full">
                <div class="px-4 pt-5 pb-4 bg-white sm:p-6 sm:pb-4">
                    <h3 class="text-lg font-medium leading-6 text-gray-900">Add Payroll</h3>
                    <div class="mt-5">
                        <!-- Add Payroll Form -->
                        <form action="{{ route('payrolls.store') }}" method="POST" class="space-y-6">
                            @csrf
                            <div class="mb-4">
                                <label for="employee_id" class="block text-sm font-medium text-gray-700">Employee</label>
                                <select id="employee_id" name="employee_id"
                                    class="block w-full px-3 py-2 mt-1 bg-white border border-gray-300 rounded-md shadow-sm focus:outline-none focus:ring-indigo-500 focus:border-indigo-500 sm:text-sm"
                                    required>
                                    @foreach ($employees as $employee)
                                        <option value="{{ $employee->id }}"
                                            {{ old('employee_id') == $employee->id ? 'selected' : '' }}>
                                            {{ $employee->complete_name }}
                                        </option>
                                    @endforeach
                                </select>
                                @error('employee_id')
                                    <p class="mt-2 text-sm text-red-600">{{ $message }}</p>
                                @enderror
                            </div>
                            @if ($errors->any())
                                <div class="relative px-4 py-3 text-red-700 border border-red-400 rounded bg-red-50"
                                    role="alert">
                                    <strong class="font-bold">Whoops!</strong>
                                    <span class="block sm:inline">There were some problems with your input.</span>
                                    <ul class="pl-5 mt-2 list-disc">
                                        @foreach ($errors->all() as $error)
                                            <li>{{ $error }}</li>
                                        @endforeach
                                    </ul>
                                </div>
                            @endif

                            <div class="grid grid-cols-1 gap-6 md:grid-cols-2">
                                <!-- Start Date -->
                                <div class="form-group">
                                    <label for="start_date" class="block text-sm font-medium text-gray-700">Start
                                        Date</label>
                                    <input type="date"
                                        class="block w-full px-3 py-2 mt-1 border border-gray-300 rounded-md shadow-sm focus:outline-none focus:ring-indigo-500 focus:border-indigo-500 sm:text-sm @error('start_date') border-red-500 @enderror"
                                        id="start_date" name="start_date" value="{{ old('start_date') }}" required>
                                    @error('start_date')
                                        <p class="mt-1 text-xs text-red-500">{{ $message }}</p>
                                    @enderror
                                </div>

                                <!-- End Date -->
                                <div class="form-group">
                                    <label for="end_date" class="block text-sm font-medium text-gray-700">End
                                        Date</label>
                                    <input type="date"
                                        class="block w-full px-3 py-2 mt-1 border border-gray-300 rounded-md shadow-sm focus:outline-none focus:ring-indigo-500 focus:border-indigo-500 sm:text-sm @error('end_date') border-red-500 @enderror"
                                        id="end_date" name="end_date" value="{{ old('end_date') }}" required>
                                    @error('end_date')
                                        <p class="mt-1 text-xs text-red-500">{{ $message }}</p>
                                    @enderror
                                </div>

                                <!-- Bonuses -->
                                <div class="form-group">
                                    <label for="bonuses" class="block text-sm font-medium text-gray-700">Bonuses</label>
                                    <input type="number" step="0.01"
                                        class="block w-full px-3 py-2 mt-1 border border-gray-300 rounded-md shadow-sm focus:outline-none focus:ring-indigo-500 focus:border-indigo-500 sm:text-sm @error('bonuses') border-red-500 @enderror"
                                        id="bonuses" name="bonuses" value="{{ old('bonuses') }}">
                                    @error('bonuses')
                                        <p class="mt-1 text-xs text-red-500">{{ $message }}</p>
                                    @enderror
                                </div>

                                <!-- Cash Advances -->
                                <div class="form-group">
                                    <label for="cash_advances" class="block text-sm font-medium text-gray-700">Cash
                                        Advances</label>
                                    <input type="number" step="0.01"
                                        class="block w-full px-3 py-2 mt-1 border border-gray-300 rounded-md shadow-sm focus:outline-none focus:ring-indigo-500 focus:border-indigo-500 sm:text-sm @error('cash_advances') border-red-500 @enderror"
                                        id="cash_advances" name="cash_advances" value="{{ old('cash_advances') }}">
                                    @error('cash_advances')
                                        <p class="mt-1 text-xs text-red-500">{{ $message }}</p>
                                    @enderror
                                </div>
                            </div>

                            <!-- Deductions -->

                            <!-- Social Security Contributions -->
                            <fieldset class="form-group">
                                <legend class="block text-sm font-medium text-gray-700">Social Security
                                    Contributions</legend>
                                <div class="mt-4 space-y-4">
                                    <div class="flex items-center">
                                        <input type="checkbox" id="sss" name="sss"
                                            class="w-4 h-4 text-indigo-600 border-gray-300 rounded focus:ring-indigo-500"
                                            {{ old('sss') ? 'checked' : '' }}>
                                        <label for="sss" class="block ml-2 text-sm text-gray-700">SSS</label>
                                    </div>
                                    <div class="flex items-center">
                                        <input type="checkbox" id="philhealth" name="philhealth"
                                            class="w-4 h-4 text-indigo-600 border-gray-300 rounded focus:ring-indigo-500"
                                            {{ old('philhealth') ? 'checked' : '' }}>
                                        <label for="philhealth"
                                            class="block ml-2 text-sm text-gray-700">PhilHealth</label>
                                    </div>
                                    <div class="flex items-center">
                                        <input type="checkbox" id="pagibig" name="pagibig"
                                            class="w-4 h-4 text-indigo-600 border-gray-300 rounded focus:ring-indigo-500"
                                            {{ old('pagibig') ? 'checked' : '' }}>
                                        <label for="pagibig" class="block ml-2 text-sm text-gray-700">Pag-IBIG</label>
                                    </div>
                                </div>
                            </fieldset>

                            <!-- Notes -->
                            <div class="form-group">
                                <label for="notes" class="block text-sm font-medium text-gray-700">Notes</label>
                                <textarea
                                    class="block w-full px-3 py-2 mt-1 border border-gray-300 rounded-md shadow-sm focus:outline-none focus:ring-indigo-500 focus:border-indigo-500 sm:text-sm @error('notes') border-red-500 @enderror"
                                    id="notes" name="notes">{{ old('notes') }}</textarea>
                                @error('notes')
                                    <p class="mt-1 text-xs text-red-500">{{ $message }}</p>
                                @enderror
                            </div>

                            <!-- Buttons -->
                            <div class="flex justify-between mt-6">
                                <button type="submit"
                                    class="px-4 py-2 text-white bg-blue-500 rounded-md shadow-sm hover:bg-blue-600 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-blue-500">Save
                                    Payroll</button>
                                <button type="button"
                                    class="px-4 py-2 text-gray-700 bg-white border border-gray-300 rounded-md shadow-sm hover:bg-gray-50 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-gray-500"
                                    onclick="closeModal('addPayrollModal')">Cancel</button>
                            </div>
                        </form>

                    </div>
                </div>
            </div>
        </div>
    </div>













    <!-- Edit and Delete Modals (Loop through each payroll) -->
    @foreach ($payrolls as $payroll)
        <div id="editPayrollModal{{ $payroll->id }}" class="fixed inset-0 z-10 hidden overflow-y-auto">
            <div class="flex items-center justify-center min-h-screen px-4 pt-4 pb-20 text-center sm:block sm:p-0">
                <div class="fixed inset-0 transition-opacity" aria-hidden="true">
                    <div class="absolute inset-0 bg-gray-500 opacity-75"></div>
                </div>

                <!-- Modal Content -->
                <div
                    class="inline-block overflow-hidden text-left align-bottom transition-all transform bg-white rounded-lg shadow-xl sm:my-8 sm:align-middle sm:max-w-lg sm:w-full">
                    <div class="px-4 pt-5 pb-4 bg-white sm:p-6 sm:pb-4">
                        <h3 class="text-lg font-medium leading-6 text-gray-900">Edit Payroll</h3>
                        <div class="mt-5">
                            <!-- Edit Payroll Form -->
                            <form action="{{ route('payrolls.update', $payroll->id) }}" method="POST">
                                @csrf
                                @method('PUT')
                                <div class="mb-4">
                                    <label for="employee_id"
                                        class="block text-sm font-medium text-gray-700">Employee</label>
                                    <select id="employee_id" name="employee_id"
                                        class="block w-full px-3 py-2 mt-1 bg-white border border-gray-300 rounded-md shadow-sm focus:outline-none focus:ring-indigo-500 focus:border-indigo-500 sm:text-sm"
                                        required>
                                        @foreach ($employees as $employee)
                                            <option value="{{ $employee->id }}"
                                                {{ old('employee_id', $payroll->employee_id) == $employee->id ? 'selected' : '' }}>
                                                {{ $employee->complete_name }}
                                            </option>
                                        @endforeach
                                    </select>
                                    @error('employee_id')
                                        <p class="mt-2 text-sm text-red-600">{{ $message }}</p>
                                    @enderror
                                </div>
                                <div class="mb-4">
                                    <label for="payroll_date" class="block text-sm font-medium text-gray-700">Payroll
                                        Date</label>
                                    <input type="date" id="payroll_date" name="payroll_date"
                                        class="block w-full px-3 py-2 mt-1 bg-white border border-gray-300 rounded-md shadow-sm focus:outline-none focus:ring-indigo-500 focus:border-indigo-500 sm:text-sm"
                                        value="{{ old('payroll_date', $payroll->payroll_date) }}" required>
                                    @error('payroll_date')
                                        <p class="mt-2 text-sm text-red-600">{{ $message }}</p>
                                    @enderror
                                </div>
                                <div class="mb-4">
                                    <label for="days_worked" class="block text-sm font-medium text-gray-700">Days
                                        Worked</label>
                                    <input type="number" id="days_worked" name="days_worked"
                                        class="block w-full px-3 py-2 mt-1 bg-white border border-gray-300 rounded-md shadow-sm focus:outline-none focus:ring-indigo-500 focus:border-indigo-500 sm:text-sm"
                                        value="{{ old('days_worked', $payroll->days_worked) }}" required>
                                    @error('days_worked')
                                        <p class="mt-2 text-sm text-red-600">{{ $message }}</p>
                                    @enderror
                                </div>
                                <div class="mb-4">
                                    <label for="bonuses" class="block text-sm font-medium text-gray-700">Bonuses</label>
                                    <input type="number" step="0.01" id="bonuses" name="bonuses"
                                        class="block w-full px-3 py-2 mt-1 bg-white border border-gray-300 rounded-md shadow-sm focus:outline-none focus:ring-indigo-500 focus:border-indigo-500 sm:text-sm"
                                        value="{{ old('bonuses', $payroll->bonuses) }}">
                                    @error('bonuses')
                                        <p class="mt-2 text-sm text-red-600">{{ $message }}</p>
                                    @enderror
                                </div>
                                <div class="mb-4">
                                    <label for="cash_advances" class="block text-sm font-medium text-gray-700">Cash
                                        Advances</label>
                                    <input type="number" step="0.01" id="cash_advances" name="cash_advances"
                                        class="block w-full px-3 py-2 mt-1 bg-white border border-gray-300 rounded-md shadow-sm focus:outline-none focus:ring-indigo-500 focus:border-indigo-500 sm:text-sm"
                                        value="{{ old('cash_advances', $payroll->cash_advances) }}">
                                    @error('cash_advances')
                                        <p class="mt-2 text-sm text-red-600">{{ $message }}</p>
                                    @enderror
                                </div>
                                <div class="mb-4">
                                    <label for="late_undertime"
                                        class="block text-sm font-medium text-gray-700">Late/Undertime</label>
                                    <input type="text" id="late_undertime" name="late_undertime"
                                        class="block w-full px-3 py-2 mt-1 bg-white border border-gray-300 rounded-md shadow-sm focus:outline-none focus:ring-indigo-500 focus:border-indigo-500 sm:text-sm"
                                        value="{{ old('late_undertime', $payroll->late_undertime) }}">
                                    @error('late_undertime')
                                        <p class="mt-2 text-sm text-red-600">{{ $message }}</p>
                                    @enderror
                                </div>
                                <div class="mb-4">
                                    <label for="sss_deduction" class="block text-sm font-medium text-gray-700">SSS
                                        Deduction</label>
                                    <input type="number" step="0.01" id="sss_deduction" name="sss_deduction"
                                        class="block w-full px-3 py-2 mt-1 bg-white border border-gray-300 rounded-md shadow-sm focus:outline-none focus:ring-indigo-500 focus:border-indigo-500 sm:text-sm"
                                        value="{{ old('sss_deduction', $payroll->sss_deduction) }}">
                                    @error('sss_deduction')
                                        <p class="mt-2 text-sm text-red-600">{{ $message }}</p>
                                    @enderror
                                </div>
                                <div class="mb-4">
                                    <label for="philhealth_deduction"
                                        class="block text-sm font-medium text-gray-700">PhilHealth Deduction</label>
                                    <input type="number" step="0.01" id="philhealth_deduction"
                                        name="philhealth_deduction"
                                        class="block w-full px-3 py-2 mt-1 bg-white border border-gray-300 rounded-md shadow-sm focus:outline-none focus:ring-indigo-500 focus:border-indigo-500 sm:text-sm"
                                        value="{{ old('philhealth_deduction', $payroll->philhealth_deduction) }}">
                                    @error('philhealth_deduction')
                                        <p class="mt-2 text-sm text-red-600">{{ $message }}</p>
                                    @enderror
                                </div>
                                <div class="mb-4">
                                    <label for="pagibig_deduction"
                                        class="block text-sm font-medium text-gray-700">Pag-IBIG Deduction</label>
                                    <input type="number" step="0.01" id="pagibig_deduction" name="pagibig_deduction"
                                        class="block w-full px-3 py-2 mt-1 bg-white border border-gray-300 rounded-md shadow-sm focus:outline-none focus:ring-indigo-500 focus:border-indigo-500 sm:text-sm"
                                        value="{{ old('pagibig_deduction', $payroll->pagibig_deduction) }}">
                                    @error('pagibig_deduction')
                                        <p class="mt-2 text-sm text-red-600">{{ $message }}</p>
                                    @enderror
                                </div>
                                <div class="mb-4">
                                    <label for="custom_deductions" class="block text-sm font-medium text-gray-700">Custom
                                        Deductions</label>
                                    <input type="number" step="0.01" id="custom_deductions" name="custom_deductions"
                                        class="block w-full px-3 py-2 mt-1 bg-white border border-gray-300 rounded-md shadow-sm focus:outline-none focus:ring-indigo-500 focus:border-indigo-500 sm:text-sm"
                                        value="{{ old('custom_deductions', $payroll->custom_deductions) }}">
                                    @error('custom_deductions')
                                        <p class="mt-2 text-sm text-red-600">{{ $message }}</p>
                                    @enderror
                                </div>
                                <div class="mb-4">
                                    <label for="net_pay" class="block text-sm font-medium text-gray-700">Net Pay</label>
                                    <input type="number" step="0.01" id="net_pay" name="net_pay"
                                        class="block w-full px-3 py-2 mt-1 bg-white border border-gray-300 rounded-md shadow-sm focus:outline-none focus:ring-indigo-500 focus:border-indigo-500 sm:text-sm"
                                        value="{{ old('net_pay', $payroll->net_pay) }}" readonly>
                                    @error('net_pay')
                                        <p class="mt-2 text-sm text-red-600">{{ $message }}</p>
                                    @enderror
                                </div>
                                <div class="mb-4">
                                    <label for="status" class="block text-sm font-medium text-gray-700">Status</label>
                                    <select id="status" name="status"
                                        class="block w-full px-3 py-2 mt-1 bg-white border border-gray-300 rounded-md shadow-sm focus:outline-none focus:ring-indigo-500 focus:border-indigo-500 sm:text-sm">
                                        <option value="Unpaid"
                                            {{ old('status', $payroll->status) == 'Unpaid' ? 'selected' : '' }}>Unpaid
                                        </option>
                                        <option value="Paid"
                                            {{ old('status', $payroll->status) == 'Paid' ? 'selected' : '' }}>Paid</option>
                                    </select>
                                    @error('status')
                                        <p class="mt-2 text-sm text-red-600">{{ $message }}</p>
                                    @enderror
                                </div>
                                <div class="mb-4">
                                    <label for="notes" class="block text-sm font-medium text-gray-700">Notes</label>
                                    <textarea id="notes" name="notes" rows="3"
                                        class="block w-full px-3 py-2 mt-1 bg-white border border-gray-300 rounded-md shadow-sm focus:outline-none focus:ring-indigo-500 focus:border-indigo-500 sm:text-sm">{{ old('notes', $payroll->notes) }}</textarea>
                                    @error('notes')
                                        <p class="mt-2 text-sm text-red-600">{{ $message }}</p>
                                    @enderror
                                </div>
                                <div class="mb-4">
                                    <label for="start_date" class="block text-sm font-medium text-gray-700">Start
                                        Date</label>
                                    <input type="date" id="start_date" name="start_date"
                                        class="block w-full px-3 py-2 mt-1 bg-white border border-gray-300 rounded-md shadow-sm focus:outline-none focus:ring-indigo-500 focus:border-indigo-500 sm:text-sm"
                                        value="{{ old('start_date', $payroll->start_date) }}">
                                    @error('start_date')
                                        <p class="mt-2 text-sm text-red-600">{{ $message }}</p>
                                    @enderror
                                </div>
                                <div class="mb-4">
                                    <label for="end_date" class="block text-sm font-medium text-gray-700">End Date</label>
                                    <input type="date" id="end_date" name="end_date"
                                        class="block w-full px-3 py-2 mt-1 bg-white border border-gray-300 rounded-md shadow-sm focus:outline-none focus:ring-indigo-500 focus:border-indigo-500 sm:text-sm"
                                        value="{{ old('end_date', $payroll->end_date) }}">
                                    @error('end_date')
                                        <p class="mt-2 text-sm text-red-600">{{ $message }}</p>
                                    @enderror
                                </div>
                                <div class="mt-5 sm:mt-4 sm:flex sm:flex-row-reverse">
                                    <button type="submit"
                                        class="inline-flex justify-center w-full px-4 py-2 text-base font-medium text-white bg-blue-600 border border-transparent rounded-md shadow-sm hover:bg-blue-700 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500 sm:ml-3 sm:w-auto sm:text-sm">
                                        Save
                                    </button>
                                    <button type="button"
                                        class="inline-flex justify-center w-full px-4 py-2 mt-3 text-base font-medium text-gray-700 bg-white border border-gray-300 rounded-md shadow-sm hover:bg-gray-50 sm:mt-0 sm:w-auto sm:text-sm"
                                        onclick="closeModal('editPayrollModal{{ $payroll->id }}')">
                                        Cancel
                                    </button>
                                </div>
                            </form>
                        </div>
                    </div>
                </div>
            </div>
        </div>









        <div id="viewpayroll{{ $payroll->id }}" class="fixed inset-0 z-10 hidden overflow-y-auto">
            <div class="flex items-center justify-center min-h-screen px-4 pt-4 pb-20 text-center sm:block sm:p-0">
                <div class="fixed inset-0 transition-opacity" aria-hidden="true">
                    <div class="absolute inset-0 bg-gray-500 opacity-75"></div>
                </div>

                <div
                    class="inline-block w-full max-w-3xl overflow-hidden text-left align-bottom transition-all transform bg-white rounded-lg shadow-xl sm:my-8">
                    <div class="px-4 pt-5 pb-4 bg-white sm:p-6 sm:pb-4">
                        <div class="max-w-2xl p-4 mx-auto bg-white border border-gray-300 rounded-md shadow-md "
                            id="modal-content">
                            <div class="mb-4 text-center">
                                <h1 class="text-xl font-bold">San Roque Hermanas, Inc.</h1>
                                <p class="text-base font-semibold">Salary Report</p>
                                <p class="text-xs">
                                    Covered Period:
                                    {{ \Carbon\Carbon::parse($payroll->start_date)->format('F j, Y') }} -
                                    {{ \Carbon\Carbon::parse($payroll->end_date)->format('F j, Y') }}
                                </p>
                            </div>

                            <div class="mb-4">
                                <h2 class="text-lg font-semibold">Employee Details</h2>
                                <p><strong>Name:</strong> {{ $payroll->employee->complete_name }}</p>
                            </div>

                            <table class="w-full mb-4 bg-white border border-gray-300 rounded-md">
                                <thead class="text-xs bg-gray-100">
                                    <tr>
                                        <th class="px-2 py-1 text-left"># of Days</th>
                                        <th class="px-2 py-1 text-left">Rate</th>
                                        <th class="px-2 py-1 text-left">Total</th>
                                    </tr>
                                </thead>
                                <tbody class="text-sm">
                                    <tr>
                                        <td class="px-2 py-1 border">{{ $payroll->days_worked }}</td>
                                        <td class="px-2 py-1 border">{{ $payroll->employee->salary_rate }}</td>
                                        <td class="px-2 py-1 border">
                                            {{ $payroll->days_worked * $payroll->employee->salary_rate }}</td>
                                    </tr>
                                </tbody>
                            </table>

                            <div class="mb-4">
                                <h3 class="text-base font-semibold">Deductions</h3>
                                <p><strong>None</strong></p>
                                <table class="w-full mb-2 text-sm bg-white border border-gray-300 rounded-md">
                                    <thead class="bg-gray-100">
                                        <tr>
                                            <th class="px-2 py-1 text-left">Benefits</th>
                                            <th class="px-2 py-1 text-left">Amount</th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        <tr>
                                            <td class="px-2 py-1 border">SSS</td>
                                            <td class="px-2 py-1 border">{{ $payroll->sss_deduction }}</td>
                                        </tr>
                                        <tr>
                                            <td class="px-2 py-1 border">Pag-Ibig</td>
                                            <td class="px-2 py-1 border">{{ $payroll->pagibig_deduction }}</td>
                                        </tr>
                                        <tr>
                                            <td class="px-2 py-1 border">Philhealth</td>
                                            <td class="px-2 py-1 border">{{ $payroll->philhealth_deduction }}</td>
                                        </tr>
                                    </tbody>
                                </table>
                            </div>

                            @php
                                $totalsalary = $payroll->days_worked * $payroll->employee->salary_rate;
                                $totaldeduction =
                                    $payroll->sss_deduction +
                                    $payroll->pagibig_deduction +
                                    $payroll->philhealth_deduction;
                                $total = $totalsalary - $totaldeduction;
                            @endphp
                            <div class="mb-4">

                                <p><strong>Net Income:</strong> {{ $total }}</p>
                                <p class="text-xs italic">Note: {{ $payroll->notes }}</p>
                            </div>

                            <table class="w-full text-sm bg-white border border-gray-300 rounded-md">
                                <thead class="bg-gray-100">
                                    <tr>
                                        <th class="px-2 py-1 text-left">Description</th>
                                        <th class="px-2 py-1 text-left">Amount</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <tr>
                                        <td class="px-2 py-1 border">Lates</td>
                                        <td class="px-2 py-1 border">{{ $payroll->late_undertime }}</td>
                                    </tr>
                                    @foreach ($payroll->employee->deductions->filter(function ($deduction) use ($payroll) {
            return $payroll->start_date <= $deduction->date && $payroll->end_date >= $deduction->date;
        }) as $deduction)
                                        <tr>
                                            <td class="px-2 py-1 border">{{ $deduction->benefit_name }}</td>
                                            <td class="px-2 py-1 border">{{ $deduction->amount }}</td>
                                        </tr>
                                    @endforeach

                                </tbody>
                                <tfoot>
                                    <tr>
                                        <td class="px-2 py-1 font-semibold text-right border">Grand Total</td>
                                        <td class="px-2 py-1 border">
                                            {{ $payroll->net_pay }}</td>
                                    </tr>
                                </tfoot>
                            </table>


                        </div>
                        <div class="mt-4 text-center">
                            <button type="button"
                                class="inline-flex justify-center w-full px-4 py-2 mt-3 text-base font-medium text-gray-700 bg-white border border-gray-300 rounded-md shadow-sm hover:bg-gray-50 sm:mt-0 sm:w-auto sm:text-sm"
                                onclick="closeModal('viewpayroll{{ $payroll->id }}')">
                                Cancel
                            </button>
                            <button class="px-4 py-2 bg-blue-500 text-white rounded hover:bg-blue-600"
                                onclick="printModal('viewpayroll{{ $payroll->id }}')">Print</button>

                        </div>
                    </div>
                </div>
            </div>
        </div>

        <div class="flex justify-center items-center" id="print-section" class="hidden"></div>

        <script>
            function printModal(modalId) {
                const modalContent = document.getElementById(modalId).querySelector('#modal-content').innerHTML;
                const printWindow = window.open('', '', 'height=500,width=800');

                printWindow.document.write('<html><head><title>Print Modal</title>');
                printWindow.document.write(
                    '<link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css">');
                printWindow.document.write(
                    '<style>body { margin: 30px; } .container { margin: 0 auto; padding: 20px; }</style>');
                printWindow.document.write('</head><body>');
                printWindow.document.write('<div class="container">' + modalContent + '</div>');
                printWindow.document.write('</body></html>');

                printWindow.document.close();

                printWindow.onload = function() {
                    printWindow.focus();
                    printWindow.print();
                    printWindow.close();
                };
            }
        </script>
        <!-- Delete Payroll Modal -->
        <div id="deletePayrollModal{{ $payroll->id }}" class="fixed inset-0 z-10 hidden overflow-y-auto">
            <div class="flex items-center justify-center min-h-screen px-4 pt-4 pb-20 text-center sm:block sm:p-0">
                <div class="fixed inset-0 transition-opacity" aria-hidden="true">
                    <div class="absolute inset-0 bg-gray-500 opacity-75"></div>
                </div>

                <!-- Modal Content -->
                <div
                    class="inline-block overflow-hidden text-left align-bottom transition-all transform bg-white rounded-lg shadow-xl sm:my-8 sm:align-middle sm:max-w-lg sm:w-full">
                    <div class="px-4 pt-5 pb-4 bg-white sm:p-6 sm:pb-4">
                        <h3 class="text-lg font-medium leading-6 text-gray-900">Delete Payroll</h3>
                        <div class="mt-5">
                            <!-- Delete Payroll Form -->
                            <form action="{{ route('payrolls.destroy', $payroll->id) }}" method="POST">
                                @csrf
                                @method('DELETE')
                                <p class="text-sm text-gray-500">Are you sure you want to delete payroll for
                                    {{ $payroll->employee->complete_name }}?</p>
                                <div class="mt-5 sm:mt-4 sm:flex sm:flex-row-reverse">
                                    <button type="submit"
                                        class="inline-flex justify-center w-full px-4 py-2 text-base font-medium text-white bg-red-600 border border-transparent rounded-md shadow-sm hover:bg-red-700 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-red-500 sm:ml-3 sm:w-auto sm:text-sm">
                                        Delete
                                    </button>
                                    <button type="button"
                                        class="inline-flex justify-center w-full px-4 py-2 mt-3 text-base font-medium text-gray-700 bg-white border border-gray-300 rounded-md shadow-sm hover:bg-gray-50 sm:mt-0 sm:w-auto sm:text-sm"
                                        onclick="closeModal('deletePayrollModal{{ $payroll->id }}')">
                                        Cancel
                                    </button>
                                </div>
                            </form>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    @endforeach

    <!-- JavaScript to Open and Close Modals -->
    <script>
        $(document).ready(function() {
            $('#payrollTable').DataTable({
                processing: true,
                serverSide: true,
                ajax: "{{ route('payrolls.index') }}",
                columns: [{
                        data: 'view',
                        name: 'view',
                        orderable: false,
                        searchable: false
                    }, {
                        data: 'employee_name',
                        name: 'employee_name'
                    },


                    {
                        data: 'start_date',
                        name: 'start_date',
                        render: function(data, type, row) {
                            // Format the date as "Month Day, Year"
                            if (type === 'display' && data) {
                                var date = new Date(data);
                                var options = {
                                    year: 'numeric',
                                    month: 'long',
                                    day: 'numeric'
                                };
                                return date.toLocaleDateString('en-US', options);
                            }
                            return data;
                        }
                    },
                    {
                        data: 'end_date',
                        name: 'end_date',
                        render: function(data, type, row) {
                            // Format the date as "Month Day, Year"
                            if (type === 'display' && data) {
                                var date = new Date(data);
                                var options = {
                                    year: 'numeric',
                                    month: 'long',
                                    day: 'numeric'
                                };
                                return date.toLocaleDateString('en-US', options);
                            }
                            return data;
                        }
                    },
                    {
                        data: 'net_pay',
                        name: 'net_pay'
                    },
                    {
                        data: 'actions',
                        name: 'actions',
                        orderable: false,
                        searchable: false
                    }
                ]
            });
        });

        function openModal(modalId) {
            document.getElementById(modalId).classList.remove('hidden');
        }

        function closeModal(modalId) {
            document.getElementById(modalId).classList.add('hidden');
        }
    </script>
@endsection
