@extends('layouts.sidebar')

@section('content')
    <div class="container mx-auto">
        <div class="flex justify-between mt-10">
            <h2 class="mb-4 text-2xl font-semibold">Miscellaneous Fees</h2>
            <button id="openModalButton"
                class="px-4 py-2 text-white transition duration-300 bg-blue-600 rounded-lg hover:bg-blue-700">
                Add Miscellaneous Fees
            </button>
        </div>
        <form action="{{ route('miscellaneous-fees.report') }}" method="GET" class="mb-4">
            <div class="flex flex-wrap gap-4">
                <div class="w-1/3">
                    <label for="month" class="block text-sm font-medium text-gray-700">Month</label>
                    <select id="month" name="month"
                        class="block w-full py-2 pl-3 pr-10 mt-1 border-gray-300 rounded-md focus:outline-none focus:ring-indigo-500 focus:border-indigo-500 sm:text-sm">
                        @foreach (range(1, 12) as $m)
                            <option value="{{ $m }}"
                                {{ $m == request('month', now()->month) ? 'selected' : '' }}>
                                {{ date('F', mktime(0, 0, 0, $m, 1)) }}
                            </option>
                        @endforeach
                    </select>
                </div>
                <div class="w-1/3">
                    <label for="year" class="block text-sm font-medium text-gray-700">Year</label>
                    <select id="year" name="year"
                        class="block w-full py-2 pl-3 pr-10 mt-1 border-gray-300 rounded-md focus:outline-none focus:ring-indigo-500 focus:border-indigo-500 sm:text-sm">
                        @foreach (range(now()->year - 5, now()->year) as $y)
                            <option value="{{ $y }}" {{ $y == request('year', now()->year) ? 'selected' : '' }}>
                                {{ $y }}
                            </option>
                        @endforeach
                    </select>
                </div>
                <div class="flex items-end w-1/3">
                    <button type="submit"
                        class="inline-flex justify-center px-4 py-2 text-sm font-medium text-white bg-indigo-600 border border-transparent rounded-md shadow-sm hover:bg-indigo-700 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                        Generate Report
                    </button>
                </div>
            </div>
        </form>
        <div class="mt-12">

            <div class="overflow-x-auto">
                <table id="payablesTable" class="min-w-full text-center bg-white border-collapse rounded shadow-md">
                    <thead class="bg-gray-200">
                        <tr>
                            <th class="px-6 py-3 text-xs font-medium tracking-wider text-gray-700 uppercase">Property</th>
                            <th class="px-6 py-3 text-xs font-medium tracking-wider text-gray-700 uppercase">Type
                            </th>
                            <th class="px-6 py-3 text-xs font-medium tracking-wider text-gray-700 uppercase">Expected Amount
                                (PHP)
                            </th>
                            <th class="px-6 py-3 text-xs font-medium tracking-wider text-gray-700 uppercase">Amount Paid
                                (PHP)
                            </th>
                            <th class="px-6 py-3 text-xs font-medium tracking-wider text-gray-700 uppercase">Voucher
                            </th>
                            <th class="px-6 py-3 text-xs font-medium tracking-wider text-gray-700 uppercase">status</th>

                            <th class="px-6 py-3 text-xs font-medium tracking-wider text-gray-700 uppercase">Notes</th>
                            <th class="px-6 py-3 text-xs font-medium tracking-wider text-gray-700 uppercase">Date
                            </th>
                            <th class="px-6 py-3 text-xs font-medium tracking-wider text-gray-700 uppercase">Actions</th>
                        </tr>
                    </thead>
                    <tbody class="text-sm text-gray-600">

                    </tbody>
                </table>
            </div>
        </div>
    @endsection
</div>


@section('scripts')
    <div id="payableModal" class="fixed inset-0 flex items-center justify-center hidden bg-gray-800 bg-opacity-75">
        <div class="relative w-full max-w-3xl p-6 bg-white rounded-lg shadow-lg">
            <div class="flex items-center justify-between pb-4 mb-4 border-b">

                <h2 class="text-2xl font-semibold ">Miscellaneous Fee Form</h2>
                <button id="closeModalButton" class="text-2xl text-gray-500 hover:text-gray-700">&times;</button>

            </div>

            <form action="{{ route('miscellaneous_fees.store') }}" method="POST">
                @csrf

                <!-- Property Dropdown -->
                <div class="mb-4">
                    <label for="property" class="block font-medium text-gray-700">Property</label>
                    <select id="property" name="property_id"
                        class="block w-full h-10 mt-1 border border-gray-300 rounded-lg shadow-sm focus:border-blue-500 focus:ring focus:ring-blue-500 focus:ring-opacity-50"
                        required>
                        @foreach ($property as $property)
                            <option value="{{ $property->id }}">{{ $property->property_name }}</option>
                        @endforeach
                    </select>
                    @error('property_id')
                        <span class="text-sm text-red-500">{{ $message }}</span>
                    @enderror
                </div>

                <!-- Name Field -->
                <div class="mb-4">
                    <label for="name" class="block font-medium text-gray-700">Name Description</label>
                    <input type="text" id="name" name="name"
                        class="block w-full h-10 mt-1 border border-gray-300 rounded-lg shadow-sm focus:border-blue-500 focus:ring focus:ring-blue-500 focus:ring-opacity-50"
                        required>
                    @error('name')
                        <span class="text-sm text-red-500">{{ $message }}</span>
                    @enderror
                </div>

                <!-- Amount Field -->
                <div class="mb-4">
                    <label for="amount" class="block font-medium text-gray-700">Amount (PHP)</label>
                    <input type="number" id="amount" name="amount"
                        class="block w-full h-10 mt-1 border border-gray-300 rounded-lg shadow-sm focus:border-blue-500 focus:ring focus:ring-blue-500 focus:ring-opacity-50"
                        step="0.01" min="0" required>
                    @error('amount')
                        <span class="text-sm text-red-500">{{ $message }}</span>
                    @enderror
                </div>

                <!-- Amount Paid Field -->
                <div class="mb-4">
                    <label for="amount_paid" class="block font-medium text-gray-700">Amount Paid (PHP)</label>
                    <input type="number" id="amount_paid" name="amount_paid"
                        class="block w-full h-10 mt-1 border border-gray-300 rounded-lg shadow-sm focus:border-blue-500 focus:ring focus:ring-blue-500 focus:ring-opacity-50"
                        step="0.01" min="0" required>
                    @error('amount_paid')
                        <span class="text-sm text-red-500">{{ $message }}</span>
                    @enderror
                </div>

                <!-- Status Field -->
                <div class="mb-4">
                    <label for="status" class="block font-medium text-gray-700">Status</label>
                    <select id="status" name="status"
                        class="block w-full h-10 mt-1 border border-gray-300 rounded-lg shadow-sm focus:border-blue-500 focus:ring focus:ring-blue-500 focus:ring-opacity-50"
                        required>
                        <option value="">Select Status</option>
                        <option value="Pending">Pending</option>
                        <option value="Paid">Paid</option>
                        <option value="Overdue">Overdue</option>
                    </select>
                    @error('status')
                        <span class="text-sm text-red-500">{{ $message }}</span>
                    @enderror
                </div>

                <!-- Notes -->
                <div class="mb-4">
                    <label for="notes" class="block font-medium text-gray-700">Notes</label>
                    <textarea id="notes" name="notes"
                        class="block w-full h-32 mt-1 border border-gray-300 rounded-lg shadow-sm focus:border-blue-500 focus:ring focus:ring-blue-500 focus:ring-opacity-50"></textarea>
                    @error('notes')
                        <span class="text-sm text-red-500">{{ $message }}</span>
                    @enderror
                </div>

                <!-- Date of Payable -->
                <div class="mb-4">
                    <label for="date" class="block font-medium text-gray-700">Date of Payable</label>
                    <input type="date" id="date" name="date"
                        class="block w-full h-10 mt-1 border border-gray-300 rounded-lg shadow-sm focus:border-blue-500 focus:ring focus:ring-blue-500 focus:ring-opacity-50"
                        required>
                    @error('date')
                        <span class="text-sm text-red-500">{{ $message }}</span>
                    @enderror
                </div>

                <div class="mt-6 text-center">
                    <button type="submit"
                        class="px-6 py-2 text-white transition duration-300 bg-blue-600 rounded-lg hover:bg-blue-700">Submit</button>
                </div>
            </form>
        </div>
    </div>




    @foreach ($MiscellaneousFee as $miscFee)
        <div id="deleteModal{{ $miscFee->id }}"
            class="fixed inset-0 flex items-center justify-center hidden bg-black bg-opacity-50">
            <!-- Modal dialog -->
            <div class="max-w-md mx-auto overflow-hidden bg-white rounded-lg shadow-xl">
                <!-- Modal header -->
                <div class="flex items-center justify-between px-4 py-2 bg-red-500">
                    <h5 class="font-bold text-white">Confirm Delete</h5>
                    <button onclick="closeModal('deleteModal{{ $miscFee->id }}')" class="text-white">&times;</button>
                </div>

                <!-- Modal body -->
                <div class="px-4 py-4">
                    <p>Are you sure you want to delete this Fee?</p>
                </div>

                <!-- Modal footer -->
                <div class="flex items-center justify-end px-4 py-3 bg-gray-100">
                    <button onclick="closeModal('deleteModal{{ $miscFee->id }}')"
                        class="px-3 py-1 mr-2 text-gray-800 bg-gray-300 rounded hover:bg-gray-400">Cancel</button>

                    <!-- Form for delete -->
                    <form id="deleteForm{{ $miscFee->id }}"
                        action="{{ route('miscellaneous_fees.destroy', $miscFee->id) }}" method="POST">
                        @csrf
                        @method('DELETE')
                        <button type="submit"
                            class="px-3 py-1 text-white bg-red-500 rounded hover:bg-red-600">Delete</button>
                    </form>
                </div>
            </div>
        </div>

        <div id="miscellaneousModal{{ $miscFee->id }}"
            class="fixed inset-0 flex items-center justify-center hidden bg-gray-800 bg-opacity-75">
            <div class="relative w-full max-w-3xl p-6 bg-white rounded-lg shadow-lg">
                <div class="flex items-center justify-between pb-4 mb-4 border-b">
                    <h2 class="text-2xl font-semibold">Update Additional Fee</h2>
                    <button onclick="closeModal('miscellaneousModal{{ $miscFee->id }}')"
                        class="text-2xl text-gray-500 closeModalButton hover:text-gray-700">&times;</button>
                </div>

                <form action="{{ route('miscellaneous_fees.update', $miscFee->id) }}" method="POST">
                    @csrf
                    @method('PUT') <!-- Use PUT method for updates -->

                    <!-- Property Dropdown -->
                    <div class="mb-4">
                        <label for="property" class="block font-medium text-gray-700">Property</label>
                        <select id="property" name="property_id"
                            class="block w-full h-10 mt-1 border border-gray-300 rounded-lg shadow-sm focus:border-blue-500 focus:ring focus:ring-blue-500 focus:ring-opacity-50"
                            required>
                            @foreach ($properties as $property)
                                <option value="{{ $property->id }}"
                                    {{ $property->id == $miscFee->property_id ? 'selected' : '' }}>
                                    {{ $property->property_name }}
                                </option>
                            @endforeach
                        </select>
                        @error('property_id')
                            <span class="text-sm text-red-500">{{ $message }}</span>
                        @enderror
                    </div>

                    <!-- Type Field -->
                    <div class="mb-4">
                        <label for="type" class="block font-medium text-gray-700">Type</label>
                        <input type="text" id="type" name="type"
                            class="block w-full h-10 mt-1 border border-gray-300 rounded-lg shadow-sm focus:border-blue-500 focus:ring focus:ring-blue-500 focus:ring-opacity-50"
                            value="{{ old('type', $miscFee->type) }}" required>
                        @error('type')
                            <span class="text-sm text-red-500">{{ $message }}</span>
                        @enderror
                    </div>

                    <!-- Amount Field -->
                    <div class="mb-4">
                        <label for="amount" class="block font-medium text-gray-700">Amount (PHP)</label>
                        <input type="number" id="amount" name="amount"
                            class="block w-full h-10 mt-1 border border-gray-300 rounded-lg shadow-sm focus:border-blue-500 focus:ring focus:ring-blue-500 focus:ring-opacity-50"
                            step="0.01" min="0" value="{{ old('amount', $miscFee->amount) }}" required>
                        @error('amount')
                            <span class="text-sm text-red-500">{{ $message }}</span>
                        @enderror
                    </div>

                    <!-- Amount Paid Field -->
                    <div class="mb-4">
                        <label for="amount_paid" class="block font-medium text-gray-700">Amount Paid (PHP)</label>
                        <input type="number" id="amount_paid" name="amount_paid"
                            class="block w-full h-10 mt-1 border border-gray-300 rounded-lg shadow-sm focus:border-blue-500 focus:ring focus:ring-blue-500 focus:ring-opacity-50"
                            step="0.01" min="0" value="{{ old('amount_paid', $miscFee->amount_paid) }}"
                            required>
                        @error('amount_paid')
                            <span class="text-sm text-red-500">{{ $message }}</span>
                        @enderror
                    </div>

                    <!-- Status Field -->
                    <div class="mb-4">
                        <label for="status" class="block font-medium text-gray-700">Status</label>
                        <select id="status" name="status"
                            class="block w-full h-10 mt-1 border border-gray-300 rounded-lg shadow-sm focus:border-blue-500 focus:ring focus:ring-blue-500 focus:ring-opacity-50"
                            required>
                            <option value="Pending" {{ $miscFee->status == 'Pending' ? 'selected' : '' }}>Pending</option>
                            <option value="Paid" {{ $miscFee->status == 'Paid' ? 'selected' : '' }}>Paid</option>
                            <option value="Overdue" {{ $miscFee->status == 'Overdue' ? 'selected' : '' }}>Overdue</option>
                        </select>
                        @error('status')
                            <span class="text-sm text-red-500">{{ $message }}</span>
                        @enderror
                    </div>

                    <!-- Notes -->
                    <div class="mb-4">
                        <label for="notes" class="block font-medium text-gray-700">Notes</label>
                        <textarea id="notes" name="notes"
                            class="block w-full h-32 mt-1 border border-gray-300 rounded-lg shadow-sm focus:border-blue-500 focus:ring focus:ring-blue-500 focus:ring-opacity-50">{{ old('notes', $miscFee->notes) }}</textarea>
                        @error('notes')
                            <span class="text-sm text-red-500">{{ $message }}</span>
                        @enderror
                    </div>

                    <!-- Date of Payable -->
                    <div class="mb-4">
                        <label for="date" class="block font-medium text-gray-700">Date of Payable</label>
                        <input type="date" id="date" name="date"
                            class="block w-full h-10 mt-1 border border-gray-300 rounded-lg shadow-sm focus:border-blue-500 focus:ring focus:ring-blue-500 focus:ring-opacity-50"
                            value="{{ old('date', $miscFee->date) }}" required>
                        @error('date')
                            <span class="text-sm text-red-500">{{ $message }}</span>
                        @enderror
                    </div>

                    <div class="mt-6 text-center">
                        <button type="submit"
                            class="px-6 py-2 text-white transition duration-300 bg-blue-600 rounded-lg hover:bg-blue-700">Update</button>
                    </div>
                </form>
            </div>
        </div>
    @endforeach

    <script>
        $(document).ready(function() {
            $('#payablesTable').DataTable({
                processing: true,
                serverSide: true,
                ajax: "{{ route('miscellaneous_fees.index') }}",
                columns: [{
                        data: 'property_name',
                        name: 'property_name'
                    },
                    {
                        data: 'type',
                        name: 'type'
                    },
                    {
                        data: 'amount',
                        name: 'amount'
                    },
                    {
                        data: 'amount_paid',
                        name: 'amount_paid'
                    },
                    {
                        data: 'id',
                        name: 'id'
                    },
                    {
                        data: 'status',
                        name: 'status'
                    },
                    {
                        data: 'notes',
                        name: 'notes'
                    },
                    {
                        data: 'date',
                        name: 'date',
                        render: function(data, type, row) {
                            // Convert the date string to a Date object and format it
                            let date = new Date(data);
                            let options = {
                                year: 'numeric',
                                month: 'long',
                                day: 'numeric'
                            };
                            return date.toLocaleDateString('en-US', options);
                        }
                    },

                    {
                        data: 'actions',
                        name: 'actions',
                        orderable: false,
                        searchable: false
                    }
                ]
            });
        });
        document.getElementById('openModalButton').addEventListener('click', function() {
            document.getElementById('payableModal').classList.remove('hidden');
        });

        document.getElementById('closeModalButton').addEventListener('click', function() {
            document.getElementById('payableModal').classList.add('hidden');
        });

        window.addEventListener('click', function(event) {
            if (event.target === document.getElementById('payableModal')) {
                document.getElementById('payableModal').classList.add('hidden');
            }
        });

        function openModal(modalId) {
            var modal = document.getElementById(modalId);
            modal.classList.remove('hidden');
            modal.classList.add('flex');
        }

        // Function to close a modal
        function closeModal(modalId) {
            var modal = document.getElementById(modalId);
            modal.classList.add('hidden');
            modal.classList.remove('flex');
        }
    </script>
@endsection
