@extends('layouts.sidebar')

@section('content')
    <div class="container p-6 mx-auto">
        <h1 class="mb-4 text-2xl font-bold">BIR Form 2307 Monthly Report for {{ $year }}</h1>

        <div class="space-y-4">

            <!-- Filter Form -->
            <form action="{{ route('reports.recievables') }}" method="GET" class="p-4 bg-white rounded-lg shadow-md">
                <div class="grid grid-cols-1 gap-4 sm:grid-cols-2">

                    <!-- Year Filter -->
                    <div>
                        <label for="year" class="block text-sm font-medium text-gray-700">Select Year:</label>
                        <select name="year" id="year"
                            class="block w-full mt-1 border-2 border-gray-300 rounded-md shadow-sm focus:border-indigo-500 focus:ring focus:ring-indigo-500 focus:ring-opacity-50">
                            @php
                                // Current year
                                $currentYear = date('Y');

                                // Define the start and end years for the dropdown
                                $startYear = 2000;
                                $endYear = $currentYear + 5; // Advance 5 years from the current year
                            @endphp
                            @for ($i = $startYear; $i <= $endYear; $i++)
                                <option value="{{ $i }}" {{ $i == $year ? 'selected' : '' }}>{{ $i }}
                                </option>
                            @endfor
                        </select>
                    </div>

                    <!-- Property Filter -->
                    <div>
                        <label for="property_id" class="block text-sm font-medium text-gray-700">Select Property:</label>
                        <select name="property_id" id="property_id"
                            class="block w-full mt-1 border-2 border-gray-300 rounded-md shadow-sm focus:border-indigo-500 focus:ring focus:ring-indigo-500 focus:ring-opacity-50">
                            <option value="">All Properties</option>
                            @foreach ($properties as $property)
                                <option value="{{ $property->id }}" {{ $property->id == $propertyId ? 'selected' : '' }}>
                                    {{ $property->property_name }}
                                </option>
                            @endforeach
                        </select>
                    </div>
                </div>
                <div class="mt-4">
                    <button type="submit"
                        class="px-4 py-2 text-white bg-blue-500 rounded-md hover:bg-blue-600 focus:outline-none focus:ring-2 focus:ring-blue-500 focus:ring-opacity-50">Filter</button>
                </div>
            </form>

            <!-- Export Form -->
            <form action="{{ route('exportRevenue') }}" method="GET" class="p-4 bg-white rounded-lg shadow-md">
                <input type="hidden" name="month" value="{{ request('month') }}">
                <input type="hidden" name="year" value="{{ request('year') }}">
                <div class="mt-4">
                    <button type="submit"
                        class="px-4 py-2 text-white bg-green-500 rounded-md hover:bg-green-600 focus:outline-none focus:ring-2 focus:ring-green-500 focus:ring-opacity-50">Export
                        to Excel</button>
                </div>
            </form>

        </div>

        <table class="min-w-full text-sm bg-white border border-gray-300 rounded-lg shadow-md">
            <thead>
                <tr class="text-left text-gray-600 bg-gray-200">
                    <th class="px-4 py-2">Unit #</th>
                    <th class="px-4 py-2">Property Name</th>
                    <th class="px-4 py-2">JAN</th>
                    <th class="px-4 py-2">FEB</th>
                    <th class="px-4 py-2">MAR</th>
                    <th class="px-4 py-2">APR</th>
                    <th class="px-4 py-2">MAY</th>
                    <th class="px-4 py-2">JUN</th>
                    <th class="px-4 py-2">JUL</th>
                    <th class="px-4 py-2">AUG</th>
                    <th class="px-4 py-2">SEPT</th>
                    <th class="px-4 py-2">OCT</th>
                    <th class="px-4 py-2">NOV</th>
                    <th class="px-4 py-2">DEC</th>
                </tr>
            </thead>
            <tbody>
                @foreach ($units as $unit)
                    <tr>
                        <td class="px-4 py-2 border">{{ $unit->unit_name }}</td>
                        <td class="px-4 py-2 border">{{ $unit->property->property_name }}</td>

                        <!-- Payments -->
                        @foreach (['JAN', 'FEB', 'MAR', 'APR', 'MAY', 'JUN', 'JUL', 'AUG', 'SEPT', 'OCT', 'NOV', 'DEC'] as $month)
                            @php
                                // Convert month name to numeric format
                                $monthNumber = date('n', strtotime($month));

                                $payment = $unit->leases
                                    ->flatMap(function ($lease) use ($monthNumber, $year) {
                                        return $lease->payments->filter(function ($payment) use ($monthNumber, $year) {
                                            return $payment->payment_date->format('n') == $monthNumber &&
                                                $payment->payment_date->format('Y') == $year;
                                        });
                                    })
                                    ->sum('Amount');

                                // Show 0 if no payments found
                                $payment = $payment ?: 0;
                            @endphp
                            <td class="px-4 py-2 border">{{ number_format($payment, 2) }}</td>
                        @endforeach
                    </tr>
                @endforeach
            </tbody>
        </table>
    </div>
@endsection
