@extends('layouts.sidebar')

@section('content')
    <style>
        @media print {
            body * {
                visibility: hidden;
            }

            .print-content,
            .print-content * {
                visibility: visible;
                font-size: 10px;
                /* Adjust the font size as needed */
            }

            .print-content {
                position: absolute;
                left: 0;
                top: 0;
                width: 210mm;
                /* A4 width */
                height: 350mm;
                /* A4 height */
                padding: 10mm;
                /* Add padding to simulate margin */
                box-sizing: border-box;
            }

            .print-content table td,
            .print-content table th {
                padding: 2px;
                /* Adjust the padding as needed */
            }
        }
    </style>
    <div class="container px-4 py-8 mx-auto ">
        <h1 class="mb-4 text-2xl font-extrabold">Remittance Report</h1>

        <!-- Filter Form -->
        <div class="w-full rounded-lg shadow-sm bg-gray-50 ">
            <form method="GET" action="{{ route('monthlyrevenue') }}" class="mb-6">
                <h2 class="mb-4 text-xl font-semibold">Filter Criteria</h2>
                <div class="grid grid-cols-3 gap-4">
                    <!-- Month Selection -->
                    <div class="flex flex-col">
                        <label for="month" class="mb-1 text-sm font-medium text-gray-700">Month:</label>
                        <select name="month" id="month"
                            class="block w-full px-3 py-2 bg-white border border-gray-300 rounded-md shadow-sm focus:ring-blue-500 focus:border-blue-500 sm:text-sm">
                            @foreach (range(1, 12) as $m)
                                <option value="{{ $m }}" {{ $m == old('month', date('n')) ? 'selected' : '' }}>
                                    {{ \DateTime::createFromFormat('!m', $m)->format('F') }}
                                </option>
                            @endforeach
                        </select>
                    </div>

                    <!-- Year Selection -->
                    <div class="flex flex-col">
                        <label for="year" class="mb-1 text-sm font-medium text-gray-700">Year:</label>
                        <select name="year" id="year"
                            class="block w-full px-3 py-2 bg-white border border-gray-300 rounded-md shadow-sm focus:ring-blue-500 focus:border-blue-500 sm:text-sm">
                            @php
                                $currentYear = now()->year;
                                $startYear = $currentYear - 10;
                                $endYear = $currentYear + 10; // Adjust the end year as needed
                            @endphp
                            @for ($year = $startYear; $year <= $endYear; $year++)
                                <option value="{{ $year }}"
                                    {{ $year == old('year', $currentYear) ? 'selected' : '' }}>
                                    {{ $year }}
                                </option>
                            @endfor
                        </select>
                    </div>

                    <div class="mt-6 ">
                        <button type="submit"
                            class="px-4 py-2 font-semibold text-white bg-blue-600 rounded-md shadow-sm hover:bg-blue-700 focus:outline-none focus:ring-2 focus:ring-blue-500">
                            Filter
                        </button>
                    </div>
                </div>
            </form>
        </div>

        <div class="print-content">

            <div class="col-span-2 p-4 rounded-lg shadow-sm bg-gray-50">
                <!-- Display Selected Filter Criteria -->
                @if (request('month') && request('year'))
                    <div class="p-4 mb-6 bg-gray-100 rounded-lg">
                        <h2 class="mb-2 text-lg font-semibold">Selected Filter Criteria</h2>
                        <p class="text-sm text-gray-700">Month:
                            {{ \DateTime::createFromFormat('!m', request('month'))->format('F') }}</p>
                        <p class="text-sm text-gray-700">Year: {{ request('year') }}</p>
                    </div>
                @endif

                <div class="overflow-x-auto">
                    <table class="w-full bg-white divide-y divide-gray-200">
                        <thead class="text-center bg-gray-100">
                            <tr>
                                <th class="px-4 py-2 text-xs font-medium text-gray-600 uppercase">Client</th>
                                <th class="px-4 py-2 text-xs font-medium text-gray-600 uppercase">Unit</th>
                                <th class="px-4 py-2 text-xs font-medium text-gray-600 uppercase">Rental Amount</th>
                                <th class="px-4 py-2 text-xs font-medium text-gray-600 uppercase">Waterbill Amount
                                </th>
                                <th class="px-4 py-2 text-xs font-medium text-gray-600 uppercase">Electricbill Amount
                                </th>
                                <th class="px-4 py-2 text-xs font-medium text-gray-600 uppercase">Additional Fees
                                    Amount
                                </th>
                                <th class="px-4 py-2 text-xs font-medium text-gray-600 uppercase">Month Water bill
                                    month
                                </th>
                                <th class="px-4 py-2 text-xs font-medium text-gray-600 uppercase">Month Electric bill
                                </th>
                                <th class="px-4 py-2 text-xs font-medium text-gray-600 uppercase">Others Payables</th>
                            </tr>
                        </thead>
                        <tbody class="text-center bg-white divide-y divide-gray-200">
                            @forelse ($newPayments as $payment)
                                <tr>
                                    <td class="px-4 py-2 text-sm text-gray-800">
                                        {{ $payment->payment->lease->client->business_name ?? 'N/A' }}</td>
                                    <td class="px-4 py-2 text-sm text-gray-800">
                                        {{ $payment->payment->lease->unit->unit_name ?? 'N/A' }}</td>
                                    <td class="px-4 py-2 text-sm text-gray-800">
                                        {{ number_format($payment->rental_amount, 2) }}</td>
                                    <td class="px-4 py-2 text-sm text-gray-800">
                                        {{ number_format($payment->waterbill_amount, 2) }}</td>
                                    <td class="px-4 py-2 text-sm text-gray-800">
                                        {{ number_format($payment->electricbill_amount, 2) }}</td>
                                    <td class="px-4 py-2 text-sm text-gray-800">
                                        {{ number_format($payment->payment->additionalFees->sum('amount_paid'), 2) }}</td>
                                    </td>
                                    <td class="px-4 py-2 text-sm text-gray-800"></td>

                                    <td class="px-4 py-2 text-sm text-gray-800"></td>

                                    <td class="px-4 py-2 text-sm text-gray-800"></td>

                                </tr>
                            @empty
                                <tr>
                                    <td colspan="8" class="px-4 py-2 text-center text-gray-500">No data available</td>
                                </tr>
                            @endforelse
                        </tbody>
                        <tfoot class="text-center bg-gray-100">
                            <tr>
                                <td colspan="2" class="px-4 py-2 font-semibold text-right text-gray-700">Totals:</td>
                                <td class="px-4 py-2 text-sm text-gray-800">{{ number_format($totalRentalAmount, 2) }}</td>
                                <td class="px-4 py-2 text-sm text-gray-800">{{ number_format($totalWaterbillAmount, 2) }}
                                </td>
                                <td class="px-4 py-2 text-sm text-gray-800">
                                    {{ number_format($totalElectricbillAmount, 2) }}
                                </td>
                                <td class="px-4 py-2 text-sm text-gray-800">{{ number_format($totalfeesAmount, 2) }}
                                <td class="px-4 py-2 text-sm text-gray-800">{{ number_format($totalWaterBillPayables, 2) }}
                                </td>
                                <td class="px-4 py-2 text-sm text-gray-800">
                                    {{ number_format($totalElectricBillPayables, 2) }}
                                </td>
                                <td class="px-4 py-2 text-sm text-gray-800">{{ number_format($othersPayables, 2) }}</td>
                            </tr>
                        </tfoot>
                    </table>
                </div>
            </div>

            <!-- Summary Section -->
            <div class="p-4 mt-6 rounded-lg shadow-sm bg-gray-50">
                <h2 class="mb-4 text-xl font-semibold">Summary</h2>

                <p class="my-2 text-xl font-bold">Recievables</p>
                <p class="text-sm font-medium text-gray-600">Total Rental Amount: <span
                        class="font-normal text-gray-700">{{ number_format($totalRentalAmount, 2) }}</span></p>
                <p class="text-sm font-medium text-gray-600">Total Waterbill Amount: <span
                        class="font-normal text-gray-700">{{ number_format($totalWaterbillAmount, 2) }}</span></p>
                <p class="text-sm font-medium text-gray-600">Total Electricbill Amount: <span
                        class="font-normal text-gray-700">{{ number_format($totalElectricbillAmount, 2) }}</span></p>
                <p class="text-sm font-medium text-gray-600">Total Additional Fees Amount: <span
                        class="font-normal text-gray-700">{{ number_format($totalfeesAmount, 2) }}</span></p>

                <p class="my-2 text-xl font-bold ">Paybles</p>
                <p class="text-sm font-medium text-gray-600">Total Water Payables: <span
                        class="font-normal text-gray-700">{{ number_format($totalWaterBillPayables, 2) }}</span></p>
                <p class="text-sm font-medium text-gray-600">Total Electric Payables: <span
                        class="font-normal text-gray-700">{{ number_format($totalElectricBillPayables, 2) }}</span></p>
                <p class="text-sm font-medium text-gray-600">Total Other Payables: <span
                        class="font-normal text-gray-700">{{ number_format($othersPayables, 2) }}</span></p>


                <p class="mt-4 text-lg font-bold">Net Revenue: <span
                        class="text-blue-600">{{ number_format($totalRevenue - $totalWaterBillPayables - $totalElectricBillPayables - $othersPayables - $totalfeesAmount, 2) }}</span>
                </p>
            </div>
        </div>
    </div>
    <div class="mt-4 text-center">
        <button onclick="window.print()" class="px-4 py-2 font-bold text-white bg-blue-500 rounded hover:bg-blue-700">
            Print Statement
        </button>
    </div>
@endsection
