@extends('layouts.sidebar')

@section('content')
    <style>
        @media print {
            body * {
                visibility: hidden;
            }

            .print-content,
            .print-content * {
                visibility: visible;
                font-size: 10px;
                /* Adjust the font size as needed */
            }

            .print-content {
                position: absolute;
                left: 0;
                top: 0;
                width: 210mm;
                /* A4 width */
                height: 297mm;
                /* A4 height */
                padding: 10mm;
                /* Add padding to simulate margin */
                box-sizing: border-box;
            }

            .print-content table td,
            .print-content table th {
                padding: 2px;
                /* Adjust the padding as needed */
            }
        }
    </style>
    <div class="container p-6 mx-auto print-content">
        <h1 class="mb-4 text-2xl font-bold">Withholding Tax Report for {{ $year }}</h1>

        <div class="space-y-4">


            <a href="{{ url('combined-report') }}" class="text-blue-500 underline">Vat Tax Report</a>
            <!-- Form to filter the report -->
            <form method="GET" action="{{ route('withholding.tax.report') }}">
                @csrf
                <div class="grid grid-cols-1 gap-4 md:grid-cols-2">
                    <div class="mb-4">
                        <label for="year" class="block text-gray-700">Year</label>
                        <input type="number" name="year" id="year" value="{{ old('year', date('Y')) }}"
                            class="w-full p-2 border rounded">
                    </div>

                    <div class="mb-4">
                        <label for="property_id" class="block text-gray-700">Property</label>
                        <select name="property_id" id="property_id" class="w-full p-2 border rounded">
                            <option value="">All Properties</option>
                            @foreach ($properties as $property)
                                <option value="{{ $property->id }}"
                                    {{ old('property_id') == $property->id ? 'selected' : '' }}>
                                    {{ $property->property_name }}
                                </option>
                            @endforeach
                        </select>
                    </div>
                </div>

                <button type="submit" class="px-4 py-2 text-white bg-blue-500 rounded">Generate Report</button>
            </form>

            <!-- Table for Withholding Tax Report -->
            <table class="min-w-full text-sm bg-white border border-gray-300 rounded-lg shadow-md">
                <thead>
                    <tr class="text-left text-gray-600 bg-gray-200">
                        <th class="px-4 py-2">Unit Name</th>
                        <th class="px-4 py-2">Property Name</th>
                        @foreach (['JAN', 'FEB', 'MAR', 'APR', 'MAY', 'JUN', 'JUL', 'AUG', 'SEP', 'OCT', 'NOV', 'DEC'] as $month)
                            <th class="px-4 py-2">{{ $month }}</th>
                        @endforeach
                    </tr>
                </thead>
                <tbody>
                    @foreach ($units as $unit)
                        <tr>
                            <td class="px-4 py-2 border">{{ $unit->unit_name }}</td>
                            <td class="px-4 py-2 border">{{ $unit->property->property_name }}</td>

                            @foreach (['JAN', 'FEB', 'MAR', 'APR', 'MAY', 'JUN', 'JUL', 'AUG', 'SEP', 'OCT', 'NOV', 'DEC'] as $month)
                                @php
                                    $monthNumber = date('n', strtotime($month));
                                    $totalAmount = 0;

                                    foreach ($unit->leases as $lease) {
                                        foreach ($lease->payments as $payment) {
                                            if (
                                                $payment->payment_date->format('n') == $monthNumber &&
                                                $payment->payment_date->format('Y') == $year
                                            ) {
                                                $totalAmount += is_numeric($payment->Amount) ? $payment->Amount : 0;
                                                $totalAmount += $payment->waterPayments->sum('amount') ?? 0;
                                                $totalAmount += $payment->electricPayments->sum('amount') ?? 0;
                                                $totalAmount += $payment->additionalFees->sum('amount') ?? 0;
                                            }
                                        }
                                    }

                                    $client = $unit->leases->first()->client ?? null;
                                    $withholdingTaxApplicable = $client ? $client->w_holding_tax === 'true' : false;
                                    $withholdingTaxAmount = 0;

                                    if ($month === 'JUN') {
                                        // Exclude June from calculations
                                        $withholdingTaxAmount = 0;
                                    } else {
                                        if ($withholdingTaxApplicable) {
                                            $withholdingTaxRate = 0.05; // 5% withholding tax
                                            $withholdingTaxAmount = $totalAmount * $withholdingTaxRate;
                                        }
                                    }

                                    $withholdingTaxAmount = is_numeric($withholdingTaxAmount)
                                        ? $withholdingTaxAmount
                                        : 0;
                                @endphp
                                <td class="px-4 py-2 border">{{ number_format($withholdingTaxAmount, 2) }}</td>
                            @endforeach
                        </tr>
                    @endforeach
                </tbody>
            </table>

        </div>
    </div>
    <div class="flex justify-center itemes-center"> <button onclick="window.print()"
            class="px-4 py-2 font-bold text-white bg-blue-500 rounded hover:bg-blue-700">
            Print
        </button></div>
@endsection
