@extends('layouts.sidebar')

@section('content')
    <div class="container mx-auto">
        <div class=" flex justify-between py-5">
            <div>
                <h2 class=" font-bold text-2xl">Electric Bill</h2>
            </div>
            <div> <button class="px-4 py-2 mb-2 font-bold text-white bg-blue-500 rounded hover:bg-blue-700"
                    onclick="openModal('addItemModal')">Add New Electric Bill</button>

                <form action="{{ route('export.Ebill') }}" method="GET" class="mb-4">
                    <div class="flex items-center space-x-4">
                        <div>
                            <label for="month" class="block text-sm font-medium text-gray-700">Month</label>
                            <select id="month" name="month"
                                class="mt-1 block w-full py-2 px-3 border border-gray-300 rounded-md shadow-sm focus:outline-none focus:ring-blue-500 focus:border-blue-500 sm:text-sm">
                                @foreach (range(1, 12) as $m)
                                    <option value="{{ $m }}" {{ $m == date('m') ? 'selected' : '' }}>
                                        {{ DateTime::createFromFormat('!m', $m)->format('F') }}
                                    </option>
                                @endforeach
                            </select>
                        </div>

                        <div>
                            <label for="year" class="block text-sm font-medium text-gray-700">Year</label>
                            <select id="year" name="year"
                                class="mt-1 block w-full py-2 px-3 border border-gray-300 rounded-md shadow-sm focus:outline-none focus:ring-blue-500 focus:border-blue-500 sm:text-sm">
                                @foreach (range(date('Y') - 10, date('Y') + 10) as $y)
                                    <option value="{{ $y }}" {{ $y == date('Y') ? 'selected' : '' }}>
                                        {{ $y }}
                                    </option>
                                @endforeach
                            </select>
                        </div>

                        <button type="submit" class="px-4 py-2 font-bold text-white bg-blue-500 rounded hover:bg-blue-700">
                            Export
                        </button>
                    </div>
                </form>


            </div>
        </div>



        @if (session('success'))
            <div class="text-center text-green-500">{{ session('success') }}</div>
        @endif

        <div class="overflow-x-auto">
            <table id="waterbillsTable" class="min-w-full text-center bg-white border-collapse rounded shadow-md">
                <thead class="bg-gray-200">
                    <tr>
                        <th class="px-6 py-3 text-xs font-medium tracking-wider text-gray-700 uppercase">Billing No.</th>
                        <th class="px-6 py-3 text-xs font-medium tracking-wider text-gray-700 uppercase">Renters</th>
                        <th class="px-6 py-3 text-xs font-medium tracking-wider text-gray-700 uppercase">Location</th>
                        <th class="px-6 py-3 text-xs font-medium tracking-wider text-gray-700 uppercase">Consumption</th>
                        <th class="px-6 py-3 text-xs font-medium tracking-wider text-gray-700 uppercase">Rate</th>
                        <th class="px-6 py-3 text-xs font-medium tracking-wider text-gray-700 uppercase">Amount</th>
                        <th class="px-6 py-3 text-xs font-medium tracking-wider text-gray-700 uppercase">Date from to</th>
                        <th class="px-6 py-3 text-xs font-medium tracking-wider text-gray-700 uppercase">Actions</th>
                    </tr>
                </thead>
                <tbody class="text-sm text-gray-600">


                    <!-- Table rows will be populated dynamically by DataTables -->
                </tbody>
            </table>
        </div>

    </div>
    @foreach ($bill as $bill)
        <div id="deleteModal{{ $bill->electricbill_id }}"
            class="fixed inset-0 flex items-center justify-center hidden bg-black bg-opacity-50">
            <!-- Modal dialog -->
            <div class="max-w-md mx-auto overflow-hidden bg-white rounded-lg shadow-xl">
                <!-- Modal header -->
                <div class="flex items-center justify-between px-4 py-2 bg-red-500">
                    <h5 class="font-bold text-white">Confirm Delete</h5>
                    <button onclick="closeModaldelete('deleteModal{{ $bill->electricbill_id }}')"
                        class="text-white">&times;</button>
                </div>

                <!-- Modal body -->
                <div class="px-4 py-4">
                    <p>Are you sure you want to delete this bill?</p>
                </div>

                <!-- Modal footer -->
                <div class="flex items-center justify-end px-4 py-3 bg-gray-100">
                    <button onclick="closeModaldelete('deleteModal{{ $bill->electricbill_id }}')"
                        class="px-3 py-1 mr-2 text-gray-800 bg-gray-300 rounded hover:bg-gray-400">Cancel</button>

                    <!-- Form for delete -->
                    <form id="deleteForm{{ $bill->electricbill_id }}"
                        action="{{ route('delete.electric', $bill->electricbill_id) }}" method="POST">
                        @csrf
                        @method('DELETE')
                        <button type="submit"
                            class="px-3 py-1 text-white bg-red-500 rounded hover:bg-red-600">Delete</button>
                    </form>
                </div>
            </div>
        </div>
    @endforeach
@endsection

@section('scripts')
    <script type="text/javascript">
        $(document).ready(function() {
            $('#waterbillsTable').DataTable({
                "processing": true,
                "serverSide": true,
                "ajax": "{{ url('electricbill') }}", // Ensure this route is correct
                "columns": [{
                        "data": "payment_id"
                    }, {
                        "data": "renters"
                    },
                    {
                        "data": "unit_location"
                    },
                    {
                        "data": "consumption"
                    },
                    {
                        "data": "rate"
                    },
                    {
                        "data": "amount"
                    },
                    {
                        "data": "date_range"
                    },
                    {
                        "data": "actions"
                    } // Ensure this matches the server response
                ]
            });
        });
    </script>

    <script>
        function openModal(modalId) {
            var modal = document.getElementById(modalId);
            modal.classList.remove('hidden');
        }

        function closeModal(modalId) {
            var modal = document.getElementById(modalId);
            modal.classList.add('hidden');
        }

        function openModaldelete(modalId) {
            var modal = document.getElementById(modalId);
            modal.classList.remove('hidden');
            modal.classList.add('flex');
        }

        // Function to close a modal
        function closeModaldelete(modalId) {
            var modal = document.getElementById(modalId);
            modal.classList.add('hidden');
            modal.classList.remove('flex');
        }
    </script>

    <div id="addItemModal" class="absolute inset-0 z-50 flex items-center justify-center hidden bg-black bg-opacity-50">
        <div class="w-1/2 overflow-y-auto bg-white rounded-lg">
            <!-- Modal header -->
            <div class="flex items-center justify-between px-4 py-2 bg-blue-500">
                <h5 class="font-bold text-white">Add eletriuc New Bill</h5>
                <button onclick="closeModal('addItemModal')" class="text-white">&times;</button>
            </div>

            <form action="{{ route('elect.add') }}" method="POST" class="p-6 bg-white rounded shadow-md">
                @csrf

                <!-- Property Name -->
                <div class="mb-4">
                    <label for="payment_id" class="block mb-2 text-sm font-bold text-gray-700">Select Billing:</label>
                    <select id="payment_id" name="payment_id"
                        class="w-full px-3 py-2 leading-tight text-gray-700 border border-black rounded shadow-sm appearance-none focus:outline-none focus:shadow-outline"
                        required>
                        <option value="">Select Billing</option>
                        @foreach ($client as $clients)
                            @php
                                $formattedDate = \Carbon\Carbon::parse($clients->payment_date)->format('F j, Y');
                            @endphp
                            <option value="{{ $clients->payment_id }}">
                                Billing No.{{ $clients->payment_id }} - {{ $clients->owners_name }},
                                Billing Date: {{ $formattedDate }},
                                Unit Name: {{ $clients->unit_name }}
                            </option>
                        @endforeach
                    </select>
                </div>
                <!-- Add Select2 CSS -->
                <link href="https://cdnjs.cloudflare.com/ajax/libs/select2/4.0.13/css/select2.min.css" rel="stylesheet" />

                <script src="https://cdnjs.cloudflare.com/ajax/libs/select2/4.0.13/js/select2.min.js"></script>

                <script>
                    $(document).ready(function() {
                        $('#payment_id').select2({
                            placeholder: 'Select Billing',
                            allowClear: true, // Option to clear selection
                            width: '100%', // Adjust width as needed
                        });
                    });
                </script>
                <div class="mb-4 hidden">
                    <label for="location" class="block mb-2 text-sm font-bold text-gray-700">Location
                    </label>
                    <input required type="text" id="location" name="location"
                        class="w-full px-3 py-2 leading-tight text-gray-700 border border-black rounded shadow appearance-none focus:outline-none focus:shadow-outline"
                        placeholder="Enter property name" value="test">

                </div>

                <!-- Street Address -->
                <div class="mb-4">
                    <label for="consumption" class="block mb-2 text-sm font-bold text-gray-700">Consumption</label>
                    <input required type="text" id="consumption" name="consumption"
                        class="w-full px-3 py-2 leading-tight text-gray-700 border border-black rounded shadow appearance-none focus:outline-none focus:shadow-outline"
                        placeholder="Enter consumption">
                </div>

                <!-- Rate -->
                <div class="mb-4">
                    <label for="rate" class="block mb-2 text-sm font-bold text-gray-700">Rate</label>
                    <input required type="text" id="rate" name="rate"
                        class="w-full px-3 py-2 leading-tight text-gray-700 border border-black rounded shadow appearance-none focus:outline-none focus:shadow-outline"
                        placeholder="Enter rate">
                </div>

                <!-- Amount -->
                <div class="mb-4">
                    <label for="amount" class="block mb-2 text-sm font-bold text-gray-700">Amount</label>
                    <input required type="text" id="amount" name="amount"
                        class="w-full px-3 py-2 leading-tight text-gray-700 border border-black rounded shadow appearance-none focus:outline-none focus:shadow-outline"
                        placeholder="Enter amount">
                </div>

                <!-- Start Date -->
                <div class="mb-4">
                    <label for="start-date" class="block mb-2 text-sm font-bold text-gray-700">Start Date</label>
                    <input required type="date" id="start-date" name="start_date"
                        class="w-full px-3 py-2 leading-tight text-gray-700 border border-black rounded shadow appearance-none focus:outline-none focus:shadow-outline">
                </div>

                <!-- End Date -->
                <div class="mb-4">
                    <label for="end-date" class="block mb-2 text-sm font-bold text-gray-700">End Date</label>
                    <input required type="date" id="end-date" name="end_date"
                        class="w-full px-3 py-2 leading-tight text-gray-700 border border-black rounded shadow appearance-none focus:outline-none focus:shadow-outline">
                </div>



                <!-- City, State, Zip -->


                <hr class="my-4">

                <button type="submit" class="w-full px-4 py-2 mt-4 text-white bg-blue-500 rounded hover:bg-blue-700">Save
                </button>
            </form>
        </div>
    </div>
@endsection
