<!-- resources/views/CMS/inventory/index.blade.php -->

@extends('layouts.sidebar')

@section('content')
    <div class="container px-4 py-8 mx-auto">
        <div class="grid grid-cols-1 gap-4 lg:grid-cols-3" id="invdiv">
            <!-- Inventory Items Section -->
            <div class="overflow-hidden bg-white rounded-lg shadow-md lg:col-span-1">
                <div class="px-4 py-2 bg-gray-200 border-b">
                    <h3 class="text-lg font-semibold text-gray-800">Inventory Management</h3>
                </div>
                <div class="p-4">
                    <div class="mb-4">
                        <button class="w-full px-4 py-2 text-white bg-blue-500 rounded hover:bg-blue-600"
                            onclick="toggleTable('stkdiv')">Stock In/Out</button>
                    </div>
                    <div class="mb-4">
                        <button class="w-full px-4 py-2 text-white bg-blue-500 rounded hover:bg-blue-600"
                            onclick="toggleTable('condiv')">Consumables</button>
                    </div>

                    <form id="addForm" action="{{ route('inventory.store') }}" method="POST">
                        @csrf
                        <div class="mb-4">
                            <label for="category" class="block text-sm font-medium text-gray-700">Category</label>
                            <select name="category" id="category"
                                class="block w-full mt-1 border-gray-300 rounded-md shadow-sm">
                                <option value="Tools & Machineries">Tools & Machineries</option>
                                <option value="Consumables / Excess Materials">Consumables / Excess Materials</option>
                                <option value="Office Supplies">Office Supplies</option>
                                <option value="Office Equipment">Office Equipment</option>
                            </select>
                        </div>
                        <div class="mb-4">
                            <label for="item_name" class="block text-sm font-medium text-gray-700">Item Name</label>
                            <input type="text" name="item_name" id="item_name"
                                class="block w-full mt-1 border-2 border-gray-300 rounded-md shadow-sm" required>
                        </div>
                        <div class="mb-4">
                            <label for="quantity" class="block text-sm font-medium text-gray-700">Quantity</label>
                            <input type="number" name="quantity" id="quantity"
                                class="block w-full mt-1 border-2 border-gray-300 rounded-md shadow-sm" required>
                        </div>
                        <div class="mb-4">
                            <label for="unit" class="block text-sm font-medium text-gray-700">Notes</label>
                            <input type="text" name="unit" id="unit"
                                class="block w-full mt-1 border-2 border-gray-300 rounded-md shadow-sm">
                        </div>
                        <div class="flex justify-end">
                            <button type="submit"
                                class="px-4 py-2 ml-2 text-white bg-blue-500 rounded hover:bg-blue-600">Add</button>
                        </div>
                    </form>
                </div>
            </div>

            <div class="mt-10 lg:col-span-2">
                @if (session('success'))
                    <div class="p-2 mt-4 text-green-700 bg-green-100 rounded">{{ session('success') }}</div>
                @endif
                <div class="flex justify-between py-5 ">
                    <div>
                        <h3 class="p-5 text-lg font-semibold text-gray-800">Items</h3>
                    </div>
                    <div>
                        <a href="{{ route('export.inventory') }}"
                            class="px-4 py-2 mb-2 font-bold text-white bg-blue-500 rounded hover:bg-blue-700">
                            Export Inventory
                        </a>
                    </div>
                </div>


                <table id="itemsTable" class="min-w-full text-center bg-white border-collapse rounded shadow-md">
                    <thead class="bg-gray-200">
                        <tr>
                        <tr>
                            <th class="px-6 py-3 text-xs font-medium tracking-wider text-gray-700 uppercase">Category</th>
                            <th class="px-6 py-3 text-xs font-medium tracking-wider text-gray-700 uppercase">Item Name</th>
                            <th class="px-6 py-3 text-xs font-medium tracking-wider text-gray-700 uppercase">Quantity</th>
                            <th class="px-6 py-3 text-xs font-medium tracking-wider text-gray-700 uppercase">Notes</th>
                            <th class="px-6 py-3 text-xs font-medium tracking-wider text-gray-700 uppercase">Actions</th>
                        </tr>
                    </thead>
                    <tbody class="text-sm text-gray-600"></tbody>
                </table>
            </div>
        </div>

        <div class="grid hidden grid-cols-1 gap-4 lg:grid-cols-3" id="stkdiv">
            <div class="overflow-hidden bg-white rounded-lg shadow-md lg:col-span-1">
                <div class="px-4 py-2 bg-gray-200 border-b">
                    <h3 class="text-lg font-semibold text-gray-800">Stock In/Out Management</h3>
                </div>
                <div class="p-4">
                    <div class="mb-4">
                        <button class="w-full px-4 py-2 text-white bg-blue-500 rounded hover:bg-blue-600"
                            onclick="toggleTable('invdiv')">Inventory</button>
                    </div>
                    <div class="mb-4">
                        <button class="w-full px-4 py-2 text-white bg-blue-500 rounded hover:bg-blue-600"
                            onclick="toggleTable('condiv')">Consumables</button>
                    </div>

                    <form action="{{ route('inventory.in_out') }}" method="POST">
                        @csrf
                        <div class="mb-4">
                            <label for="inventory_id" class="block text-sm font-medium text-gray-700">Item</label>
                            <select name="inventory_id" id="inventory_id"
                                class="block w-full mt-1 border-2 border-gray-300 rounded-md shadow-sm" required>
                                @foreach ($inventoryItems as $item)
                                    <option value="{{ $item->id }}">{{ $item->item_name }} ({{ $item->category }})
                                    </option>
                                @endforeach
                            </select>
                        </div>
                        <div class="mb-4">
                            <label for="type" class="block text-sm font-medium text-gray-700">Type</label>
                            <select name="type" id="type"
                                class="block w-full mt-1 border-2 border-gray-300 rounded-md shadow-sm" required>
                                <option value="in">Stock In</option>
                                <option value="out">Stock Out</option>
                            </select>
                        </div>
                        <div class="mb-4">
                            <label for="quantity" class="block text-sm font-medium text-gray-700">Quantity</label>
                            <input type="number" name="quantity" id="quantity"
                                class="block w-full mt-1 border-2 border-gray-300 rounded-md shadow-sm" required>
                        </div>
                        <div class="mb-4">
                            <label for="notes" class="block text-sm font-medium text-gray-700">Notes</label>
                            <input type="text" name="notes" id="notes"
                                class="block w-full mt-1 border-2 border-gray-300 rounded-md shadow-sm" required>
                        </div>
                        <div class="mb-4">
                            <label for="date" class="block text-sm font-medium text-gray-700">Date</label>
                            <input type="date" name="date" id="date"
                                class="block w-full mt-1 border-2 border-gray-300 rounded-md shadow-sm" required>
                        </div>
                        <div class="flex justify-end">
                            <button type="submit"
                                class="px-4 py-2 text-white bg-blue-500 rounded hover:bg-blue-600 ">Submit</button>
                        </div>
                    </form>
                </div>
            </div>

            <div class="mt-10 lg:col-span-2">
                @if (session('success'))
                    <div class="p-2 mt-4 text-green-700 bg-green-100 rounded">{{ session('success') }}</div>
                @endif

                <h3 class="p-5 text-lg font-semibold text-gray-800">Stock In/Out</h3>
                <table id="stocksTable" class="min-w-full text-center bg-white border-collapse rounded shadow-md">
                    <thead class="bg-gray-200">
                        <tr>
                            <th class="px-6 py-3 text-xs font-medium tracking-wider text-gray-700 uppercase">Item</th>
                            <th class="px-6 py-3 text-xs font-medium tracking-wider text-gray-700 uppercase">Type</th>
                            <th class="px-6 py-3 text-xs font-medium tracking-wider text-gray-700 uppercase">Quantity</th>
                            <th class="px-6 py-3 text-xs font-medium tracking-wider text-gray-700 uppercase">Notes</th>
                            <th class="px-6 py-3 text-xs font-medium tracking-wider text-gray-700 uppercase">Date</th>
                            <th class="px-6 py-3 text-xs font-medium tracking-wider text-gray-700 uppercase">Actions</th>
                        </tr>
                    </thead>
                    <tbody class="text-sm text-gray-600">
                    </tbody>
                </table>
            </div>
        </div>



        <div class="grid hidden grid-cols-1 gap-4 lg:grid-cols-3" id="condiv">
            <div class="overflow-hidden bg-white rounded-lg shadow-md lg:col-span-1">
                <div class="px-4 py-2 bg-gray-200 border-b">
                    <h3 class="text-lg font-semibold text-gray-800">Consumables</h3>
                </div>
                <div class="p-4">
                    <div class="mb-4">
                        <button class="w-full px-4 py-2 text-white bg-blue-500 rounded hover:bg-blue-600"
                            onclick="toggleTable('invdiv')">Inventory</button>
                    </div>
                    <div class="mb-4">
                        <button class="w-full px-4 py-2 text-white bg-blue-500 rounded hover:bg-blue-600"
                            onclick="toggleTable('stkdiv')">Stock In/Out</button>
                    </div>
                    <form action="{{ route('add.consumables') }}" method="POST">
                        @csrf

                        <div class="mb-4">
                            <label for="name" class="block text-sm font-medium text-gray-700">Name</label>
                            <input type="text" name="name" id="name" value="{{ old('name') }}"
                                class="block w-full mt-1 border-2 border-gray-300 rounded-md shadow-sm @error('name') border-red-500 @enderror"
                                required>
                            @error('name')
                                <p class="mt-1 text-xs text-red-500">{{ $message }}</p>
                            @enderror
                        </div>

                        <div class="mb-4">
                            <label for="quantity" class="block text-sm font-medium text-gray-700">Quantity</label>
                            <input type="number" name="quantity" id="quantity" value="{{ old('quantity') }}"
                                class="block w-full mt-1 border-2 border-gray-300 rounded-md shadow-sm @error('quantity') border-red-500 @enderror"
                                required>
                            @error('quantity')
                                <p class="mt-1 text-xs text-red-500">{{ $message }}</p>
                            @enderror
                        </div>

                        <div class="mb-4">
                            <label for="amount_spent" class="block text-sm font-medium text-gray-700">Amount Spent</label>
                            <input type="text" name="amount_spent" id="amount_spent"
                                value="{{ old('amount_spent') }}"
                                class="block w-full mt-1 border-2 border-gray-300 rounded-md shadow-sm @error('amount_spent') border-red-500 @enderror"
                                required>
                            @error('amount_spent')
                                <p class="mt-1 text-xs text-red-500">{{ $message }}</p>
                            @enderror
                        </div>

                        <div class="mb-4">
                            <label for="date" class="block text-sm font-medium text-gray-700">Date</label>
                            <input type="date" name="date" id="date" value="{{ old('date') }}"
                                class="block w-full mt-1 border-2 border-gray-300 rounded-md shadow-sm @error('date') border-red-500 @enderror"
                                required>
                            @error('date')
                                <p class="mt-1 text-xs text-red-500">{{ $message }}</p>
                            @enderror
                        </div>

                        <div class="mb-4">
                            <label for="notes" class="block text-sm font-medium text-gray-700">Notes</label>
                            <input type="text" name="notes" id="notes" value="{{ old('notes') }}"
                                class="block w-full mt-1 border-2 border-gray-300 rounded-md shadow-sm @error('notes') border-red-500 @enderror">
                            @error('notes')
                                <p class="mt-1 text-xs text-red-500">{{ $message }}</p>
                            @enderror
                        </div>

                        <div class="flex justify-end">
                            <button type="submit"
                                class="px-4 py-2 text-white bg-blue-500 rounded hover:bg-blue-600">Submit</button>
                        </div>
                    </form>

                </div>
            </div>

            <div class="mt-10 lg:col-span-2">
                @if (session('success'))
                    <div class="p-2 mt-4 text-green-700 bg-green-100 rounded">{{ session('success') }}</div>
                @endif

                <h3 class="p-5 text-lg font-semibold text-gray-800">Consumables</h3>
                <form action="{{ route('export.consumables') }}" method="GET">
                    <!-- Year Input -->
                    <div class="mb-4">
                        <label for="year" class="block text-sm font-medium text-gray-700">Year:</label>
                        <input type="number" name="year" id="year" min="2000" max="{{ date('Y') }}"
                            value="{{ old('year', date('Y')) }}" required
                            class="block w-full mt-1 border-2 border-gray-300 rounded-md shadow-sm">
                    </div>

                    <!-- Month Selector -->
                    <div class="mb-4">
                        <label for="month" class="block text-sm font-medium text-gray-700">Month:</label>
                        <select name="month" id="month" required
                            class="block w-full mt-1 border-2 border-gray-300 rounded-md shadow-sm">
                            @for ($i = 1; $i <= 12; $i++)
                                <option value="{{ $i }}" {{ old('month') == $i ? 'selected' : '' }}>
                                    {{ DateTime::createFromFormat('!m', $i)->format('F') }}
                                </option>
                            @endfor
                        </select>
                    </div>

                    <!-- Submit Button -->
                    <div class="flex justify-center">
                        <button type="submit"
                            class="px-4 py-2 text-white bg-blue-500 rounded hover:bg-blue-600">Export</button>
                    </div>
                </form>

                <table id="consumablesTable" class="min-w-full text-center bg-white border-collapse rounded shadow-md">
                    <thead class="bg-gray-200">
                        <tr>
                            <th class="px-6 py-3 text-xs font-medium tracking-wider text-gray-700 uppercase">Item Name</th>
                            <th class="px-6 py-3 text-xs font-medium tracking-wider text-gray-700 uppercase">Quantity</th>
                            <th class="px-6 py-3 text-xs font-medium tracking-wider text-gray-700 uppercase">Amount Spent
                            </th>
                            <th class="px-6 py-3 text-xs font-medium tracking-wider text-gray-700 uppercase">Date</th>

                            <th class="px-6 py-3 text-xs font-medium tracking-wider text-gray-700 uppercase">Notes</th>
                            <th class="px-6 py-3 text-xs font-medium tracking-wider text-gray-700 uppercase">Actions</th>
                        </tr>
                    </thead>
                    <tbody class="text-sm text-gray-600">
                    <tbody></tbody>
                </table>
            </div>
        </div>
    </div>







    @foreach ($inventoryItems1 as $item)
        <div id="deleteModal{{ $item->id }}"
            class="fixed inset-0 flex items-center justify-center hidden bg-black bg-opacity-50">
            <!-- Modal dialog -->
            <div class="max-w-md mx-auto overflow-hidden bg-white rounded-lg shadow-xl">
                <!-- Modal header -->
                <div class="flex items-center justify-between px-4 py-2 bg-red-500">
                    <h5 class="font-bold text-white">Confirm Delete</h5>
                    <button onclick="closeModal12('deleteModal{{ $item->id }}')" class="text-white">&times;</button>
                </div>

                <!-- Modal body -->
                <div class="px-4 py-4">
                    <p>Are you sure you want to delete this item?</p>
                </div>

                <!-- Modal footer -->
                <div class="flex items-center justify-end px-4 py-3 bg-gray-100">
                    <button onclick="closeModal12('deleteModal{{ $item->id }}')"
                        class="px-3 py-1 mr-2 text-gray-800 bg-gray-300 rounded hover:bg-gray-400">Cancel</button>

                    <!-- Form for delete -->
                    <form id="deleteForm{{ $item->id }}" action="{{ route('inventory.destroy', $item->id) }}"
                        method="POST">
                        @csrf
                        @method('DELETE')
                        <button type="submit"
                            class="px-3 py-1 text-white bg-red-500 rounded hover:bg-red-600">Delete</button>
                    </form>
                </div>
            </div>
        </div>





        <div id="editModal{{ $item->id }}"
            class="fixed inset-0 flex items-center justify-center hidden bg-black bg-opacity-50">
            <!-- Modal dialog -->
            <div class="w-1/2 mx-auto overflow-hidden bg-white rounded-lg shadow-xl">
                <!-- Modal header -->
                <div class="flex items-center justify-between px-4 py-2 bg-blue-500">
                    <h5 class="font-bold text-white">Confirm Delete</h5>
                    <button onclick="closeModal12('editModal{{ $item->id }}')" class="text-white">&times;</button>
                </div>

                <!-- Modal body -->
                <form action="{{ route('inventory.update', $item->id) }}" method="POST" class="p-10 ">
                    @csrf
                    @method('PUT')
                    <div class="mb-4">
                        <label for="category" class="block text-sm font-medium text-gray-700">Category</label>
                        <select name="category" id="category"
                            class="block w-full mt-1 border-gray-300 rounded-md shadow-sm" required>
                            <option value="Tools & Machineries"
                                {{ $item->category === 'Tools & Machineries' ? 'selected' : '' }}>Tools & Machineries
                            </option>
                            <option value="Consumables / Excess Materials"
                                {{ $item->category === 'Consumables / Excess Materials' ? 'selected' : '' }}>Consumables /
                                Excess Materials</option>
                            <option value="Office Supplies" {{ $item->category === 'Office Supplies' ? 'selected' : '' }}>
                                Office Supplies</option>
                            <option value="Office Equipment"
                                {{ $item->category === 'Office Equipment' ? 'selected' : '' }}>Office Equipment</option>
                        </select>
                    </div>
                    <div class="mb-4">
                        <label for="item_name" class="block text-sm font-medium text-gray-700">Item Name</label>
                        <input type="text" name="item_name" id="item_name" value="{{ $item->item_name }}"
                            class="block w-full mt-1 border-2 border-gray-300 rounded-md shadow-sm" required>
                    </div>
                    <div class="mb-4">
                        <label for="quantity" class="block text-sm font-medium text-gray-700">Quantity</label>
                        <input type="number" name="quantity" id="quantity" value="{{ $item->quantity }}"
                            class="block w-full mt-1 border-2 border-gray-300 rounded-md shadow-sm" required>
                    </div>
                    <div class="mb-4">
                        <label for="unit" class="block text-sm font-medium text-gray-700">Notes</label>
                        <input type="text" name="unit" id="unit" value="{{ $item->unit }}"
                            class="block w-full mt-1 border-2 border-gray-300 rounded-md shadow-sm">
                    </div>
                    <div class="flex justify-end">
                        <button type="submit"
                            class="px-4 py-2 ml-2 text-white bg-blue-500 rounded hover:bg-blue-600">Update</button>
                    </div>
                </form>
            </div>
        </div>
    @endforeach


    @foreach ($consumables as $item)
        <div id="deleteconsumableModal{{ $item->id }}"
            class="fixed inset-0 flex items-center justify-center hidden bg-black bg-opacity-50">
            <!-- Modal dialog -->
            <div class="max-w-md mx-auto overflow-hidden bg-white rounded-lg shadow-xl">
                <!-- Modal header -->
                <div class="flex items-center justify-between px-4 py-2 bg-red-500">
                    <h5 class="font-bold text-white">Confirm Delete</h5>
                    <button onclick="closeModal12('deleteconsumableModal{{ $item->id }}')"
                        class="text-white">&times;</button>
                </div>

                <!-- Modal body -->
                <div class="px-4 py-4">
                    <p>Are you sure you want to delete this consumable item?</p>
                </div>

                <!-- Modal footer -->
                <div class="flex items-center justify-end px-4 py-3 bg-gray-100">
                    <button onclick="closeModal12('deleteconsumableModal{{ $item->id }}')"
                        class="px-3 py-1 mr-2 text-gray-800 bg-gray-300 rounded hover:bg-gray-400">Cancel</button>

                    <!-- Form for delete -->
                    <form id="deleteForm{{ $item->id }}" action="{{ route('consumable.delete', $item->id) }}"
                        method="POST">
                        @csrf
                        @method('DELETE')
                        <button type="submit"
                            class="px-3 py-1 text-white bg-red-500 rounded hover:bg-red-600">Delete</button>
                    </form>
                </div>
            </div>
        </div>




        <div id="editmodalconsume{{ $item->id }}"
            class="fixed inset-0 flex items-center justify-center hidden bg-black bg-opacity-50">
            <!-- Modal dialog -->
            <div class="w-1/2 mx-auto overflow-hidden bg-white rounded-lg shadow-xl">
                <!-- Modal header -->
                <div class="flex items-center justify-between px-4 py-2 bg-blue-500">
                    <h5 class="font-bold text-white">Edit Consumable</h5>
                    <button onclick="closeModal12('editmodalconsume{{ $item->id }}')"
                        class="text-white">&times;</button>
                </div>
                <!-- Modal body -->
                <form action="{{ route('update.consumables', $item->id) }}" method="POST" class="p-10">
                    @csrf
                    @method('PUT')

                    <div class="mb-4">
                        <label for="name" class="block text-sm font-medium text-gray-700">Name</label>
                        <input type="text" name="name" id="name" value="{{ old('name', $item->name) }}"
                            class="block w-full mt-1 border-2 border-gray-300 rounded-md shadow-sm" required>
                        @error('name')
                            <p class="text-sm text-red-500">{{ $message }}</p>
                        @enderror
                    </div>

                    <div class="mb-4">
                        <label for="quantity" class="block text-sm font-medium text-gray-700">Quantity</label>
                        <input type="number" name="quantity" id="quantity"
                            value="{{ old('quantity', $item->quantity) }}"
                            class="block w-full mt-1 border-2 border-gray-300 rounded-md shadow-sm" required>
                        @error('quantity')
                            <p class="text-sm text-red-500">{{ $message }}</p>
                        @enderror
                    </div>

                    <div class="mb-4">
                        <label for="amount_spent" class="block text-sm font-medium text-gray-700">Amount Spent</label>
                        <input type="text" name="amount_spent" id="amount_spent"
                            value="{{ old('amount_spent', $item->amount_spent) }}"
                            class="block w-full mt-1 border-2 border-gray-300 rounded-md shadow-sm" required>
                        @error('amount_spent')
                            <p class="text-sm text-red-500">{{ $message }}</p>
                        @enderror
                    </div>

                    <div class="mb-4">
                        <label for="date" class="block text-sm font-medium text-gray-700">Date</label>
                        <input type="date" name="date" id="date" value="{{ old('date', $item->date) }}"
                            class="block w-full mt-1 border-2 border-gray-300 rounded-md shadow-sm" required>
                        @error('date')
                            <p class="text-sm text-red-500">{{ $message }}</p>
                        @enderror
                    </div>

                    <div class="mb-4">
                        <label for="notes" class="block text-sm font-medium text-gray-700">Notes</label>
                        <input type="text" name="notes" id="notes" value="{{ old('notes', $item->notes) }}"
                            class="block w-full mt-1 border-2 border-gray-300 rounded-md shadow-sm">
                        @error('notes')
                            <p class="text-sm text-red-500">{{ $message }}</p>
                        @enderror
                    </div>

                    <div class="flex justify-end">
                        <button type="submit"
                            class="px-4 py-2 ml-2 text-white bg-blue-500 rounded hover:bg-blue-600">Update</button>
                    </div>
                </form>
            </div>
        </div>
    @endforeach







    @foreach ($stockInOut1 as $item)
        <div id="deletestockModal{{ $item->id }}"
            class="fixed inset-0 flex items-center justify-center hidden bg-black bg-opacity-50">
            <!-- Modal dialog -->
            <div class="max-w-md mx-auto overflow-hidden bg-white rounded-lg shadow-xl">
                <!-- Modal header -->
                <div class="flex items-center justify-between px-4 py-2 bg-red-500">
                    <h5 class="font-bold text-white">Confirm Delete</h5>
                    <button onclick="closeModal12('deletestockModal{{ $item->id }}')"
                        class="text-white">&times;</button>
                </div>


                <div class="px-4 py-4">
                    <p>Are you sure you want to delete this item?</p>
                </div>

                <!-- Modal footer -->
                <div class="flex items-center justify-end px-4 py-3 bg-gray-100">
                    <button onclick="closeModal12('deleteModal{{ $item->id }}')"
                        class="px-3 py-1 mr-2 text-gray-800 bg-gray-300 rounded hover:bg-gray-400">Cancel</button>

                    <!-- Form for delete -->
                    <form id="deleteForm{{ $item->id }}" action="{{ route('inventory.delete', $item->id) }}"
                        method="POST">
                        @csrf
                        @method('DELETE')
                        <button type="submit"
                            class="px-3 py-1 text-white bg-red-500 rounded hover:bg-red-600">Delete</button>
                    </form>
                </div>
            </div>
        </div>
    @endforeach



    <script>
        // Function to open a modal
        function openModal12(modalId) {
            document.getElementById(modalId).classList.remove('hidden');
        }

        function closeModal12(modalId) {
            document.getElementById(modalId).classList.add('hidden');
        }
    </script>

@section('scripts')
    <script>
        $(document).ready(function() {
            $('#itemsTable').DataTable({
                processing: true,
                serverSide: true,
                ajax: {
                    url: '{{ route('inventory.index') }}',
                    data: {
                        table: 'item'
                    }
                },
                columns: [{
                        data: 'category',
                        name: 'category'
                    },
                    {
                        data: 'item_name',
                        name: 'item_name'
                    },
                    {
                        data: 'quantity',
                        name: 'quantity'
                    },

                    {
                        data: 'unit',
                        name: 'unit'
                    },
                    {
                        data: 'actions',
                        name: 'actions',
                        orderable: false,
                        searchable: false
                    }
                ]
            });

            $('#stocksTable').DataTable({
                processing: true,
                serverSide: true,
                ajax: {
                    url: '{{ route('inventory.index') }}',
                    data: {
                        table: 'stocks'
                    }
                },
                columns: [{
                        data: 'inventory.item_name',
                        name: 'inventory.item_name'
                    },
                    {
                        data: 'type',
                        name: 'type'
                    },
                    {
                        data: 'quantity',
                        name: 'quantity'
                    },
                    {
                        data: 'notes',
                        name: 'notes'
                    },
                    {
                        data: 'date',
                        name: 'date'
                    },
                    {
                        data: 'actions',
                        name: 'actions',
                        orderable: false,
                        searchable: false
                    }
                ]
            });
            $('#consumablesTable').DataTable({
                processing: true,
                serverSide: true,
                ajax: {
                    url: '{{ route('inventory.index') }}',
                    data: {
                        table: 'consumables'
                    }
                },
                columns: [{
                        data: 'name',
                        name: 'name'
                    },
                    {
                        data: 'quantity',
                        name: 'quantity'
                    },
                    {
                        data: 'amount_spent',
                        name: 'amount_spent'
                    },

                    {
                        data: 'date',
                        name: 'date',
                        render: function(data, type, row) {
                            // Format the date as "Month Day, Year"
                            if (type === 'display' && data) {
                                var date = new Date(data);
                                var options = {
                                    year: 'numeric',
                                    month: 'long',
                                    day: 'numeric'
                                };
                                return date.toLocaleDateString('en-US', options);
                            }
                            return data;
                        }
                    },
                    {
                        data: 'notes',
                        name: 'notes'
                    },

                    {
                        data: 'actions',
                        name: 'actions',
                        orderable: false,
                        searchable: false
                    }
                ]
            });
        });


        function openModal(action, id) {
            // Handle modal opening logic here
        }

        function toggleTable(tableId) {
            const divs = document.querySelectorAll(".grid");
            divs.forEach(div => {
                if (div.id === tableId) {
                    div.classList.remove("hidden");
                } else {
                    div.classList.add("hidden");
                }
            });
        }
    </script>
@endsection
@endsection
