@extends('layouts.sidebar')
<script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
@section('content')
    <div class="container mx-auto mt-10">

        <h1 class="mb-6 text-3xl font-bold">Admin Dashboard</h1>

        <div class="grid grid-cols-1 gap-6 sm:grid-cols-2 lg:grid-cols-4">
            <!-- Total Number of Tenants -->
            <div class="overflow-hidden bg-white rounded-lg shadow-lg">
                <div class="p-6">
                    <div class="flex items-center justify-between mb-4">
                        <div>
                            <h5 class="text-xl font-semibold text-gray-900">Total Number of Tenants</h5>
                            <p class="text-2xl text-gray-600">{{ $totalTenants }}</p>
                        </div>
                        <div class="p-2 bg-blue-500 rounded-full">
                            <svg class="w-8 h-8 text-white" fill="none" stroke="currentColor" viewBox="0 0 24 24"
                                xmlns="http://www.w3.org/2000/svg">
                                <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2"
                                    d="M12 5v14m0 0l-3-3m3 3l3-3M5 12h14m0 0l-3-3m3 3l3 3"></path>
                            </svg>
                        </div>
                    </div>
                    <canvas id="tenantsChart" width="400" height="300"></canvas>
                </div>
            </div>

            <!-- All Account Receivables -->
            <div class="overflow-hidden bg-white rounded-lg shadow-lg">
                <div class="p-6">
                    <div class="flex items-center justify-between mb-4">
                        <div>
                            <h5 class="text-xl font-semibold text-gray-900">All Account Receivables</h5>
                            <p class="text-2xl text-gray-600">₱{{ number_format($totalReceivables, 2) }}</p>
                        </div>
                        <div class="p-2 bg-green-500 rounded-full">
                            <svg class="w-8 h-8 text-white" fill="none" stroke="currentColor" viewBox="0 0 24 24"
                                xmlns="http://www.w3.org/2000/svg">
                                <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M5 13l4 4L19 7">
                                </path>
                            </svg>
                        </div>
                    </div>
                    <canvas id="receivablesChart" width="400" height="300"></canvas>
                </div>
            </div>

            <!-- Total Vacant Units -->
            <div class="overflow-hidden bg-white rounded-lg shadow-lg">
                <div class="p-6">
                    <div class="flex items-center justify-between mb-4">
                        <div>
                            <h5 class="text-xl font-semibold text-gray-900">Total Vacant Units</h5>
                            <p class="text-2xl text-gray-600">{{ $totalVacantUnits }}</p>
                        </div>
                        <div class="p-2 bg-yellow-500 rounded-full">
                            <svg class="w-8 h-8 text-white" fill="none" stroke="currentColor" viewBox="0 0 24 24"
                                xmlns="http://www.w3.org/2000/svg">
                                <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2"
                                    d="M19 14l-7 7m0 0l-7-7m7 7V3"></path>
                            </svg>
                        </div>
                    </div>
                    <canvas id="vacantUnitsChart" width="400" height="300"></canvas>
                </div>
            </div>

            <!-- Total Occupied Units -->
            <div class="overflow-hidden bg-white rounded-lg shadow-lg">
                <div class="p-6">
                    <div class="flex items-center justify-between mb-4">
                        <div>
                            <h5 class="text-xl font-semibold text-gray-900">Total Occupied Units</h5>
                            <p class="text-2xl text-gray-600">{{ $totalOccupiedUnits }}</p>
                        </div>
                        <div class="p-2 bg-red-500 rounded-full">
                            <svg class="w-8 h-8 text-white" fill="none" stroke="currentColor" viewBox="0 0 24 24"
                                xmlns="http://www.w3.org/2000/svg">
                                <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2"
                                    d="M13 10V3L4 14h7v7l9-11h-7z"></path>
                            </svg>
                        </div>
                    </div>
                    <canvas id="occupiedUnitsChart" width="400" height="300"></canvas>
                </div>
            </div>
        </div>

    </div>
    <div class="space-y-4">

        @if ($overduePayments->isNotEmpty())
            <div class="flex items-center p-4 bg-gray-100 border-l-4 border-gray-400">
                <span class="mr-2 text-lg">🔒</span>
                <div>
                    <h4 class="font-bold">Padlock Alert</h4>
                    <ul class="mt-2">
                        @foreach ($overduePayments as $payment)
                            @php
                                $dueDate = $payment->payment_date->copy()->addDays($payment->lease->terms);

                            @endphp
                            <li>
                                Business Name: {{ $payment->lease->client->business_name }} , Client:
                                {{ $payment->lease->client->owners_name }} - Amount:
                                ₱{{ number_format($payment->Amount, 2) }}
                                - Due
                                Date: {{ $dueDate->format('F j, Y') }}
                            </li>
                        @endforeach
                    </ul>
                </div>
            </div>
        @endif

        <!-- Foreclosure Notifications -->
        @if ($foreclosurePayments->isNotEmpty())
            <div class="flex items-center p-4 bg-yellow-100 border-l-4 border-yellow-400">
                <span class="mr-2 text-lg">⚠️</span>
                <div>
                    <h4 class="font-bold">Foreclosure Notices</h4>

                    <ul class="mt-2">
                        @foreach ($foreclosurePayments as $payment)
                            @php
                                $dueDate = $payment->payment_date->copy()->addDays($payment->lease->terms);

                            @endphp
                            <li>
                                Client: {{ $payment->lease->client->business_name }} - Amount:
                                ₱{{ number_format($payment->Amount, 2) }}
                                - Due
                                Date: {{ $dueDate->format('F j, Y') }}

                            </li>
                        @endforeach
                    </ul>
                </div>
            </div>
        @endif
    </div>

    </div>

    <script>
        // Chart.js code to create charts
        document.addEventListener("DOMContentLoaded", function() {
            // Chart data
            var tenantsChartData = {
                labels: ['Total Tenants'],
                datasets: [{
                    label: 'Total Tenants',
                    data: [{{ $totalTenants }}],
                    backgroundColor: 'rgba(54, 162, 235, 0.2)',
                    borderColor: 'rgba(54, 162, 235, 1)',
                    borderWidth: 1
                }]
            };

            var receivablesChartData = {
                labels: ['All Account Receivables'],
                datasets: [{
                    label: 'All Account Receivables',
                    data: [{{ $totalReceivables }}],
                    backgroundColor: 'rgba(75, 192, 192, 0.2)',
                    borderColor: 'rgba(75, 192, 192, 1)',
                    borderWidth: 1
                }]
            };

            var vacantUnitsChartData = {
                labels: ['Total Vacant Units'],
                datasets: [{
                    label: 'Total Vacant Units',
                    data: [{{ $totalVacantUnits }}],
                    backgroundColor: 'rgba(255, 206, 86, 0.2)',
                    borderColor: 'rgba(255, 206, 86, 1)',
                    borderWidth: 1
                }]
            };

            var occupiedUnitsChartData = {
                labels: ['Total Occupied Units'],
                datasets: [{
                    label: 'Total Occupied Units',
                    data: [{{ $totalOccupiedUnits }}],
                    backgroundColor: 'rgba(255, 99, 132, 0.2)',
                    borderColor: 'rgba(255, 99, 132, 1)',
                    borderWidth: 1
                }]
            };

            // Get canvas elements
            var tenantsChartCtx = document.getElementById('tenantsChart').getContext('2d');
            var receivablesChartCtx = document.getElementById('receivablesChart').getContext('2d');
            var vacantUnitsChartCtx = document.getElementById('vacantUnitsChart').getContext('2d');
            var occupiedUnitsChartCtx = document.getElementById('occupiedUnitsChart').getContext('2d');

            // Create charts
            var tenantsChart = new Chart(tenantsChartCtx, {
                type: 'bar',
                data: tenantsChartData,
                options: {
                    scales: {
                        y: {
                            beginAtZero: true
                        }
                    }
                }
            });

            var receivablesChart = new Chart(receivablesChartCtx, {
                type: 'bar',
                data: receivablesChartData,
                options: {
                    scales: {
                        y: {
                            beginAtZero: true
                        }
                    }
                }
            });

            var vacantUnitsChart = new Chart(vacantUnitsChartCtx, {
                type: 'bar',
                data: vacantUnitsChartData,
                options: {
                    scales: {
                        y: {
                            beginAtZero: true
                        }
                    }
                }
            });

            var occupiedUnitsChart = new Chart(occupiedUnitsChartCtx, {
                type: 'bar',
                data: occupiedUnitsChartData,
                options: {
                    scales: {
                        y: {
                            beginAtZero: true
                        }
                    }
                }
            });
        });
    </script>
@endsection
